locale = {
["..."]="…",
["011101000"]="011101000",
["011101001"]="011101001",
["15+%d damage, %d invulnerable left"] = "15+%d Schaden, %d Unverwundbarkeit übrig", -- Continental_supplies
["1-5, Precise + 1-4: Choose structure type"] = "1-5, Genaues Zielen + 1-4: Gebäudetyp wählen", -- Construction_Mode
["+1 barrel!"] = "+1 Fass!", -- Tumbler
["%.1fs"] = "%.1fs", -- Racer, TechRacer
["+1 Grenade"] = "+1 Granate", -- Basic_Training_-_Flying_Saucer
["+1 mine!"] = "+1 Mine", -- Tumbler
["1 - Normal Girder"]="1 – Normaler Bauträger",
["1 - Normal Land"]="1 – Normales Gelände",
["1 - Normal Rubber"]="1 – Normales Gummi",
["+1 point"] = "+1 Punkt", -- Mutant
["-1 point"] = "-1 Punkt", -- Mutant
["-1 to anyone for a suicide"]="-1 für Selbstmord",
["+1 to the Bottom Feeder for killing anyone"] = "+1 für den Versager für jeden Abschuss", -- Mutant
["+1 to the Mutant for killing anyone"] = "+1 für den Mutanten für jeden Abschuss", -- Mutant
["+2 for becoming the Mutant"] = "+2, wenn man Mutant wird", -- Mutant
["2 - Indestructible Girder"]="2 – Unzerstörbarer Bauträger",
["2 - Indestructible Land"]="2 – Unzerstörbares Gelände",
["30 minutes later..."]="30 Minuten später …",
["%.3fs"] = "%.3fs", -- A_Space_Adventure:ice02
["3 - Icy Girder"]="3 – Eisiger Bauträger",
["3 - Icy Land"]="3 – Eisiges Gelände",
["4 - Bouncy Girder"]="4 – Sprunghafter Bauträger",
["4 - Bouncy Land"]="4 – Sprunghaftes Gelände",
["5 additional enemies will be spawned during the game"]="5 weitere Gegner werden während des Spiels auftauchen",
["5 additional enemies will be spawned during the game."] = "In diesem Spiel werden 5 zusätzliche Gegner auftauchen.", -- A_Space_Adventure:fruit01
["5 deadly hogs"]="5 tödliche Igel",
["5 Deadly Hogs"] = "5 Tödliche Igel", -- A_Space_Adventure:death02
["6 more seconds added to the clock"]="6 Bonussekunden auf die Uhr",
["About a month ago, a cyborg came and told us that you're the cannibals!"]="Vor etwa einem Monat kam ein Cyborg und erzählte uns, dass ihr die Kannibalen seid.",
["Above-average pilot"]="Überdurchschnittlicher Pilot",
["Accuracy Bonus! +15 points"] = "Präzisionsbonus! +15 Punkte", -- Space_Invasion
["Accuracy bonus: +%d points"]="Präzisions-Bonus: +%d Punkte",
["Achievement gotten: %s"] = "Auszeichnung erhalten: %s", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_That_Sinking_Feeling, User_Mission_-_Bamboo_Thicket, User_Mission_-_Dangerous_Ducklings, Tumbler
["A Classic Fairytale"]="Ein klassisches Märchen",
["A crate critical to this mission has been destroyed."] = "Eine missionskritische Kiste wurde zerstört.", -- SimpleMission
["Actually, you aren't worthy of life! Take this..."]="Eigentlich hast du nicht das Recht, zu leben! Nimm das!",
["A cy-what?"]="Ein Cy-was?",
["Add %d"] = "%d addieren", -- HedgeEditor
["Admit what?"] = "Was zugeben?", -- A_Classic_Fairytale:queen
["ADVANCED REPOSITIONING MODE"]="FORTGESCHRITTENER VERLEGUNGSMODUS",
["Adventurous"]="Abenteuerlich",
["A frenetic Hedgewars mini-game"] = "Ein hektisches Hedgewars-Minispiel", -- Frenzy
["Africa"]="Afrika",
["A frozen adventure"]="Ein frostiges Abenteuer",
["After Leaks A Lot betrayed his tribe, he joined the cannibals..."]="Nachdem Undichte Stelle seinen Stamm betrogen hatte, trat er den Kannibalen bei.",
["After that incident he went underground and started working on his plan to steal the device."]="Nach dem Unfall ging er in den Untergrund und arbeitete an seinem Plan, um das Gerät zu stehlen.",  -- A_Space_Adventure:moon02
["After the shock caused by the enemy spy, Leaks A Lot and Dense Cloud went hunting to relax."]="Nach dem Schock, der vom feindlichen Spion ausgelöst wurde, gingen Undichte Stelle und Dichte Wolke zur Entspannung auf die Jagd.",
["After you killed an enemy, you'll lose the weapon that he is named after."] = "Wenn du einen Feind tötest, verlierst du die Waffe, nach der er benannt wurde.", -- A_Space_Adventure:death02
["After you left the moon, my other loyal minions came and resurrected me so I could complete my master plan."] = "Nachdem du den Mond verlassen hast, kamen meine anderen treuen Gehilfen und haben mich wiederbelebt, damit ich meinen Masterplan vollenden kann.", -- A_Space_Adventure:death01
["Again with the 'cannibals' thing!"]="Nicht schon wieder dieser »Kannibalen«-Unfug!",
["A Hedgewars minigame"] = "Ein Hedgewars-Minispiel", -- Capture_the_Flag
["A Hedgewars mini-game"] = "Ein Hedgewars-Minispiel", -- Racer, Space_Invasion, TechRacer, Tumbler
["A Hedgewars tag game"] = "Ein Hedgewars-Fangenspiel", -- Mutant
["Ahhh, home, sweet home. Made it in %d seconds."]="Ah, trautes Heim, Glück allein! Geschafft in %d Sekunden.",
["Aim at the ceiling and hold [Attack] pressed until the rope attaches."] = "Ziel auf die Decke und halte [Angriff], bis das Seil befestigt wird.", -- Basic_Training_-_Rope
["Aiming practice"] = "Zielübung", -- 
["Aiming Practice"] = "Zielübung", -- Basic_Training_-_Sniper_Rifle, Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Sniper_Rifle, Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["Aim: [Up]/[Down]"] = "Zielen: [Hoch]/[Runter]", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Rope
["Air General"]="Luftkommandant",
["Air Mine"]="Luftmine",
["Air Mine Placement Mode"]="Luftminenplatzierungsmodus",
["AIR MINE PLACEMENT MODE"]="LUFTMINENPLATZIERUNGSMODUS",
["A leap in a leap"]="Ein Sprung in einem Sprung",
["Alex"] = "Alex", -- 
["Alien! I wish to be moved!"] = "Außerirdischer! Ich wünsche, bewegt zu werden!", -- A_Classic_Fairytale:queen
["A little gift from the cyborgs"]="Ein kleines Geschenk von den Cyborgs",
["Al.Kaholic"] = "Al. Koholik", -- 
["All But Last"] = "Nicht Den Letzten", -- WxW
["All But Last: You must not solely attack the team with the least health"] = "Nicht Den Letzten: Du darfst das schwächste Team nicht einzeln angreifen", -- WxW
["All gone...everything!"]="Alles fort, alles!",
["Allies"]="Verbündete",
["All right, I'll admit it!"] = "Okay, ich geb’s zu!", -- A_Classic_Fairytale:queen
["All right, we just need to get to the other side of the island!"]="Okay, wir müssen einfach nur auf die andere Seite der Insel gelangen!",
["All right, you got me!"] = "Richtig, du hast mich ertappt!", -- A_Classic_Fairytale:queen
["All the other places are protected by our flight-inhibiting weapons."] = "All die anderen Orte werden von unseren flugverhindernden Waffen geschützt.", -- A_Space_Adventure:fruit01
["All the other places are protected by our flight-inhibiting weapons"]="Alle anderen Orte sind von unseren flugverhindernden Waffen geschützt.",
["All the saucer pilots dream to come here one day in order to compete with the best!"]="Alle Untertassenpiloten träumen davon, hier eines Tages herzukommen, um gegen die Besten um die Wette zu fliegen!",
["All they do is sit around and judge us!"] = "Alles, was sie tun, ist herumsitzen und uns beurteilen!", -- A_Classic_Fairytale:queen
["All this to please our beloved “elders” … hick …"] = "All das, um unseren geliebten »Ältesten« zu schmeicheln … hick …", -- A_Classic_Fairytale:queen
["All walls touched!"]="Alle Wände berührt!",
["All you do is take long walks when everyone else works."] = "Alles, was du tust, sind lange Spaziergänge, während jeder andere schuftet.", -- A_Classic_Fairytale:queen
["All your hedgehogs must be above the marked height!"] = "All deine Igel müssen sich über der markierten Höhe befinden!", -- A_Classic_Fairytale:family
["Also, you should know that the only place where you can fly is the left-most part of this area."] = "Außerdem solltest du wissen, dass der einzige Ort, in dem du fliegen kannst, der Platz ganz links in diesem Gebiet ist.", -- A_Space_Adventure:fruit01
["Also, you should know that the only place where you can fly is the left-most part of this area"]="Außerdem solltest du wissen, dass der einzige Ort, wo du fliegen kannst, ganz links in diesem Gebiet ist.",
["Always being considered weak and fragile."] = "Immer für schwach und fragil gehalten.", -- A_Classic_Fairytale:queen
["Amazing! I was never beaten in a race before!"]="Großartig! Ich wurde zuvor noch nie in einem Wettlauf geschlagen!",
["Ammo depleted!"] = "Munition aufgebraucht!", -- Space_Invasion
["Ammo: %d"] = "Munition: %d", -- Tumbler
["Ammo is reset at the end of your turn."]="Munition wird am Ende des Spielzuges zurückgesetzt.",
["Ammo Limit: Hogs can’t have more than 1 ammo per type"] = "Munitionslimit: Igel können nicht mehr als 1 Munition pro Typ besitzen", -- Highlander
["Ammo Maniac! +5 points!"] = "Munitionsverrückter! +5 Punkte!", -- Space_Invasion
["A mysterious Box"] = "Eine mysteriöse Kiste", -- Basic_Training_-_Movement
[" and 8 more seconds added to the clock"]=" und 8 Bonussekunden auf die Uhr",
["...and got ambushed by the Red Strawberries"]="… und von den Roten Erdbeeren überfallen wurdest.",
["... and got ambushed by the Red Strawberries"] = "… und wurde von den Roten Erdbeeren in einen Hinterhalt gelockt", -- A_Space_Adventure:fruit03
["And how am I alive?!"]="Und wie kann es sein, dass ich am Leben bin?",
["And I just forgot the checkpoint of my main mission. Great, just great!"] = "Und ich hab soeben den Kontrollpunkt meiner Hauptmission vergessen. Na super!", -- A_Space_Adventure:cosmos
["… and I think they are up to something. Something bad!"] = "… und ich glaube, sie haben etwas vor. Etwas Böses!", -- A_Classic_Fairytale:epil
["Andrey"] = "Andreas", -- 
["And so happened that Leaks A Lot failed to complete the challenge! He landed, pressured by shame ..."] = "Und so geschah es, dass Undichte Stelle bei der Herausforderung versagte. Er landete voller Scham …", -- A_Classic_Fairytale:first_blood
["And so it began..."]="Und so fing es an …",
["And so the cyborgs took over the island."] = "Und so eroberten die Cyborgs die Insel.", -- A_Classic_Fairytale:queen
["...and so the cyborgs took over the world..."]="Und so eroberten die Cyborgs die Welt …",
["And so they discovered that cyborgs weren't invulnerable..."]="Und so fanden sie heraus, dass die Cyborgs nicht unverwundbar sind.",
["… and then I took a stroll …"] = "… und dann ging ich spazieren …", -- A_Classic_Fairytale:epil
["And what do they do in the meantime? Nothing!"] = "Und was tun sie währenddessen? Nichts!", -- A_Classic_Fairytale:queen
["And where's all the weed?"]="Und wo ist all das Gras?",
["And you believed me? Oh, god, that's cute!"]="Und du hast mir geglaubt? Ach Gottchen, das ist so süß!",
["And you need to move to the top!"] = "Und du musst nach ganz oben!", -- Basic_Training_-_Movement
["An experimental editing tool for missions and more"] = "Ein experimentelles Tool für Missionen und mehr", -- HedgeEditor
["Anno 1032"] = "Anno 1032", -- Continental_supplies
["An object has been destroyed before it took enough damage."] = "Ein Objekt wurde zerstört, bevor es genug Schaden nahm!", -- SimpleMission
["Antarctica"]="Antarktika",
["Antarctic summer: Every 4th turn you get 1 girder, 1 mudball, 2 sine guns and 1 portable portal device."] = "Antarktischer Sommer: Jeden 4. Zug erhälst du 1 Träger, 1 Schlammball, 2 Sinuskanonen und 1 tragbares Portalgerät.", -- Continental_supplies
["Anti-Gravity Device Part (+1)"] = "Teil des Antischwerkraftgeräts (+1)", -- A_Space_Adventure:desert01, A_Space_Adventure:fruit02, A_Space_Adventure:ice01
["Anton"] = "Anton", -- 
["An unexpected event!"]="Ein unerwartetes Ereignis!",
["Anyway, the aliens accept me for who I am."] = "Jedenfalls akzeptieren die Außerirdischen mich für den, der ich bin!", -- A_Classic_Fairytale:queen
["A random hedgehog will inherit the weapons of his deceased team-mates"]="Ein zufälliger Igel wird die Waffen seiner verstorbenen Teamkollegen erben", -- A_Space_Adventure:death02
["A random hedgehog will inherit the weapons of his deceased team-mates."]="Ein zufälliger Igel wird die Waffen seiner verstorbenen Teamkollegen erben.", -- A_Space_Adventure:death02
["Arashi"] = "Arashi", -- 
["Areas surrounded by a green dashed outline are portal-proof and repel portals."] = "Land, das mit einer grünen gestrichtelten Linie umrandet ist, ist portalabweisend.", -- A_Space_Adventure:final
["Areas surrounded by a security border are indestructible."] = "Land, das eine Sicherheitsumrandung hat, ist unzerstörbar.", -- A_Space_Adventure:final
["Areas with a green dashed outline are portal-proof."] = "Land mit grüner gestrichtelter Umrandung ist portalabweisend.", -- A_Space_Adventure:final
["Areas with a security outline are indestructible."] = "Land mit Sicherheitsumrandung ist unzerstörbar.", -- A_Space_Adventure:final
["Are we there yet?"]="Sind wir schon da?",
["Are you accusing me of something?"]="Beschuldigst du mich?",
["Are you helping the aliens?"] = "Hilfst du den Außerirdischen?", -- A_Classic_Fairytale:queen
["Are you saying that many of us have died for your entertainment?"]="Willst du damit sagen, dass viele von uns nur für eure Unterhaltung gestorben sind?",
["Argh, the boredom!"] = "Argh, diese Langeweile!", -- A_Classic_Fairytale:queen
["Artur Detour"]="Artus Rück",
["As a reward for your performance, here's some new technology!"]="Als Belohnung für deine Leistung gebe ich dir eine neue Technologie!",
["Ash"] = "Ash", -- 
["A Shoppa minigame"] = "Ein Shoppa-Minispiel", -- WxW
["Asia"]="Asien",
["As long you don't touch the ground, you can|re-use the same rope as often as you like."] = "So lange du den Boden nicht berührst,|kannst du das selbe Seil wiederverwenden, so oft du willst.", -- Basic_Training_-_Rope
["A smuggler! Prepare for battle"]="Ein Schmuggler! Bereitmachen zum Kämpfen!",
["A Space Adventure"]="Ein Weltraumabenteuer",
["Assault Team"]="Sturmtruppe",
["Asteroid"] = "Asteroid", -- Big_Armory
["As the ammo is sparse, you might want to reuse ropes while mid-air."] = "Da die Munition knapp ist, solltest du Seile in der Luft wiederverwenden.", -- A_Classic_Fairytale:dragon
["As the challenge was completed, Leaks A Lot set foot on the ground..."]="Nachdem die Herausforderung abgeschlossen war, setzte Undichte Stelle einen Fuß auf den Boden.",
["As you are more experienced, I want you to lead them to battle."] = "Da du kampferprobt bist, will ich, dass du sie in die Schlacht führst.", -- A_Space_Adventure:fruit01
["As you are more experienced, I want you to lead them to the battle"]="Da du erfahrener bist, will ich, dass du sie in der Schlacht anführst.",
["As you can see I have survived our last encounter and I had time to plot my master plan!"]="Wie du sehen kannst, habe ich unser letztes Zusammentreffen überlebt und ich hatte Zeit, meinen Masterplan auszuhecken.",
["As you can see, there is no way to get on the other side!"]="Wie du siehst, gibt es keinen Weg, um auf die andere Seite zu kommen.",
["As you probably noticed, these rubber bands|are VERY elastic. Hedgehogs and many other|things will bounce off without taking any damage."] = "Wie du vielleicht bemerkt hast, sind diese|Gummibalken SEHR elastisch. Igel und viele andere|Dinge werden ohne jeglichen Schaden abprallen.", -- Basic_Training_-_Movement
["As you've seen, the dropped grenade roughly fell into your flying direction."] = "Wie du gesehen hast, fällt die Granate ungefähr in deine Flugrichtung.", -- Basic_Training_-_Flying_Saucer
["Athlete"]="Athlet",
["Attack: Activate"] = "Angriff: Aktivieren", -- Racer
["Attack Captain Lime before he attacks back."] = "Greif Leutnant Limone an, bevor er dich angreift.", -- A_Space_Adventure:fruit02
["Attack From Rope: %s"] = "Angriff Vom Seil: %s", -- WxW
["Attack From Rope: You may only attack from a rope."] = "Angriff Vom Seil: Du darfst nur vom Seil angreifen.", -- WxW
["Attack rule: %s"] = "Angriffsregel: %s", -- WxW
["Attack: Select this continent"] = "Angreifen: Diesen Kontinent wählen", -- Continental_supplies
["Attack: [Space]"] = "Angreifen: [Leertaste]", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
["Attack: Tap the [Bomb]"] = "Angreifen: [Bombe] antippen", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:shadow
["Attack the assassins before they attack back."] = "Greif die Assassinen an, bevor sie es tun.", -- A_Space_Adventure:fruit02
["Attack: Throw ball"] = "Angriff: Ball werfen", -- Knockball
["At the end of the game your health was "]="Am Ende des Spiels war deine Gesundheit ",
["At the end of the game your health was %d."] = "Am Ende des Spiels hattest du %d Gesundheit.", -- A_Space_Adventure:ice01
["At the start of the game each enemy hog has only the weapon that he is named after"]="Am Anfang des Spiels hat jeder feindliche Igel nur die Waffe, nach der er benannt wurde", -- A_Space_Adventure:death02
["At the start of the game each enemy hog has only the weapon that he is named after."]="Am Anfang des Spiels hat jeder feindliche Igel nur die Waffe, nach der er benannt wurde.", -- A_Space_Adventure:death02
["Australia"]="Australien",
["Available weapon specials:"] = "Verfügbare Waffenextras:", -- Continental_supplies
["Average pilot"]="Durchschnittlicher Pilot",
["Avoid bazookas, red and blue invaders."] = "Weiche Bazookas und den roten und blauen Invasoren aus.", -- Space_Invasion
["Axes"] = "Äxter", -- Bazooka_Battlefield
["Aye! Fellow! Let me exit this chamber of doom!"] = "Aye! Leute! Lasst mich aus dieser Kammer des Schreckens hinaus!", -- A_Classic_Fairytale:epil
["Back Breaker"]="Rückenbrecher",
["Back in the village, after telling the villagers about the threat..."]="Zurück im Dorf, nachdem die Dorfbewohner vor der Gefahr gewarnt worden sind …",
["Back in the village, the two tribes finally started to live in harmony."] = "Zurück im Dorf lebten die beiden Stämme endlich wieder in Frieden.", -- A_Classic_Fairytale:epil
["Back Jump: [Backspace] ×2"] = "Rückwärtssprung: [Rücktaste] ×2", -- Basic_Training_-_Movement
["Back Jump: Double-tap the [Curvy Arrow]"] = "Rückwärtssprung: [Krummen Pfeil] doppelt antippen", -- Basic_Training_-_Movement
["Back Jumping (1/2)"] = "Rückwärtsspringen (1/2)", -- Basic_Training_-_Movement
["Back Jumping (2/2)"] = "Rückwärtsspringen (2/2)", -- Basic_Training_-_Movement
["Backstab"]="Verrat",
["Backwards jump: Press [Backspace] twice"] = "Rückwärtssprung: Drück [Rücktaste] doppelt", -- A_Classic_Fairytale:first_blood
["Backwards jump: Tap the [Curvy Arrow] twice"] = "Rückwärtssprung: [Krummen Pfeil] doppelt antippen", -- A_Classic_Fairytale:first_blood
["Bacon"] = "Speck", -- 
["Bad Guy"] = "Böser Junge", -- User_Mission_-_The_Great_Escape
["Badmad"] = "Fies und böse", -- portal
["Bad Team"]="Böses Team",
["Bad timing"]="Schlechtes Timing",
["Baggy"] = "Schlabber", -- 
["Balrog"] = "Balrog", -- 
["Bamboo Thicket"]="Bambusdickicht",
["Barrel Launcher"]="Fasswerfer",
["Barrel Placement Mode"]="Fassplatzierungsmodus",
["BARREL PLACEMENT MODE"]="FASSPLATZIERUNGSMODUS",
["Barrier unlocked!"] = "Barriere geöffnet!", -- Basic_Training_-_Rope
["Baseball bat specials cannot be used close to other hogs."] = "Baseballschläger-Extras können nicht in der Nähe anderer Igel benutzt werden.", -- Continental_supplies
["Baseball Bat with Ball"] = "Baseballschläger mit Ball", -- Knockball
["Base damage has been modified to 12 per shot."] = "Der Grundschaden wurde auf 12 pro Schuss geändert.", -- Battalion
["Based on what you've learned, destroy the target on the girder and as always, land safely!"] = "Zeig, was du gelernt hast und zerstör die Zielscheibe auf dem Träger|und lande, wie immer, sicher!", -- Basic_Training_-_Flying_Saucer
["Basically this is a combination of diving and launching."] = "Im Grunde genommen ist das eine Kombination aus Tauchen und Schießen.", -- Basic_Training_-_Flying_Saucer
["Basic Bazooka Training"] = "Grundausbildung: Bazooka", -- Basic_Training_-_Bazooka
["Basic Grenade Training"] = "Grundausbildung: Granate", -- Basic_Training_-_Grenade
["Basic Movement Training"] = "Grundausbildung: Fortbewegung", -- Basic_Training_-_Movement
["Basic Rope Training"] = "Grundausbildung: Seil", -- Basic_Training_-_Rope
["Basic Training"] = "Grundausbildung", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
["Basketball"] = "Basketball", -- Basketball
["Bat balls at your enemies and|push them into the sea!"]="Schlage Bälle auf deine Widersacher|und lass sie ins Meer fallen!",
["Battalion"] = "Battalion", -- Battalion
["Battle Starts Now!"]="Jetzt beginnt die Schlacht!",
["Batty"] = "Plemplem", -- 
["Bat your opponents through the|baskets and out of the map!"]="Schlage deine Widersacher durch|die Körbe und aus der Karte hinaus!",
["Bazooka Battlefield"] = "Bazookaschlachtfeld", -- Bazooka_Battlefield
["Bazooka Master"] = "Bazookameister", -- Basic_Training_-_Bazooka
["Bazookas are influenced by wind."] = "Bazookas werden vom Wind beeinflusst.", -- Basic_Training_-_Bazooka
["Bearded Beast"] = "Bärtiges Biest", -- 
["Be careful, the future of Hogera is in your hands!"]="Sei vorsichtig, die Zukunft von Hogera liegt in deinen Händen!",
["Be careful, your fuel is limited from now on!"] = "Vorsichtig, dein Treibstoff ist ab jetzt begrenzt!", -- Basic_Training_-_Flying_Saucer
["Be careful, your gadgets won't work in the bandit area. You should get an ice gun."] = "Sei vorsichtig, deine Apparate werden im Banditenland nicht funktionieren. Du solltest dir eine Eiskanone besorgen.", -- A_Space_Adventure:ice01
["Beep Loopers"]="Piepskreisler",
["Beginner"]="Anfänger",
["Behind these trees on the east side there is Secret Base 17."] = "Hinter diesen Bäumen auf der Ostseite ist Geheimbasis 17.", -- A_Space_Adventure:cosmos
["Below-average pilot"]="Unterdurchschnittlicher Pilot",
["Besides, why would I choose certain death?"] = "Außerdem, warum sollte ich den sicheren Tod wählen?", -- A_Classic_Fairytale:queen
["Best team times: "] = "Team-Bestzeiten: ", -- Racer, TechRacer
["Better get yourself another health crate to heal your wounds."] = "Hol dir besser noch eine Gesundheitskiste, um deine Wunden zu heilen.", -- Basic_Training_-_Movement
["Better luck next time!"]="Vielleicht klappt’s beim nächsten Mal!",
["Better Safe Than Sorry"] = "Sicher ist sicher", -- A_Space_Adventure:desert02
["Beware, any damage taken will stay until you complete the moon's main mission"]="Achtung, jeglicher Schaden, den du nimmst, wird bleiben, bis du die Hauptmission des Mondes fertiggestellt hast.",
["Beware of mines: They explode after 3 seconds."] = "Vorsicht vor Minen: Sie explodieren nach 3 Sekunden.", -- A_Classic_Fairytale:journey
["Beware of mines: They explode after 5 seconds."] = "Vorsicht vor Minen: Sie explodieren nach 5 Sekunden.", -- A_Classic_Fairytale:journey
["Beware, though! If you are slow, you die!"]="Aber Vorsicht! Wenn du langsam bist, wirst du sterben!",
["Beware, though! Many smugglers come often to explore these tunnels and scavenge whatever valuable items they can find."]="Aber Vorsicht! Viele Schmuggler kommen oft hier her, um diese Tunnel zu durchsuchen und alles mögliche, was sie finden, zu sammeln.", -- A_Space_Adventure:desert01
["Beware, though, you will only be able to move slowly through the water."] = "Aber gib acht, du kannst dich nur langsam durchs Wasser bewegen.", -- Basic_Training_-_Flying_Saucer
["Big Armory"] = "Großes Arsenal", -- Big_Armory
["Billy Frost"]="Bernd Frost",
["Bingo"] = "Bingo", -- 
["Bio-Filter: Aggressively removes enemies."] = "Biofilter: Hält Feinde aggressiv fern.", -- Construction_Mode
["Bio-Filter"]="Biofilter",
["Biomechanic Team"]="Biomechanisches Team",
["Bitter"] = "Bitter", -- 
["Blanka"] = "Blanka", -- 
["Blender"]="Blender",
["Bloodpie"]="Blutkuchen",
["Bloodrocutor"]="Blutfrierer",
["Bloodsucker"]="Blutsauger",
["BlowTorch"]="Schweißbrenner",
["Blue"] = "Blau", -- 
["Blue Team"]="Blaues Team",
["Bob"]="Bert",
["Bobo"] = "Bobo", -- User_Mission_-_Nobody_Laugh
["Bone Jackson"]="Knochen-Ede",
["Bonely"]="Knochi",
["Bones"] = "Knochen", -- 
["BOOM! BOOM! BOOM! %s are the masters of destruction with %d destroyed invaders."] = "BUMM! BUMM! BUMM! %s sind die Meister der Zerstörung mit %d zerstörten Invasoren.", -- Space_Invasion
["Boom!"]="Bumm!",
["Boom! %s has destroyed %d invaders."] = "Bumm! %s hat %d Invasoren zerstört.", -- Space_Invasion
["BOOM! %s really didn't like the invaders, so they decided to destroy as much as %d of them."] = "BUMM! %s mochte die Invasoren gar nicht gern und entschlossen sich, ganze %d von ihnen zu vernichten.", -- Space_Invasion
["Boris"]="Boris",
["Boss defeated! +30 points!"] = "Boss besiegt! +30 Punkte!", -- Space_Invasion
["Boss Slayer! +25 points!"] = "Bosstöter! +25 Punkte!", -- Space_Invasion
["Both Barrels"] = "Zweischießer", -- 
["Both your hedgehogs must survive."] = "Deine beiden Igel müssen überleben.", -- User_Mission_-_Teamwork_2, User_Mission_-_Teamwork
["Bottom Feeder"] = "Versager", -- Mutant
["Bounciness"] = "Sprunghaftigkeit", -- Basic_Training_-_Grenade
["Bouncing Bomb"] = "Hüpfende Bombe", -- Basic_Training_-_Bazooka
["Bouncy Boomerang"] = "Springender Bumerang", -- Continental_supplies
["Bouncy Girder: [4]"] = "Sprunghafter Träger: [4]", -- HedgeEditor
["Bouncy Land: [4]"] = "Sprunghaftes Gelände: [4]", -- HedgeEditor
["Bouncy Land"]="Sprunghaftes Gelände",
["Bounty: Get 6 weapons for each kill (even on own hogs)."] = "Kopfgeld: Erhalte 6 Waffen für jeden Abschuss (sogar für eigene Igel).", -- Continental_supplies
["Bozo"] = "August", -- 
["Brain Blower"]="Hirnpuster",
["Brainiac"]="Hirni",
["Brainila"]="Hirnilia",
["Brain Stu"]="Hirntopf",
["Brain Teaser"]="Hirnreiz",
["Brigadier Briggs"] = "Brigadier Brecht", -- 
["Bruce"]="Brutus",
["Brutal Lily"]="Brutalo-Lilie",
["Brutus"]="Brutus",
["Build a fortress and destroy your enemy."]="Baue ein Fort und zerstöre deinen Feind.",
["Build an awesome race track by placing|waypoints which the hedgehogs have to|touch in any order to finish a round."] = "Baue eine Rennstrecke, indem du Wegpunkte platzierst,|die die Igel in beliebiger Reihenfolge berühren müssen,|um eine Runde zu absolvieren.", -- Racer
["Build a track and race."]="Konstruiere eine Strecke und mach ein Wettrennen.",
["Builder"]="Baumeister",
["Build one of multiple different structures|to aid you in victory, at the cost of energy."] = "Baue eines aus mehreren verschiedenen Gebäuden,|um dir beim Sieg zu helfen, auf Kosten von Energie.", -- Construction_Mode
["Bullseye"]="Volltreffer!",
["Bunny"] = "Hasi", -- 
["burp"] = "burp", -- 
["Bushes"] = "Büsche", -- Bazooka_Battlefield
["Bushi"] = "Bushi", -- 
["Buster"] = "Freundchen", -- 
["But it proved to be no easy task!"]="Aber es war keine einfache Aufgabe!",
["But I want my sandals!"] = "Aber ich will meine Sandalen!", -- A_Classic_Fairytale:queen
["But one thing's for sure:"] = "Aber eins ist mal sicher:", -- A_Space_Adventure:final
["But that's impossible!"]="Aber das ist unmöglich!",
["But the ones alive are stronger in their heart!"]="Aber die Lebendigen sind in ihrem Herzen stärker.",
["But … they kidnapped you!"] = "Aber … sie haben dich entführt!", -- A_Classic_Fairytale:queen
["But...we died!"]="Aber … wir sind gestorben!",
["But where can we go?"]="Aber wohin können wir gehen?",
["But why did you betray us?!"] = "Aber warum hast du uns verraten?!", -- A_Classic_Fairytale:queen
["But why would they help us?"]="Aber warum würden sie uns helfen?",
["But you're cannibals. It's what you do."]="Aber ihr seid Kannibalen. Das ist, was ihr tut.",
["But you said you'd let her go!"]="Aber du sagtest, dass du sie freilässt!",
["But you saved me!"] = "Aber du hast mich gerettet!", -- A_Classic_Fairytale:queen
["By the way, not only bazookas will bounce on water, but also grenades and many other things."] = "Übrigens, nicht nur Bazookas, sondern auch Granaten und viele andere Dinge werden auf dem Wasser hüpfen.", -- Basic_Training_-_Bazooka
["By the way, you can turn around without walking|by holding down Precise when you hit a walk control."] = "Übrigens, du kannst dich umdrehen, ohne zu gehen,|indem du die »Genaues zielen«-Taste gedrückt hältst|und dann eine der Gehen-Tasten drückst.", -- Basic_Training_-_Movement
["C-1"] = "C-1", -- portal
["C-2"] = "C-2", -- portal
["Callahan"] = "Callahan", -- 
["Call me Beep! Well, 'cause I'm such a nice...person!"]="Nenn mich »Pieps«! Weil ich so eine nette … Person bin!",
["Cannibal Sentry"]="Kannibalenwache",
["Cannibals"]="Kannibalen",
["Cannibals?! You're the cannibals!"]="Kannibalen?! Ihr seid die Kannibalen!",
["... can you do it?"]="Kannst du es schaffen?",
["Can you do it?"] = "Kannst du es schaffen?", -- A_Space_Adventure:ice02
["Cappy"] = "Käppi", -- Basic_Training_-_Movement
["Captain Lime"]="Leutnant Limone",
["Captain Lime offered his help if you assist him in battle."] = "Leutnant Limone bietet dir seine Hilfe an, wenn du ihm im Kampf zur Seite stehst.", -- A_Space_Adventure:fruit01
["Capture The Flag"] = "Capture The Flag", -- CTF_Blizzard, Capture_the_Flag
["Careful, hedgehogs can't swim!"] = "Achtung, Igel können nicht schwimmen!", -- Basic_Training_-_Movement
["Careless"]="Achtlos",
["Carol"]="Karol",
["Challenge completed!"]="Herausforderung bewältigt!",
["Challenge complete!"] = "Herausforderung abgeschlossen!",
["CHALLENGE COMPLETE"]="HERAUSFORDERUNG ABGESCHLOSSEN",
["Challenge failed!"] = "Herausforderung gescheitert!", -- 
["Challenge"]="Herausforderung",
["Challenge Objectives"]="Herausforderungsziele",
["Challenge objectives"] = "Herausforderungsziele", -- A_Space_Adventure:death02, A_Space_Adventure:desert03, A_Space_Adventure:final, A_Space_Adventure:fruit03, A_Space_Adventure:ice02, A_Space_Adventure:moon02
["Challenge over!"] = "Herausforderung vorbei!", -- User_Mission_-_Rope_Knock_Challenge
["Change bounciness: Tap [B]"] = "Sprungkraft ändern: [B] antippen", -- Basic_Training_-_Grenade
["Change Content: [Left], [Right]"]="Inhalt ändern: [Links], [Rechts]",
["Change detonation timer: Tap the [Clock]"] = "Explosionszeitzünder einstellen: [Uhr] antippen", -- Basic_Training_-_Grenade, A_Classic_Fairytale:shadow
["Change direction: [Left]/[Right]"] = "Richtung ändern: [Links]/[Rechts]", -- Basic_Training_-_Grenade
["Change Health Boost: [Left], [Right]"]="Gesundheitsschub ändern: [Links], [Rechts]",
["Change Health: [Left], [Right]"]="Gesundheit ändern: [Links], [Rechts]",
["Change LandFlag: [1], [2], [3], [4]"]="LandFlag ändern: [1], [2], [3], [4]",
["Change modification mode: [Left], [Right]"] = "Modifikationsmodus ändern: [Links], [Rechts]", -- HedgeEditor
["Change Placement Mode: [Up], [Down]"]="Platzierungsmodus ändern: [Hoch], [Runter]",
["Change Rotation: [Left], [Right]"]="Rotieren: [Links], [Rechts]",
["Change Selection: [Up], [Down], [Left], [Right]"]="Auswahl ändern: [Hoch], [Runter], [Links], [Rechts]",
["Change Sprite Frame: [Precise]+[Left], [Precise]+[Right]"] = "Nächstes Sprite-Frame: [Genaues Zielen]+[Rechts]|Vorheriges Sprite-Frame: [Genaues Zielen]+[Links]", -- HedgeEditor
["Change Sprite: [Left], [Right]"] = "Sprite wählen: [Links], [Rechts]", -- HedgeEditor
["Change Timer (in milliseconds): [Left], [Right]"]="Zeitzünder (in Millisekunden) ändern: [Links], [Rechts]",
["Change Timer: [Left], [Right]"] = "Zeitzünder wählen: [Links], [Rechts]", -- HedgeEditor
["Change weapon: [Long jump] or [Slot 1]-[Slot 3]"] = "Waffe wechseln: [Weiter Sprung] oder [Slot 1]-[Slot 3]", -- Tumbler
["Charmander"] = "Glumanda", -- 
["Chasing the blue hog"]="Jag den blauen Igel",
["Cheater"]="Cheater",
["Checkpoint reached!"]="Kontrollpunkt erreicht!",
["CheckPoint reached!"]="Kontrollpunkt erreicht!",
["Chef"]="Chefkoch",
["Chester"] = "Fifi", -- 
["Chicken"] = "Hühnchen", -- 
["Chief Sandologist"]="Haupt-Sandologe",
["Chikorita"] = "Endivie", -- 
["Choose location: Left click"] = "Ort wählen: Linksklick", -- A_Classic_Fairytale:shadow
["Choose location: Tap the [Target] button, then tap on the spot you want to choose"] = "Ort wählen: [Ziel]-Taste antippen, dann den gewünschten Ort antippen", -- A_Classic_Fairytale:shadow
["Choose Selection/Placement/Deletion: [Left], [Right]"] = "Auswahl-/Platzierungs-/Löschmodus wählen: [Links], [Rechts]", -- HedgeEditor
["Choose your continent wisely, as your decision will be permanent."] = "Wähle deinen Kontinent weise, da deine Entscheidung endgültig ist.", -- Continental_supplies
["Choose your side! If you want to join the strange man, walk up to him.|Otherwise, walk away from him. If you decide to att...nevermind..."]="Wähl deine Seite! Wenn du dem seltsamen Mann beitreten willst, geh zu ihm hin.|Geh ansonsten von ihm fort. Wenn du angr… Vergiss es!",
["Chunli"] = "Chunli", -- 
["Clark Kent"] = "Clark Kent", -- 
["Cleaver"]="Hackebeil",
["Cleaver Placement Mode"]="Hackebeilplatzierungsmodus",
["CLEAVER PLACEMENT MODE"] = "HACKEBEILPLATZIERUNGSMODUS", -- HedgeEditor
["Climb Home"]="Nach Hause klettern",
["Closing in"] = "Es neigt sich dem Ende zu", -- A_Classic_Fairytale:queen
["Clown"]="Clown",
["Clowns"]="Clowns",
["Clumsy"]="Hoppla",
["Cluster Bomb Training"] = "Splittergranatentraining", -- Target_Practice_-_Cluster_Bomb
["Collateral Damage II"]="Kollateralschaden II",
["Collateral Damage"]="Kollateralschaden",
["- Collect all the blue crates"] = "- Sammel alle blaue Kisten auf", -- HedgeEditor
["Collect all the crates, but remember, our time in this life is limited!"]="Sammle all die Kisten ein, aber denk dran, unsere Zeit in diesem Leben ist begrenzt!",
["Collect or destroy all the health crates."]="Sammle oder zerstöre alle Gesundheitskisten.",
["Collect or destroy the final crate to finish the training."] = "Schnapp dir oder zerstöre die letzte Kiste, um die Übung abzuschließen.", -- Basic_Training_-_Flying_Saucer
["- Collect the blue crate"] = "- Sammel die blaue Kiste auf", -- HedgeEditor
["Collect the crate and attack!"] = "Sammle die Kiste auf und greif an!", -- WxW
["Collect the crate on the right."] = "Sammle die Kiste rechts ein.", -- A_Classic_Fairytale:first_blood
["Collect the crates within the time limit!|If you fail, you'll have to try again."]="Sammle die Kisten innerhalb der Zeitbegrenzung ein!|Wenn du versagst, musst es erneut versuchen.",
["Collect the crate with the flying saucer!"] = "Sammle die Kiste mit der fliegenden Untertasse auf!", -- A_Space_Adventure:cosmos
["Collect the crate with the flying saucer"]="Sammle die Kiste mit der fliegenden Untertasse ein.",
["Collect the first crate to begin!"] = "Sammle die erste Kiste ein, um anzufangen!", -- Basic_Training_-_Flying_Saucer
["Collect the freezer and get the device part from Thanta."] = "Sammle die Eiskanone ein und hol dir das Geräteteil von Thanta.", -- A_Space_Adventure:ice01
["Collect the green and purple invaders."] = "Sammle die grünen und violetten Invasoren auf.", -- Space_Invasion
["Collect the icegun and get the device part from Thanta"]="Sammle die Eiskanone ein und besorge das Bauteil von Thanta",
["Collect the remaining crates to complete the training."] = "Schnapp dir die verbleibenden Kisten, um die Ausbildung zu beenden.", -- Basic_Training_-_Movement
["Collect the weapon crate and drop|a grenade from rope to destroy the barrels."] = "Sammel die Waffenkiste ein und|lass eine Granate vom Seil aus fallen,|um die Fässer zu zerstören.", -- Basic_Training_-_Rope
["Collect the weapon crate at the left coast!"] = "Sammle die Waffenkiste an der linken Küste auf!", -- A_Classic_Fairytale:journey
["Color Squad"] = "Farbentrupp", -- 
["Come back to this mission after collecting all the device parts"]="Kehre zu dieser Mission zurück, nachdem du alle Bauteile eingesammelt hast.",
["Come back to this mission and visit the other planets to collect the crates"]="Kehre zu dieser Mission zurück und besuche die anderen Planeten, um die Kisten einzusammeln.",
["Come closer and die! … burp …"] = "Kommt näher und sterbt! … rülps …", -- A_Classic_Fairytale:queen
["Come closer, so that your training may continue!"]="Komm näher, damit deine Übungen fortfahren können!",
["Comet"] = "Komet", -- Big_Armory
["Commander"]="Kommandant",
["COMMANDS: (Use while no weapon is selected)"]="BEFEHLE: (Benutzen, wenn keine Waffe gewählt ist)",
["Compete to use as few planes as possible!"]="Verwende so wenige Flugzeuge wie möglich!",
["Complete all main and side missions to complete the spacetrip mission."] = "Schließe alle Haupt- und Nebenmissionen ab, um die Weltraumreise-Mission abzuschließen.", -- A_Space_Adventure:cosmos
["Complete the obstacle course."] = "Schließ die Hindernisstrecke ab.", -- Basic_Training_-_Movement
["Complete the remaining side missions to complete this mission."] = "Beende die verbleibenden Nebenmissionen, um die Weltraumreise abzuschließen.", -- A_Space_Adventure:cosmos
["Complete the track as fast as you can!"]="Durchlaufe die Strecke so schnell du kannst!",
["Completion time: %.2fs"] = "Benötigte Zeit: %.2fs", -- User_Mission_-_Rope_Knock_Challenge
["Comrades! Sail me away!"] = "Kameraden! Setzt die Segel!", -- A_Classic_Fairytale:queen
["Configuration accepted."]="Konfiguration akzeptiert.",
["Configuration phase"] = "Konfigurationsphase", -- WxW
["Congrats! You made them run away!"]="Gratulation! Du hast sie in die Flucht geschlagen!",
["Congrats! You won!"]="Gratulation! Du hast gewonnen!",
["Congratulations!"]="Gratulation!",
["Congratulations, now you can take Thanta's device part!"] = "Gratulation, du kannst dir nun Thantas Bauteil nehmen!", -- A_Space_Adventure:ice01
["Congratulations, now you can take Thanta's device part..."]="Gratulation, nun kannst du dir Thantas Bauteil nehmen …",
["Congratulations, you acquired the device part!"]="Gratulation, du hast das Bauteil erhalten!",
["Congratulations, you are the best!"]="Gratulation, du bist der Beste!",
["Congratulations, you are the fastest!"]="Gratulation, du bist der Schnellste!",
["Congratulations, you collected the device part!"]="Gratulation, du hast das Bauteil eingesammelt!",
["Congratulations! You have completed the obstacle course!"] = "Gratulation! Du hast den Hindernislauf geschafft!", -- Basic_Training_-_Movement
["Congratulations! You have destroyed all targets within the time."] = "Du hast alle Zielscheiben innerhalb der Zeit zerstört.", -- 
["Congratulations, you have saved Hogera!"]="Gratulation, du hast Hogera gerettet!",
["Congratulations! You have truly mastered this challenge! Don't forget to save the demo."]="Gratulation! Du hast diese Herausforderung wahrhaft gemeistert! Vergiss nicht, die Wiederholung zu speichern.",
["Congratulations! You've eliminated all targets|within the allowed time frame."]="Gratulation! Du hast alle Zielscheiben innerhalb der|verfügbaren Zeit ausgeschaltet.",
["Congratulations, you won!"]="Gratulation, du hast gewonnen!",
["Conquering the galaxy"] = "Eroberung der Galaxis", -- A_Space_Adventure:cosmos
["CONSTRUCTION MODE"]="BAUMODUS",
["Construction Mode tool"] = "Baumoduswerkzeug", -- Construction_Mode
["Construction Station: Allows placement of|    girders, rubber, mines, sticky mines|    and barrels."] = "Baustation: Ermöglicht Platzierung von Trägern,|    Gummis, Minen, Haftminen und Fässern.", -- Construction_Mode
["Construction Station"]="Baustation",
["Continental supplies"]="Kontinentallieferungen",
["Continent selection"] = "Kontinentauswahl", -- Continental_supplies
["Continents: Select a continent at the beginning."] = "Kontinente: Wähle am Anfang einen Kontinent.", -- Continental_supplies
["Control"] = "Kontrolle", -- Control
["Control pillars to score points."]="Behalte die Kontrolle über die Säulen, um Punkte zu erhalten.",
["Copper"] = "Kupfer", -- User_Mission_-_Nobody_Laugh
["Corn"]="Mais",
["Corporal Calvin"] = "Unteroffizier Utrecht", -- 
["Corporationals"]="Kapitalista",
["Corpsemonger"]="Leichenschänder",
["Corpse Thrower"]="Leichenschmeißer",
["Cost: %d"] = "Kosten: %d", -- Construction_Mode
["Cotton Needer"] = "Falschsager", -- Mutant
["Count Hogula"] = "Graf Igula", -- 
["Coward"] = "Feigling", -- A_Classic_Fairytale:queen
["Crate Before Attack: %s"] = "Kiste Vorm Angriff: %s", -- WxW
["Crate Before Attack: You must collect a crate before you can attack."] = "Kiste Vorm Angriff: Du musst eine Kiste aufsammeln, bevor du angreifen kannst.", -- WxW
["Crate Placer"] = "Kistenplatzierer", -- Construction_Mode
["Crates: Crates drop more often with a higher chance of bonus ammo"] = "Kisten: Kisten erscheinen häufiger und haben öfters Bonusmunition", -- Battalion
["Crates: Crates drop randomly and may be empty"] = "Kisten: Kisten erscheinen zufällig und können leer sein", -- Battalion
["Crates: Crates drop randomly with chance of being empty"] = "Kisten: Kisten erscheinen zufällig und können leer sein", -- Battalion
["Crates left: %d"]="Verbleibende Kisten: %d",
["Crates per turn: %d"] = "Kisten pro Zug: %d", -- WxW
["Crazy Gravity: Gravity randomly changes within a range from %i%% to %i%% with a period of %s"] = "Verrückte Schwerkraft: Schwerkraft verändert sich zufällig zwischen %i%% und %i%% mit einer Periode von %s", -- Gravity
["Crazy Runner"]="Verrückter Renner",
["Cricket Time"] = "Kricket", -- Continental_supplies
["CTF_Blizzard"] = "CTF_Blizzard", -- CTF_Blizzard
["Cursor: Build structure"] = "Cursor: Gebäude bauen", -- Construction_Mode
["Cursor: Mode action"] = "Cursor: Modusaktion", -- HedgeEditor
["|Cursor: Place crate"] = "|Cursor: Kiste platzieren", -- Construction_Mode
["Cursor: Place waypoint"] = "Cursor: Wegpunkt platzieren", -- Racer
["Cutlass Cain"] = "Säbel-Sepp", -- 
["Cybernetic Empire"]="Kybernetisches Imperium",
["Cyborg. It's what the aliens call themselves."]="Cyborg. So nennen sich die Außerirdischen selbst.",
["Dahmer"]="Dahmer",
["Daisy"] = "Daisy", -- 
["DAMMIT, ROOKIE! GET OFF MY HEAD!"]="VERDAMMT, REKRUT! RUNTER VON MEINEM KOPF!",
["DAMMIT, ROOKIE!"]="VERDAMMT, REKRUT!",
["+%d Ammo"] = "+%d Munition", -- Space_Invasion
["Dangerous Ducklings"]="Gefährliche Entchen",
["Dark Strawberry"]="Dunkle Erdbeere",
["%d damage was dealt in this game."] = "In diesem Spiel wurde %d Schaden angerichtet.", -- Mutant
["%d / %d"] = "%d / %d", -- Battalion
["%d | %d"] = "%d | %d", -- Mutant
["%d/%d"] = "%d/%d", -- SpeedShoppa
["Deadly Grape"]="Traube des Todes",
["Deadweight"]="Gravitus",
["Deal 15 damage + 10% of your hog’s health to all hogs around you and get 2/3 back."] = "Mach 15 Schaden + 10% deiner Gesundheit auf alle Igel im Umkreis und erhalte 2/3 zurück.", -- Continental_supplies
["Deals 15 damage to all enemies in the circle."] = "Richte 15 Schaden auf alle Gegner im Kreis an.", -- Continental_supplies
["Deer"] = "Hirsch", -- 
["Defeat all enemies!"] = "Besiege alle Feinde!", -- portal
["Defeat!"] = "Niederlage!", -- HedgeEditor
["Defeat Professor Hogevil!"]="Besiege Professor Bösigel!",
["Defeat the cannibals!"] = "Besiege die Kannibalen!", -- A_Classic_Fairytale:shadow
["Defeat the cyborgs!"]="Besiege die Cyborgs!",
["Defeat the enemy!"] = "Besiege den Feind!", -- A_Classic_Fairytale:queen
["Delete Waypoint"] = "Wegpunkt löschen", -- HedgeEditor
["Deletion Mode: [5]"]="Löschmodus: [5]",
["Deletion Mode"]="Löschmodus",
["Demolition is fun!"]="Zerstörung macht Spaß!",
["Demo"] = "Zerstörer", -- The_Specialists
["Dense Cloud"]="Dichte Wolke",
["Dense Cloud must have already told them everything..."]="Dichte Wolke muss ihnen bereits alles gesagt haben.",
["Dense Cloud?! What are you doing?!"] = "Dichte Wolke?! Was tust du da?!", -- A_Classic_Fairytale:queen
["Depleted Kamikaze! +5 points!"] = "Munitionsloses Kamikaze! +5 Punkte!", -- Space_Invasion
["Derp"] = "Naja", -- User_Mission_-_Nobody_Laugh
["Desert Storm"] = "Wüstensturm", -- 
["Destroy all targets with no more than 10 bazookas."] = "Zerstöre alle Zielscheiben mit nicht mehr als 10 Bazookas!", -- Basic_Training_-_Bazooka
["Destroy all the targets!"] = "Zerstöre all die Zielscheiben!", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["Destroyer of planes"]="Flugzeug-Zerstörer",
["Destroy him, Leaks A Lot! He is responsible for the deaths of many of us!"]="Zerstöre ihn, Undichte Stelle! Er ist verantwortlich für viele Tote auf unserer Seite!",
["Destroy invaders and collect bonuses to score points."] = "Zerstöre Invasoren und sammle Boni auf, um zu punkten.", -- Space_Invasion
["- Destroy the enemy"] = "- Vernichte den Feind", -- HedgeEditor
["- Destroy the red target"] = "- Zerstöre das rote Ziel", -- HedgeEditor
["- Destroy the red targets"] = "- Zerstöre die roten Ziele", -- HedgeEditor
["Destroy the targets!"] = "Zerstöre die Zielscheiben!", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["+%d flamer fuel!"] = "+%d Flammenwerfertreibstoff", -- Tumbler
["%d-Hit Combo! +%d points!"] = "%d-Treffer-Kombi! +%d Punkte!", -- Space_Invasion
["Did anyone follow you?"]="Ist dir irgendjemand gefolgt?",
["Did I miss something?"] = "Hab ich was verpasst?", -- Space_Invasion
["Did not finish"] = "Wurde nicht fertig", -- Racer, TechRacer
["Did you really think I've changed?"] = "Habt ihr wirklich geglaubt, dass ich mich geändert habe?", -- A_Classic_Fairytale:queen
["Did you really think that I've changed?"] = "Habt ihr wirklich geglaubt, dass ich mich geändert habe?", -- A_Classic_Fairytale:queen
["Did you really think that we needed the help of one of you?"] = "Habt ihr wirklich geglaubt, dass wir die Hilfe von einen von euch gebraucht haben?", -- A_Classic_Fairytale:queen
["Did you see him coming?"]="Hast du ihn kommen sehen?",
["Did you warn the village?"]="Hast du das Dorf gewarnt?",
["Die, die, die!"]="Stirb, stirb, stirb!",
["Difficulty: Easy"] = "Schwierigkeitsgrad: Leicht", -- A_Classic_Fairytale:first_blood
["Difficulty: Hard"] = "Schwierigkeitsgrad: Schwer", -- A_Classic_Fairytale:first_blood
["Dimitry"] = "Dimitri", -- 
["%d invaders have been destroyed in this game."] = "In diesem Spiel wurden %d Invasoren zerstört.", -- Space_Invasion
["Disabled"] = "Deaktiviert", -- WxW
["Disguise as a Rockhopper Penguin"] = "Als Felsenpinguin tarnen", -- Continental_supplies
["Displacer"] = "Displacer", -- 
["Diver"] = "Taucher", -- User_Mission_-_Diver
["%d ms"] = "%d ms", -- HedgeEditor
["Doing stuff a monkey could do."] = "Dinge, die ein Affe tun könnte.", -- A_Classic_Fairytale:queen
["Domination game"] = "Spiel um die Vorherrschaft", -- Control
["Donald"] = "Donald", -- 
["Do not destroy the crates"]="Zerstöre nicht die Kisten.",
["Do not destroy the crates!"] = "Zerstör nicht die Kisten!", -- A_Space_Adventure:fruit02
["Do not laugh, inexperienced one, for he speaks the truth!"]="Lach nicht, Unerfahrener, da er die Wahrheit spricht!",
["Do not let his words fool you, young one! He will stab you in the back as soon as you turn away!"]="Lass dich nicht von seinen Worten einlullen, Jüngling! Er wird dich hinterrücks ermorden, sobald du ihm den Rücken zuwendest!",
["Don't be foolish son, there will be more"]="Sei kein Idiot, Sohn, es werden mehr kommen.",
["Don't be foolish, son, there will be more."] = "Sei kein Narr, Sohn, es werden bald mehr sein.", -- A_Space_Adventure:fruit01
["Don't blow up the crate."] = "Jag die Kiste nicht in die Luft.", -- A_Classic_Fairytale:journey
["Don't destroy the device crate!"]="Zerstöre nicht das Bauteil!",
["Don't eliminate Captain Lime before collecting the last crate!"]="Eliminiere Leutnant Limone nicht, bevor du die letzte Kiste eingesammelt hast!",
["Don't hit me, you fools!"] = "Nicht auf mich, ihr Idioten!", -- A_Space_Adventure:moon01
["Don't hit yourself!"] = "Triff nicht dich selbst!", -- Basic_Training_-_Bazooka
["Don't touch the flames!"] = "Berühr nicht die Flammen!", -- ClimbHome
["Don't you dare harming our tribe!"] = "Wag es nicht, unserem Stamm wehzutun!", -- A_Classic_Fairytale:queen
["Double Kill!"]="Doppelmord!",
["Double kill!"] = "Zweierschlächter!", -- Mutant
["Do you have any idea how bad an exploding arrow hurts?"] = "Habt ihr die leiseste Ahnung, wie sehr ein explodierender Apfel wehtut?", -- A_Classic_Fairytale:queen
["Do you have any idea how valuable grass is?"]="Habt ihr überhaupt eine Ahnung darüber, wie wertvoll Gras ist?",
["Do you have any idea what it's like in the village for a woman?"] = "Habt ihr die leiseste Ahnung, wie es im Dorf für eine Frau so ist?", -- A_Classic_Fairytale:queen
["Do you know where they are?"] = "Weißt du, wo sie sind?", -- A_Classic_Fairytale:queen
["Do you think you're some kind of god?"]="Hältst du dich für eine Art Gott?",
["Dragon's Lair"]="Die Höhle des Löwen",
["Dr. Banting"] = "Dr. Keuch", -- 
["Dr. Barnard"] = "Dr. Brand", -- 
["Dr. Blackwell"] = "Dr. Schwarz", -- 
["Dr.Cornelius"]="Dr. Cornelius",
["Dr. Cornelius"] = "Dr. Cornelius", -- A_Space_Adventure:cosmos, A_Space_Adventure:death01
["Dr. Crushing"] = "Dr. Knacks", -- 
["Dr. Drew"] = "Dr. Horch", -- 
["Dr. Harvey"] = "Dr. Lesch", -- 
["Dr. Hollows"] = "Dr. Hohl", -- 
["Dr. Horace"] = "Dr. Lauf", -- 
["Drills"]="Kurzer Prozess",
["Dr. Jenner"] = "Dr. Koch", -- 
["Dr. Jung"] = "Dr. Jung", -- 
["Drone Hunter! +10 points!"] = "Drohnenjäger! +10 Punkte!", -- Space_Invasion
["Drop a ball of dirt which turns into a|cluster on impact. Doesn’t end turn."] = "Lass einen Erdklumpen fallen,|der sich bei Aufprall in einen Bombensplitter|verwandelt. Beendet den Zug nicht.", -- Continental_supplies
["- Dropped flags may be returned or recaptured"] = "- Fallengelassene Flaggen können zurückgebracht oder aufgesammelt werden", -- Capture_the_Flag
["Dropping a weapon while in water would just drown it, but launching one would work."] = "Eine Waffe im Wasser fallen zu lassen, würde sie einfach nur absaufen lassen,|aber ein Abfeuern würde funktionieren.", -- Basic_Training_-_Flying_Saucer
["Drop weapon (while on rope): [Long Jump]"] = "Waffe fallen lassen (vom Seil): [Weitsprung]", -- Basic_Training_-_Rope
["Drove the minions away"]="Seine Lakaien vertrieben",
["Drove the Professor away"]="Den Professor vertrieben",
["Drowner"]="Absäufer",
["Dr. Parkinson"] = "Dr. Parkinson", -- 
["Drunk greenhorn"]="Betrunkener Grünschnabel",
["Drunk with power, perhaps!"] = "Betrunken von Macht, vielleicht!", -- A_Classic_Fairytale:queen
["%d sec"] = "%d s", -- Construction_Mode
["+%d seconds!"] = "+%d Sekunden!", -- Tumbler
["Dubloon Devil"] = "Dublonenteufel", -- 
["Dude, all the plants are gone!"]="Mann, all die Pflanzen sind fort!",
["Dude, can you see Ramon and Spiky?"]="He, kannst du Ramon und Stachli sehen?",
["Dude, it's unbearable!"] = "Mann, das ist unerträglich!", -- A_Classic_Fairytale:queen
["Dude, let me out!"] = "Mann, lass mich raus!", -- A_Classic_Fairytale:epil
["Dude, that outfit is so cool!"] = "Mann, dieses Outfit ist so cool!", -- A_Classic_Fairytale:epil
["Dude, that's so cool!"]="Junge, das ist so cool!",
["Dude, this is boring!"] = "Mann, das ist so langweilig!", -- A_Classic_Fairytale:queen
["Dude, we really need a new shaman..."]="Mann, wir brauchen wirklich einen neuen Schamanen.",
["Dude, what's this place?!"]="Junge, was ist das für ein Ort?!",
["Dude, where are we?"]="He, wo sind wir?",
["Dude, wow! I just had the weirdest high!"]="Junge, wow! Ich hatte gerade das seltsamste Erlebnis!",
["Dude, wow, you're so cute!"] = "Mann, wow, ihr seid so süß!", -- A_Classic_Fairytale:queen
["Dud Mine Placement Mode"] = "Blindgängerminenplatzierungsmodus", -- HedgeEditor
["DUD MINE PLACEMENT MODE"] = "BLINDGÄNGERMINENPLATZIERUNGSMODUS", -- HedgeEditor
["During the final testing of the device an accident happened"]="Bei den letzten Tests des Gerätes ist ein Unfall passiert.",
["During the final testing of the device an accident happened."] = "Bei den letzten Tests des Geräts ist ein Unfall passiert.", -- A_Space_Adventure:moon02
["During the game you can get new RC planes by collecting the weapon crates"]="Während des Spiels kannst du neue Funkflugzeuge erhalten, indem du die Waffenkisten sammelst",
["During the game you can get new RC planes by collecting the weapon crates."]="Während des Spiels kannst du neue Funkflugzeuge erhalten, indem du die Waffenkisten sammelst.",
["Dust Storm"] = "Staubsturm", -- Continental_supplies
["Each time you destroy all the targets on your current level you'll get teleported to the next level"]="Jedes Mal, wenn du alle Zielscheiben im aktuellen Level zerstörst, wirst du zum nächsten Level teleportiert",
["Each time you destroy all the targets on your current level you'll get teleported to the next level."]="Jedes Mal, wenn du alle Zielscheiben im aktuellen Level zerstörst, wirst du zum nächsten Level teleportiert.",
["Each time you play this missions enemy hogs will play in a random order"]="Jedes Mal, wenn du diese Mission spielst, werden die feindlichen Igel in einer zufälligen Reihenfolge spielen", -- A_Space_Adventure:death02
["Each turn is only ONE SECOND!"]="Jeder Zug dauert nur EINE SEKUNDE!",
["Each turn you get 1-3 random weapons"]="Du bekommst jede Runde 1-3 zufällig gewählte Waffen",
["Each turn you get one random weapon"]="Du bekommst jede Runde eine zufällig gewählte Waffe",
["Each turn you'll have only one rope to use"]="In jedem Zug kannst du nur ein Seil benutzen",
["Each turn you'll have only one rope to use."] = "In jedem Zug kannst du nur ein Seil benutzen.", -- A_Space_Adventure:moon02
["Eagle Eye"]="Adlerauge",
["Ear Sniffer"]="Ohrenschnüffler",
["Eckles"] = "Kicher", -- User_Mission_-_Nobody_Laugh
["Eclipse"] = "Eklipse", -- Big_Armory
["Editing Commands: (Use while no weapon is selected)"] = "Bearbeitungsbefehle: (Benutzen, wenn keine Waffe gewählt)", -- HedgeEditor
["Ehm... ok..."]="Aha, okay …",
["Ehm, okay ..."] = "Ähem, okay …", -- A_Space_Adventure:moon01
["Elderbot"]="Altbot",
["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."]="Eliminiere alle Zielscheiben, bevor die Zeit abläuft.|Du hast in dieser Mission unbegrenzte Munition.",
["Eliminated the evil minions"]="Die bösen Lakaien eliminiert",
["Eliminated the Professor Hogevil"]="Professor Bösigel eliminiert",
["Eliminate the enemy before the time runs out."] = "Eliminiere den Feind, bevor die Zeit abläuft.", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree
["Eliminate the enemy."] = "Eliminiere den Feind.", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock, User_Mission_-_Nobody_Laugh
["Eliminate the enemy hogs to win."]="Vernichte alle gegnerischen Igel, um zu gewinnen.",
["Eliminate Unit 3378."] = "Eliminiere Einheit 3378.", -- User_Mission_-_Teamwork
["Eliminate WatchBot 4000."] = "Eliminiere Wachboter 4000.", -- User_Mission_-_Teamwork_2
["Eliminate your captor."] = "Eliminiere deinen Peiniger.", -- User_Mission_-_The_Great_Escape
["Elite pilot"]="Elitepilot",
["Elmo"]="Elmo",
["Enabled"] = "Aktiviert", -- WxW
["Enemy kills: Collect victim's weapons and +%d%% of its base health"] = "Feind töten: Erhalte Opferwaffen und +%d%% dessen Grundgesundheit", -- Battalion
["Energetic Engineer"]="Energetischer Ingenieur",
["Engineer"]="Ingenieur",
["Enjoy the swim..."]="Viel Spaß beim Schwimmen …",
["Entered boredom phase! Discrepancies detected …"] = "Langeweilephase eingeleitet! Diskrepanzen erfasst …", -- A_Classic_Fairytale:queen
["Epilogue"] = "Epilog", -- A_Classic_Fairytale:epil
["Eugene"] = "Eugen", -- 
["Europe"]="Europa",
["Every 2 rings, the ring color will be green and you'll get an extra flying saucer"]="Alle 2 Ringe wird der Ring grün und du erhältst eine neue fliegende Untertasse",
["Every 2 rings you'll get extra flying saucers"]="Alle 2 Ringe erhältst du neue fliegende Untertassen",
["Everyone knows this."]="Das weiß jeder.",
["Every single time!"]="Jedes Mal!",
["Everything looks OK..."]="Alles sieht gut aus.",
["Every time you kill an enemy hog your ammo will get reset next turn"]="Jedes Mal, wenn du einen Gegner tötest, wird deine Munition im nächsten Zug zurückgesetzt", -- A_Space_Adventure:death02
["Everywhere I look, I see hogs walking around …"] = "Überall, wo ich hinschaue, sehe ich Igel herumspazieren …", -- A_Classic_Fairytale:epil
["Exactly, man! That was my dream."]="Genau! Das war mein Traum.",
["Except me, of course! I just saved a whole planet!"] = "Außer ich natürlich! Ich hab ja schließlich einen ganzen Planeten gerettet!", -- A_Space_Adventure:final
["Experienced beginner"]="Erfahrener Anfänger",
["Explore the tunnel with the other hedgehogs and search for the device."] = "Erforsche den Tunnel mit den anderen Igeln und such nach dem Gerät.", -- A_Space_Adventure:fruit02
["Exploring the tunnel"]="Höhlenforscher",
["Eye Chewer"]="Augenkauer",
["Fair Wind"] = "Steife Brise", -- 
["Fall Damage"] = "Fallschaden", -- Basic_Training_-_Movement
["Fallen Angel"] = "Gefallener Engel", -- Tentacle_Terror
["Family Reunion"]="Familientreffen",
["Fastest escape: %d turns"] = "Schnellste Flucht: %d Züge", -- A_Space_Adventure:desert02
["Fastest lap: %.3fs by %s"] = "Beste Zeit: %.3fs von %s", -- TrophyRace
["Feeble Resistance"]="Kraftloser Widerstand",
["Fell From Grace"]="Fiel in Ungnade",
["Fell From Heaven"]="Fiel Vom Himmel",
["Fell From Heaven is the best! Fell From Heaven is the greatest!"]="Fiel Vom Himmel ist die Beste! Fiel Vom Himmel ist die Größte!",
["Femur Lover"]="Schenkellieber",
["Fierce Competition! +8 points!"] = "Harter Wettkampf! +8 Punkte!", -- Space_Invasion
["Fiery Water?! Are you drunk again?"] = "Feuerwasser?! Bist du schon wieder betrunken?", -- A_Classic_Fairytale:queen
["Fiery Water"]="Feuerwasser",
["Fighting instead of cultivating a beautiful friendship."] = "Kämpfen, anstatt eine wunderschöne Freundschaft zu pflegen.", -- A_Classic_Fairytale:epil
["Fight: Press [Attack]"] = "Kämpfen: Drücke [Angreifen]", -- A_Space_Adventure:fruit01
["Filthy Blue"]="Blödblau",
["Final Challenge:"] = "Letzte Herausforderung:", -- Basic_Training_-_Rope
["Finally! We're out of this hellhole. Now go save the princess, %s!"] = "Endlich! Wir sind raus aus diesem Höllenloch. Jetzt befrei die Prinzessin, %s!", -- A_Classic_Fairytale:family
["Finally you are here..."]="Endlich bist du hier …",
["Finally you are here!"] = "Endlich bist du hier!", -- A_Space_Adventure:desert01, A_Space_Adventure:ice01
["Final result"] = "Endstand", -- Mutant
["Final Targets"] = "Letzte Zielscheiben", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["Final team scores:"] = "Endstand:", -- Space_Invasion
["Find all the parts of the anti-gravity device."] = "Finde all die Teile des Antischwerkraftgeräts.", -- A_Space_Adventure:cosmos
["Find a way to detonate all the explosives and stay alive!"]="Finde einen Weg, alle Sprengstoffe zu detonieren und bleib am Leben!",
["Find your tribe!|Cross the lake!"]="Finde deinen Stamm!|Überquere den Fluss!",
["Finish this challenge as fast as possible to earn bonus points."] = "Beende diese Herausforderung so schnell du kannst, um Bonuspunkte zu erhalten.", -- User_Mission_-_Rope_Knock_Challenge
["Finish waypoint placement"] = "Wegpunktplatzierung beenden", -- Racer
["Finish your training."] = "Schließe deine Übungen ab.", -- A_Classic_Fairytale:first_blood
["Finite Ropes"] = "Endliche Seile", -- Basic_Training_-_Rope
["Fire a rocket with napalm."] = "Feuere eine Rakete mit Napalm ab.", -- Continental_supplies
["Fire: [Precise]"] = "Feuern: [Genaues Zielen]", -- Space_Invasion, Tumbler
["Fire some exploding medicine that will heal 15 health to all hogs in its effect radius."] = "Wirf eine explodierende Medizin, die allen Igeln im Einflussradius 15 Gesundheit gibt.", -- Continental_supplies
["Fire your hedgehog like a sticky mine."] = "Feuere deinen Igel wie eine Haftmine.", -- Continental_supplies
["First aid kits?!"]="Erste-Hilfe-Koffer?",
["First Blood"]="Der erste Zusammenstoß",
["- First clan to capture the flag wins"] = "- Der erste Klan, der die Flagge erobert, gewinnt", -- Capture_the_Flag
["- First clan to score %d captures wins"] = "- Der erste Klan mit %d Eroberungen gewinnt", -- Capture_the_Flag
["First killer will mutate"] = "Erster Mörder wird mutieren", -- Mutant
["First Steps"]="Erste Schritte",
["Fishy"] = "Fischi", -- 
["Flag captured!"]="Flagge genommen!",
["Flag respawned!"]="Flagge wieder erschienen!",
["Flag returned!"]="Flagge zurückgebracht!",
["Flamer"]="Flammenwerfer",
["Flaming Worm"]="Flammenwurm",
["Flare"] = "Leuchtfackel", -- Continental_supplies
["Flawless victory!"]="Perfekter Sieg!",
["Flee: Press [Jump]"] = "Fliehen: Drücke [Springen]", -- A_Space_Adventure:fruit01
["Flesh for Brainz"]="Fleisch gegen Hirn",
["Fly around and hurl explosives to your enemies."] = "Flieg herum und wirf Sprengkörper auf deine Gegner.", -- Tumbler
["Flying Saucer Training"] = "Grundausbildung: Fliegende Untertasse", -- Basic_Training_-_Flying_Saucer
["Fly into space to fight off the invaders with barrels!"] = "Flieg in den Weltraum, um die Invasoren mit Fässern abzuwehren!", -- Space_Invasion
["Fly to the meteorite and detonate the explosives"]="Fliege zum Meteoriten und sprenge die Bomben.",
["Fly to the moon"]="Flieg zum Mond.",
["Fly to the moon."] = "Flieg zum Mond.", -- A_Space_Adventure:cosmos
["Follow the path and destroy the next target."] = "Folge dem Pfad und zerstöre die nächste Zielscheibe.", -- Basic_Training_-_Rope
["Forgetfulness: You will lose all your weapons each turn."] = "Vergesslichkeit: Du wirst jeden Zug alle Waffen verlieren.", -- Continental_supplies
["For the next crate, you have to do back jumps."] = "Für die nächste Kiste brauchst du Rückwärtssprünge.", -- Basic_Training_-_Movement
["Four Eyes"] = "Vier Augen", -- 
["Frank"] = "Frank", -- User_Mission_-_Nobody_Laugh
["Frankie"] = "Franki", -- 
["Free Dense Cloud and continue the mission!"]="Befrei Dichte Wolke und setze die Mission fort!",
["FRENZY"]="WAHNSINN",
["Friendly Fire!"]="Eigenbeschuss!",
["Friendly kills: Clear killer's pool and -%d%% of its base health"] = "Freund töten: Leert den Pool des Mörders; -%d%% seiner Grundgesundheit", -- Battalion
["From the second turn and beyond the water rises"]="Vom 2. Zug an wird das Wasser steigen.",
["From the second turn and beyond the water rises."] = "Vom zweiten Zug an wird das Wasser steigen.", -- A_Space_Adventure:desert02
["Frozen Bandits"]="Frostbanditen",
["Fruit Assassins"]="Obstassassinen",
["Fruit"] = "Obst", -- 
["Fruity"] = "Fruchtig", -- 
["Fuel: %d"] = "Treibstoff: %d", -- Tumbler
["Fuzzy Beard"] = "Stoppelbart", -- 
["“g=150”, where 150 is 150% of normal gravity."] = "»g=150«, wobei die »150« für 150% der Normalschwerkraft steht.", -- Gravity
["“g=50, g2=150, period=4000” for gravity changing|from 50 to 150 and back with period of 4000 ms."] = "»g=50, g2=150, period=4000«, für Schwerkraft,|die von 50 bis 150 wechselt mit einer Periode von 4000ms.", -- Gravity
["Galaxy Guardians"] = "Galaxiewächter", -- Big_Armory
["Game over!"] = "Spiel vorbei!", -- Space_Invasion
["Game Started!"]="Spiel gestartet!",
["Game? Was this a game to you?!"]="Spiel? War das ein Spiel für dich?!",
["Gangsters"] = "Gangster", -- 
["Gas Gargler"]="Gasgurgler",
["Gasp! A smuggler!"] = "Huch! Ein Schmuggler!", -- A_Space_Adventure:desert01
["Gasp!"] = "Huch!", -- A_Space_Adventure:desert01
["Gathering fruits all day long."] = "Den ganzen Tag nur Obst sammeln.", -- A_Classic_Fairytale:queen
["Gear Placement Tool"] = "Gear-Platzierungswerkzeug", -- HedgeEditor
["General information:"] = "Allgemeine Informationen:", -- Continental_supplies
["General Lemon"]="General Limone",
["Generator: Generates energy."] = "Generator: Erzeugt Energie.", -- Construction_Mode
["Generator"]="Generator",
["Get Dense Cloud out of the pit!"]="Hol Dichte Wolke aus der Grube!",
["Get him Spike!"]="Hol ihn, Stachel!",
["Get him, Spike!"] = "Stachel, hol ihn dir!", -- A_Space_Adventure:desert01
["Get on over there and take him out!"]="Mach, dass du hinüber kommst und schalte ihn aus!",
["Get on the head of the mole."] = "Stell dich auf dem Kopf des Maulwurfs.", -- A_Classic_Fairytale:first_blood
["Get past the flower."] = "Überquere die Blume.", -- A_Classic_Fairytale:journey
["Get ready to fight!"]="Bereitmachen zum Kämpfen!",
["Get that crate!"]="Hol dir die Kiste!",
["Get the crate on the other side of the island."] = "Hol dir die Kiste von der anderen Seite der Insel.", -- A_Classic_Fairytale:journey
["Get the final crate to the right to complete the training."] = "Hol dir die letzte Kiste ganz rechts, um die Übung abzuschließen.", -- Basic_Training_-_Movement
["Get the highest score to win."] = "Hol dir die höchste Punktzahl, um zu gewinnen.", -- Space_Invasion
["Get the next crate by jumping over the abyss."] = "Hol dir die nächste Kiste, indem du über den Abgrund springst.", -- Basic_Training_-_Movement
["Getting ready"]="Bereitmachen",
["Getting Started"] = "Los geht's!", -- Basic_Training_-_Rope
["Getting to the device"]="Zum Greifen nah",
["Get to the crate using your flying saucer!"] = "Gelange zur Kiste mit deiner fliegenden Untertasse!", -- Basic_Training_-_Flying_Saucer
["Get your teammates out of their natural prison and save the princess!"] = "Befrei deine Freunde aus ihrem natürlichen Gefängnis und rette die Prinzessin!", -- A_Classic_Fairytale:family
["Giggles"] = "Kicher", -- 
["Gimme Bones"]="Gib Knochen",
["Girder"]="Bauträger",
["Girder Placement Mode"]="Bauträgerplatzierungsmodus",
["GIRDER PLACEMENT MODE"]="BAUTRÄGERPLATZIERUNGSMODUS",
["Give a hog a preset identity and weapons"] = "Gib einem Igel eine voreingestellte Identität und Waffen", -- HedgeEditor
["Give an entire team themed hats and names"] = "Gib einem Team thematische Hüte und Namen", -- HedgeEditor
["Glark"]="Glark",
["Glasses"] = "Brille", -- 
["Glassy"] = "Glasig", -- 
["Goal Definition Mode"] = "Zieldefinierungsmodus", -- HedgeEditor
["GOAL DEFINITION MODE"] = "ZIELDEFINIERUNGSMODUS", -- HedgeEditor
["Goal: Score %d points or more to win!"] = "Ziel: Erreiche mindestens %d Punkte für den Sieg.", -- Mutant
["Go and collect the crate"]="Geh und sammle die Kiste auf.",
["Godai"] = "Godai", -- 
["Go down and save these PAotH hogs!"]="Geh runter und rette diese PAdI-Igel!",
["Go, get him again!"] = "Los, fang ihn erneut!", -- A_Space_Adventure:moon02
["Go get him again"]="Los, hol ihn dir wieder!",
["Goggles"] = "Luken", -- 
["Goggs"] = "Goggs", -- 
["GO! GO! GO!"]="Los, los, los!",
["Good birdy......"]="Braver Vogel …",
["Good bye!"] = "Tschüss!", -- Basic_Training_-_Flying_Saucer
["Good idea, they'll never find us there!"]="Gute Idee, dort werden sie uns niemals finden!",
["Good job! Defeat the rest of the aliens!"] = "Gut gemacht! Besiege die verbleibenden Außerirdischen!", -- A_Classic_Fairytale:queen
["Good job!"] = "Gut gemacht!", -- Basic_Training_-_Flying_Saucer, Basic_Training_-_Rope
["Good job! Now destroy the final targets to finish the training."] = "Gut gemacht! Jetzt zerstöre die letzten Zielscheiben,|um die Übung abzuschließen.", -- Basic_Training_-_Grenade
["Good luck...or else!"]="Viel Glück! Sonst …!",
["Good luck out there!"]="Viel Glück da draußen!",
["Good luck!"]="Viel Glück!",
["Good so far!"]="Gut soweit!",
["Good to go!"]="Startklar!",
["Good! You now control Cappy."] = "Gut! Jetzt steuerst du Käppi.", -- Basic_Training_-_Movement
["Go on top of the flower."] = "Geh auf die Spitze der Blume.", -- A_Classic_Fairytale:first_blood
["Go, quick!"]="Los, schnell!",
["Gorkij"]="Gorkidsch",
["Go surf!"]="Los, surfe!",
["Got 1 more saucer"]="1 neue Untertasse",
["Got 1 more saucer and 8 more seconds added to the clock"] = "1 neue Untertasse und 8 zusätzliche Sekunden auf die Uhr", -- A_Space_Adventure:ice02
["GOTCHA!"]="ERWISCHT!",
["Go to go back"]="Ich muss umkehren.",
["Go to Thanta and get the device part!"]="Gehe zu Thanta und ergattere das Bauteil!",
["Go to the moon by using the flying saucer and complete the main mission"]="Komm zum Mond, indem du die fliegende Untertasse benutzt und die Hauptmission beendest.",
["Go to the surface!"]="Geh an die Oberfläche!",
["Go to the target."] = "Beweg dich zum Ziel.", -- Basic_Training_-_Rope
["Go to the upper platform and get the weapons in the crates!"]="Geh zur oberen Plattform und nimm dir die Waffen in den Kisten!",
["Got the saucer!"]="Ich hab die Untertasse!",
["Got to go back."] = "Ich muss zurück.", -- A_Space_Adventure:cosmos
["Got you? You're acting weird."] = "Dich ertappt? Du bist ja komisch drauf.", -- A_Classic_Fairytale:queen
["Grab mines/barrels: [High jump]"] = "Minen/Fässer schnappen: [Hochsprung]", -- Tumbler
["Gravity: 100%"] = "Schwerkraft: 100%", -- Gravity
["Great choice, Steve! Mind if I call you that?"]="Großartige Entscheidung, Stefan! Stört es dich, wenn ich dich so nenne?",
["Great!"] = "Großartig!", -- Basic_Training_-_Rope
["Great! Let’s kill all these enemies, using portals."] = "Großartig! Lasst uns diese Feinde vernichten, und zwar mit Portalen.", -- portal
["Great! You will be contacted soon for assistance."]="Gut! Du wirst schon bald für Unterstützung benachrichtigt.",
["Green areas aren't portal enabled"]="Grüne Bereiche sind portalabweisend",
["Green Bananas"]="Grüne Bananen",
["Green double rings also give you a new flying saucer."] = "Grüne Doppelringe geben dir zusätzlich eine fliegende Untertasse.", -- A_Space_Adventure:ice02
["Green"] = "Grün", -- 
["Green Hog Grape"]="Grünigeltraube",
["Green hogs won't intentionally hurt you"]="Grüne Igel werden dich nicht absichtlich verletzen.",
["Greenhorn"]="Grünschnabel",
["Green Lipstick Bullet"] = "Grüne Lippenstiftpatrone", -- Continental_supplies
["Greetings, cloudy one!"]="Grüße, du Wolkiger!",
["Greetings from the Navy, %s (%s), for being a distance of %d away from the mainland!"]="Grüße von der Marine, %s (%s), für einen Abstand von %d vom Festland!",
["Greetings, %s!"] = "Sei gegrüßt, %s!", -- A_Classic_Fairytale:dragon
["Grenades explode after 1 to 5 seconds (you decide)."] = "Granaten explodieren nach 1 bis 5 Sekunden (du entscheidest).", -- Basic_Training_-_Grenade
["Grenades with high bounciness bounce a lot and behave chaotic."] = "Granaten mit hoher Sprungkraft springen sehr stark und verhalten sich chaotisch.", -- Basic_Training_-_Grenade
["Grenadier"]="Grenadier",
["Grey"] = "Grau", -- 
["Guards"]="Wächter",
["Guile"] = "Guile", -- 
["Guys, do you think there's more of them?"]="Leute, glaubt ihr, dass es noch mehr von ihnen gibt?",
["Haha! Come!"] = "Haha! Kommt!", -- A_Classic_Fairytale:queen
["Haha!"]="Haha!",
["HAHA!"]="HAHA!",
["Hahahaha!"]="Hahahaha!",
["Haha, I love the look on your face!"] = "Haha, ich mag deinen Gesichtsausdruck!", -- A_Classic_Fairytale:queen
["Haha, now THAT would be something!"]="Haha, na DAS wär ja was!",
["Haha, that was just a coincidence!"] = "Haha, das war nur ein Zufall!", -- A_Classic_Fairytale:queen
["Hannibal"]="Hannibal",
["Hapless Hogs"]="Glücklose Igel",
["Happy with your race track?|Then stop building and start racing!"] = "Zufrieden mit deiner Rennstrecke?|Dann hör auf, zu bauen, und starte das Rennen!", -- Racer
["Hard flying"]="Schwerer Flug",
["Harris"] = "Harald", -- 
["Harry"] = "Harry", -- User_Mission_-_Nobody_Laugh
["Harry Potter"] = "Harry Potter", -- 
["Hatless Jerry"]="Hutloser Igor",
["Have no illusions, your tribe is dead, indifferent of your choice."]="Mach dir keine Hoffnungen, dein Stamm ist tot, unabhängig von deiner Entscheidung.",
["Haven't found it yet ..."] = "Hab's noch nicht gefunden …", -- A_Space_Adventure:desert01
["Haven't found it yet..."]="Ich hab es noch nicht gefunden.",
["Have we ever attacked you first?"]="Haben wir euch jemals zuerst angegriffen?",
["H confirmed that there isn't such a PAotH activity logged"]="H bestätigte, dass eine solche PAdI-Aktivität nicht protokolliert ist.",
["H confirmed that there isn't such a PAotH activity logged."] = "H bestätigte, dass eine solche PAdI-Aktivität nicht protokolliert ist.", -- A_Space_Adventure:desert01
["Healing Station: Heals nearby hogs."] = "Heilstation: Heilt Igel in der Nähe.", -- Construction_Mode
["Healing Station"]="Heilstation",
["Health Crate Placement Mode"]="Gesundheitskistenplatzierungsmodus",
["HEALTH CRATE PLACEMENT MODE"]="GESUNDHEITSKISTENPLATZIERUNGSMODUS",
["Health: %d"] = "Gesundheit: %d", -- HedgeEditor
["Health"] = "Gesundheit", -- Basic_Training_-_Movement
["Health: Hogs lose up to 7% base health per turn"] = "Gesundheit: Igel verlieren bis zu 7% der Grundgesundheit pro Zug", -- Battalion
["Health Modification Mode"]="Gesundheitsmodifikationsmodus",
["HEALTH MODIFICATION MODE"]="GESUNDHEITSMODIFIKATIONSMODUS",
["Heavenly Defense"] = "Himmlische Verteidigung", -- Tentacle_Terror
["Heavy Cannfantry"]="Schwere Kannfanterie",
["Heavy"]="Schwierig",
["Heckles"] = "Jux", -- 
["Heck, you even executed one of your own!"] = "Verdammt, ihr habt sogar einen von euch exekutiert!", -- A_Classic_Fairytale:queen
["Hedge-cogs"]="Stachelräder",
["HEDGE EDITOR"]="HEDGE EDITOR",
["HEDGEEDITOR"] = "HEDGEEDITOR", -- HedgeEditor
["HedgeEditor tool"] = "HedgeEditor-Werkzeug", -- HedgeEditor
["Hedgehog"] = "Igel", -- 
["Hedgehog Projectile"] = "Igelprojektil", -- Continental_supplies
["Hedgehogs can not be deleted."] = "Igel können nicht gelöscht werden.", -- HedgeEditor
["Hedgehogs left: %d"] = "Verbleibende Igel: %d", -- User_Mission_-_That_Sinking_Feeling
["Hedgehogs will be revived after their death."] = "Igel werden nach ihrem Tod wiederbelebt.", -- Mutant
["Hedgehogs will start in the first waypoint."] = "Igel starten im ersten Wegpunkt.", -- Racer
["Hedgibal Lecter"]="Iglibal Lector",
["He doesn't know it but this device is a part of the anti-gravity device"]="Er weiß es nicht, aber dieses Bauteil ist ein Teil des Antischwerkraftgeräts.",
["He doesn't know it but this device is a part of the anti-gravity device."] = "Er weiß es nicht, aber dieses Gerät ist Teil des Antischwerkraftgeräts.", -- A_Space_Adventure:ice01
["He has captured the rest of the PAotH team and awaits to capture you!"]="Er hat den Rest des PAdI-Teams gefangen und wartet auf deine Gefangennahme!",
["Heh, it's not that bad."]="Hehe, so schlimm ist er nicht.",
["Height over time"] = "Höhe über die Zeit", -- ClimbHome
["He is a very tough and very determined hedgehog. I would be extremely careful if I were you."] = "Er ist ein sehr hartnäckiger und sehr starrköpfiger Igel. Ich wäre extrem vorsichtig, wenn ich an deiner Stelle wäre.", -- A_Space_Adventure:moon02
["He is a very tough and very determined hedgehog. I would be extremely careful if I were you"]="Er ist ein sehr starker und willensstarker Igel. An deiner Stelle wäre ich sehr vorsichtig.",
["Helena"]="Helena",
["Hell Army"] = "Höllenarmee", -- portal
["Hello again, %s!"] = "Hallo, mal wieder, %s!", -- A_Classic_Fairytale:family
["Help Disabled"] = "Hilfe deaktiviert", -- HedgeEditor
["Help Enabled"] = "Hilfe aktiviert", -- HedgeEditor
["Helpers: Each team starts with %d helper points"] = "Helfer: Jedes Team beginnt mit %d Helferpunkten", -- Battalion
["Helpers: Hogs will get 1 out of 2 helpers randomly each turn"] = "Helfer: Igel kriegen zufällig 1 aus 2 Helfern pro Zug", -- Battalion
["Help me, Leaks!"]="Hilf mir, Undichte!",
["Help me, please!"]="Hilf mir bitte!",
["He moves like an eagle in the sky."]="Er bewegt sich wie ein Adler in der Luft.",
["He must be in the village already."]="Er muss schon im Dorf sein.",
["HeneK"] = "HeneK", -- 
["Here, let me help you!"]="Okay, lasst mich euch helfen!",
["Here, let me help you save her!"]="Hier, lass mich dir helfen, sie zu retten!",
["Here...pick your weapon!"]="Hier … wähl deine Waffe!",
["Here! Take it..."]="Hier, nimm es …",
["Here! Take it!"] = "Hier! Nimm es!", -- A_Space_Adventure:ice01
["Here we go!"]="Auf geht's!",
["Here you will find the current mission instructions."] = "Hier siehst du die aktuellen Missionsanweisungen.", -- Basic_Training_-_Movement
["Here you will learn how to fly the flying saucer|and get so learn some cool tricks."] = "Hier wirst du den Flug mit der fliegenden Untertasse|und ein paar coole Tricks lernen.", -- Basic_Training_-_Flying_Saucer
["Heroic Wind"] = "Heroischer Wind", -- Continental_supplies
["He's so brave..."]="Er ist so mutig.",
["He was the lab assistant of Dr. Goodhogan, the inventor of the anti-gravity device"]="Er war der Laborassistent von Dr. Gutigeln, dem Erfinder des Antischwerkraftgeräts.",
["He was the lab assistant of Dr. Goodhogan, the inventor of the anti-gravity device."] = "Er war der Laborassistent von Dr. Gutigeln, dem Erfinder des Antischwerkraftgeräts.", -- A_Space_Adventure:moon02
["He won't be selling us out anymore!"]="Er wird uns nicht mehr verraten!",
["Hey, don't forget us! We still need to climb up!"] = "He! Vergiss uns nicht! Wir müssen immer noch nach oben klettern!", -- A_Classic_Fairytale:family
["Hey guys!"]="Hey, Leute!",
["Hey, guys!"]="Hey, Leute!",
["Hey"]="Hey",
["Hey Hog Solo! Finally you have come..."]="Hey, Igel Einsam! Endlich bist du angekommen …",
["Hey! I was supposed to collect it!"] = "Hey! Eigentlich sollte ich die Kiste aufsammeln!", -- A_Space_Adventure:fruit02
["Hey, %s! Finally you have come!"] = "Hallo, %s! Endlich bist du gekommen!", -- A_Space_Adventure:moon01
["Hey, %s! Look, someone is stealing the saucer!"] = "He, %s! Pass auf, jemand stiehlt die fliegende Untertasse!", -- A_Space_Adventure:cosmos
["Hey! This is cheating!"]="Hey, das ist geschummelt!",
["H"]="H",
["Hidden"] = "Versteckt", -- portal
["High Gravity: Gravity is %i%%"] = "Hohe Schwerkraft: Schwerkraft ist auf %i%%", -- Gravity
["High Jump: [Backspace]"] = "Hochsprung: [Rücktaste]", -- Basic_Training_-_Movement
["High Jump: Tap the [Curvy Arrow] shortly"] = "Hochsprung: [Krummen Pfeil] kurz antippen", -- Basic_Training_-_Movement
["Highlander: Eliminate enemy hogs to take their weapons"] = "Hochländer: Eliminiere feindliche Igel, um ihre Waffen zu nehmen", -- Highlander
["Highlander: Eliminate hogs to take their weapons"] = "Hochländer: Eliminiere Igel, um ihre Waffen zu nehmen", -- Highlander
["Highland: Hogs get %d random weapons from their pool"] = "Hochland: Igel erhalten %d zufällige Waffen aus ihrem Waffenpool", -- Battalion
["--- Highland Mode ---"] = "--- Hochlandmodus ---", -- Battalion
["High Target"] = "Hohes Ziel", -- Basic_Training_-_Bazooka
["Hightime"]="Hoch hinaus",
["Hightower"] = "Hochturm", -- 
["Hill Guard"] = "Hügelwache", -- Bazooka_Battlefield
["Hi! Nice to meet you"]="Hi! Schön, dich zu sehen.",
["Hi! Nice to meet you."] = "Hi! Schön, dich zu sehen.", -- A_Space_Adventure:ice01
["Hint: Cinematics can be skipped with the [Precise] key."] = "Tipp: Zwischensequenzen können mit der [Genaues Zielen]-Taste übersprungen werden.", -- A_Classic_Fairytale:first_blood, A_Classic_Fairytale:shadow
["Hint: Drilling holes should solve everything."] = "Tipp: Löcher bohren sollte alle Probleme lösen.", -- A_Classic_Fairytale:family
["Hint: Hold down [M] to review the mission texts."] = "Tipp: Halte [M] gedrückt, um die Missionstexte erneut zu sehen.", -- A_Classic_Fairytale:first_blood
["Hint: It might be a good idea to place a girder before starting to drill. Just saying."] = "Tipp: Es könnte eine gute Idee sein, einen Träger zu platzieren,|bevor du mit dem Bohren anfängst. Ich sag ja nur.", -- A_Classic_Fairytale:family
["Hint: It might be easier if you vary the angle only slightly."] = "Tipp: Es könnte leichter sein, wenn du den Winkel nur leicht veränderst.", -- Basic_Training_-_Bazooka
["Hint: Just select the parachute, it opens automatically when you fall."] = "Tipp: Wähle einfach den Fallschirm aus, er öffnet sich von alleine, wenn du fällst.", -- A_Classic_Fairytale:first_blood
["Hint: Kills won't transfer a hog's pool to the killer's pool"] = "Tipp: Der Pool eines getöteten Igels wird nicht seinem Mörder übertragen", -- Battalion
["Hint: Launch the bazooka horizontally at full power."] = "Tipp: Starte die Bazooka horizontal mit voller Kraft.", -- Basic_Training_-_Bazooka
["Hint: Pause the game to review the mission texts."] = "Tipp: Pausiere das Spiel, um die Missionstexte erneut zu lesen.", -- A_Classic_Fairytale:first_blood
["Hint: Select the blow torch, aim and press [Fire]. Press [Fire] again to stop."] = "Tipp: Wähle den Schweißbrenner aus, ziele und drücke [Angriff]. Drücke [Angriff] erneut zum Anhalten.", -- A_Classic_Fairytale:journey
["Hint: Select the low gravity and press [Fire]."] = "Tipp: Wähle die niedrige Schwerkraft aus und drücke [Angriff].", -- A_Classic_Fairytale:journey
["Hint: Select the rope, [Up] or [Down] to aim, [Attack] to fire, directional keys to move."] = "Tipp: Wähle das Seil, [Hoch]/[Runter] zum Zielen,|[Angriff] zum Feuern, Richtungstasten zum Bewegen.", -- A_Classic_Fairytale:first_blood
["Hint: Select the Shoryuken and hit [Attack].|P.S.: You can use it mid-air."] = "Tipp: Wähle das Shoryuken und drücke [Angriff].|P.S.: Du kannst es in der Luft benutzen.", -- A_Classic_Fairytale:first_blood
["Hint: %s needs to get really close to the princess!"] = "Tipp: %s muss sehr nah an der Prinzessin stehen!", -- A_Classic_Fairytale:family
["Hint: The rope only bends around objects.|When it doesn't hit anything, it's always straight."] = "Tipp: Das Seil verbiegt sich nur um Objekte.|Wenn es nichts berührt, ist es immer schnurgerade.", -- Basic_Training_-_Rope
["--- Hint ---"] = "--- Tipp ---", -- Battalion
["Hint: To jump higher, wait a bit before you hit “High Jump” a second time."] = "Tipp: Um höher zu springen, warte etwas, bevor du »Hochsprung« erneut drückst.", -- Basic_Training_-_Movement
["Hint: To place a girder, select it,|then use [Left] and [Right] to select angle and length,|then choose a location for the girder."] = "Tipp: Um einen Träger zu platzieren, wähle ihn aus,|dann benutze [Links]/[Rechts], um Winkel und Länge zu wählen,|dann wähle einen Ort für den Träger.", -- A_Classic_Fairytale:shadow
["Hint: Use the quit key to see the team’s continent."] = "Tipp: Benutze die Verlassentaste, um den Kontinent des Teams zu sehen.", -- Continental_supplies
["Hint: When you shorten the rope, you move faster!|And when you lengthen it, you move slower."] = "Tipp: Wenn du das Seil verkürzt, bewegst du dich schneller!|Und wenn du es verlängerst, wirst du langsamer.", -- Basic_Training_-_Rope
["Hint: You might want to stay out of sight and take all the crates ..."] = "Tipp: Du solltest aus der Schusslinie bleiben und alle Kisten aufsammeln.", -- A_Classic_Fairytale:journey
["His arms are so strong!"]="Seine Arme sind so stark!",
["Hit the “Switch Hedgehog” key until you have|selected Cappy, the hedgehog with the cap!"] = "Drücke die »Igel wechseln«-Taste, bis du|Käppi ausgewählt hast, den Igel mit der Mütze!", -- Basic_Training_-_Movement
["Hmm … it's going slower than expected."] = "Hmm … das dauert länger, als ich erwartet habe.", -- A_Classic_Fairytale:queen
["Hmmm...actually...I didn't either."]="Hmmm, ich … eigentlich auch nicht.",
["Hmmm..."]="Hmmm …",
["Hmmm, I’ll have to find some way of moving him off this anti-portal surface."] = "Hmmm, ich muss herausfinden, wie ich ihn von dieser Anti-Portal-Oberfläche wegbekomme.", -- portal
["Hmmm...it's a draw. How unfortunate!"]="Hmmm … Es ist unentschieden. Wie blöd!",
["Hmmm...perhaps a little more time will help."]="Hmmm. Vielleicht wird etwas mehr Zeit helfen.",
["Hm... Now I ran out of fuel..."]="Hmm … Jetzt ist mein Treibstoff alle.",
["Hm ... Now I ran out of fuel."] = "Hmm … nun hab ich keinen Treibstoff mehr.", -- A_Space_Adventure:cosmos
["Hog 100"]="Igel 100",
["Hog 1"]="Igel 1",
["Hog 3x5"]="Igel 3x5",
["Hog 7+7"]="Igel 7+7",
["Hog decar"]="Igel decar",
["Hog dertien"]="Igel dertien",
["Hog D"]="Igel D",
["Hog %d"] = "Igel %d", -- SimpleMission
["Hog EOF"]="Igel EOF",
["Hogera is definitely the last planet I saved!"] = "Ich rette so bald keine Planeten mehr. Hogera reicht!", -- A_Space_Adventure:final
["Hogera is safe!"]="Hogera ist in Sicherheit!",
["Hog exi"]="Igel exi",
["Hog Hephaestus"]="Igel Hephaestus",
["Hog Identity Mode"]="Igelidentitätsmodus",
["HOG IDENTITY MODE"]="IGELIDENTITÄTSMODUS",
["Hog III"]="Igel III",
["Hogminator"]="Iglinator",
["Hog nueve"]="Igel nueve",
["Hog octo"]="Igel octo",
["Hog onze"]="Igel onze",
["Hog Saturn"]="Igel Saturn",
["Hogs in sight!"]="Igel in Sicht!",
["Hog Solo and GB"]="Igel Einsam und GB",
["Hog Solo arrived at "]="Igel Einsam ist angekommen an ",
["...Hog Solo fights for his life"]="… kämpft Igel Einsam ums Überleben.",
["... Hog Solo fights for his life"] = "… kämpft Igel Einsam ums Überleben.", -- A_Space_Adventure:death02
["Hog Solo"]="Igel Einsam",
["- Hogs will be revived"] = "- Igel werden wiederbelebt", -- Capture_the_Flag
["- Hogs will drop the flag when killed"] = "- Getötete Igel lassen die Flagge fallen", -- Capture_the_Flag
["Hog two"]="Igel zwei",
["Hold [Attack] to attach the rope."] = "Halte [Angriff], um das Seil zu befestigen.", -- Basic_Training_-_Rope
["Hold the Attack key pressed for more power."] = "Halte die Angriffstaste für mehr Kraft.", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["Holy shit!"] = "Ach du dicker Vater!", -- Mutant
["Honda"] = "Honda", -- 
["Honest Lee"]="Leo Ehrlich",
["Hooks"] = "Haken", -- 
["Hoorah!!!"]="Hurra!",
["Hooray! I actually did it! Hogera is safe!"] = "Hurra! Ich hab’s tatsächlich geschafft! Hogera ist in Sicherheit!", -- A_Space_Adventure:final
["Hooray! I've found it, now I have to get back to Captain Lime!"] = "Hurra! Ich hab’s gefunden! Nun muss ich zurück zu Leutnant Limone!", -- A_Space_Adventure:fruit02
["Hooray! You are a champion!"] = "Hurra! Du bist ein Champion!", -- A_Space_Adventure:ice02
["Hopeless case"]="Hoffnungsloser Fall",
["Hop on top of the next flower and advance to the left coast."] = "Spring auf die Spitze der nächsten Blume und rücke zur linken Küste vor.", -- A_Classic_Fairytale:journey
["Horns"] = "Hörner", -- 
["Hostage Situation"]="Geiselrettung",
["How can I ever repay you for saving my life?"]="Wie kann ich es jemals wieder gutmachen, dass du mein Leben gerettet hast?",
["How come in a village full of warriors, it's up to me to save it?"]="Wie kommt es, dass es immer an mir liegt, ein Dorf voller Krieger zu retten?",
["How could you betray us?"] = "Wie konntest du uns nur verraten?", -- A_Classic_Fairytale:queen
["How difficult would you like it to be?"]="Wie schwer möchtest du es haben?",
["HOW DO THEY KNOW WHERE WE ARE?"] = "WOHER WISSEN SIE, WO WIR SIND?", -- A_Classic_Fairytale:united
["However, if you fail to do so, she dies a most violent death, just like your friend! Muahahaha!"]="Aber wenn du versagst, wird sie den grausamsten Tod sterben, genau, wie dein Freund! Muhahahaha!",
["However, if you fail to do so, she dies a most violent death! Muahahaha!"]="Wenn du aber versagst, wird sie den grausamsten Tod sterben! Muhahahaha!",
["However, my mates don't agree with me on letting you go..."]="Aber meine Freunde wollen dich nicht gehen lassen …",
["However, the army of %s is about to attack any moment now."] = "Jedoch wird die Armee der %s jeden Moment angreifen.", -- A_Space_Adventure:fruit01
["How to Rope"] = "Verwendung des Seils", -- Basic_Training_-_Rope
["How would you like being discriminated against?"] = "Wie würde es sich anfühlen, wenn ihr die Diskriminierten wärt?", -- A_Classic_Fairytale:queen
["Huh?"] = "Hä?", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:queen
["Hunter"]="Jäger",
["I ain't gonna sit around no more!"] = "Jetzt werd ich nicht mehr herumsitzen!", -- A_Classic_Fairytale:queen
["I already said I'm sorry!"] = "Ich hab schon gesagt, dass es mir Leid tut!", -- A_Classic_Fairytale:epil
["I always suspected him!"] = "Ich hab ihn die ganze Zeit schon verdächtigt!", -- A_Classic_Fairytale:epil
["I am going to leave the kids play by themselves."] = "Ich werde die Kinder alleine spielen lassen.", -- A_Classic_Fairytale:queen
["I am not ready for this planet yet. I should visit it when I have found all the other device parts."]="Ich bin für diesen Planeten noch nicht bereit. Ich sollte ihn besuchen, sobald ich alle anderen Bauteile gefunden habe.", -- A_Space_Adventure:cosmos
["I am sorry but I was looking for a device that may be hidden somewhere around here."]="Tut mir Leid, aber ich suchte nach einem Gerät, das hier irgendwo versteckt sein könnte.", -- A_Space_Adventure:fruit02
["I believe there's more of them."]="Ich glaube, es gibt noch mehr von ihnen.",
["I cannot let you go any further! … burp …"] = "Ich kann euch nicht weitergehen lassen! … rülps …", -- A_Classic_Fairytale:queen
["I can see you have been training diligently."]="Ich sehe, dass du fleißig geübt hast.",
["I can't believe how blind we were."] = "Ich kann nicht glauben, wie blind wir gewesen sind.", -- A_Classic_Fairytale:epil
["I can't believe it worked!"]="Ich kann nicht glauben, dass es funktioniert hat!",
["I can't believe this!"]="Ich kann es nicht glauben!",
["I can't believe what I'm hearing!"]="Ich kann nicht glauben, was ich höre!",
["I can't let you go further because …"] = "Ich kann euch nicht weitergehen lassen, weil …", -- A_Classic_Fairytale:queen
["I can't wait any more, I have to save myself!"]="Ich kann nicht länger warten, ich muss selber zur Hilfe eilen!",
["Ice Jake"]="Eis-Jakob",
["I could just teleport myself there..."]="Ich könnte mich einfach dorthin teleportieren.",
["Icy Girder: [3]"] = "Eisiger Bauträger: [3]", -- HedgeEditor
["Icy Land: [3]"] = "Eisiges Gelände: [3]", -- HedgeEditor
["Icy Land"]="Eisiges Gelände",
["I'd better get going myself."]="Ich geh jetzt besser weiter.",
["Identity Thief"] = "Identitätsdieb", -- Mutant
["I didn't until about a month ago."]="Ich wusste es nicht vor einem Monat.",
["I don't care. It's worth a fortune! Good bye, you idiot!"] = "Mir egal. Sie ist ein Vermögen wert. Tschüss, du Narr!", -- A_Space_Adventure:fruit02
["I don't know if I can forget what you've done!"] = "Ich weiß nicht, ob ich vergessen kann, was du getan hast!", -- A_Classic_Fairytale:epil
["I don't know who I can trust anymore."] = "Ich weiß nicht mehr, wem ich vertrauen kann.", -- A_Classic_Fairytale:epil
["I don't like your tone! You're hurting me!"] = "Deine Ausdrucksweise gefällt mir nicht! Du verletzt mich!", -- A_Classic_Fairytale:queen
["I feel something...a place! They will arrive near the circles!"]="Ich spüre etwas … einen Ort! Sie werden in der Nähe der Kreise auftauchen!",
["If only I had a way..."]="Wenn ich nur wüsste, wie.",
["If only I were given a chance to explain my being here..."]="Wenn ich nur eine Gelegenheit hätte, um meine Anwesenheit zu erklären …",
["If only one enemy is left, you'll get bonus ammo."] = "Wenn es nur noch einen Gegner gibt, erhältst du neue Munition.", -- A_Space_Adventure:death02
["I forgot that she's the daughter of the chief, too..."]="Ich hab vergessen, dass sie auch die Tochter des Häuptlings ist.",
["I found it! Hooray!"] = "Ich hab's gefunden! Hurra!", -- A_Space_Adventure:desert01
["If some good old explosives were enough to save Hogera …"] = "Wenn ein paar einfache Sprengkörper gereicht haben, um Hogera zu retten, …", -- A_Space_Adventure:final
["If they try coming here, they can have a taste of my delicious knuckles!"]="Wenn sie versuchen, hierher zukommen, können sie von meinen köstlichen Fäusten kosten!",
["If you agree to provide the information we need, you will be spared!"]="Wenn du einverstanden bist, uns die Information, die wir brauchen, zu geben, wirst du verschont!",
["If you can get that crate fast enough, your beloved \"princess\" may go free."]="Wenn du diese Kiste schnell genug einsammelst, darfst du deine geliebte »Prinzessin« befreien.",
["If you decide to help us, though, we will no longer need to find a new governor for the island."]="Wenn du uns helfen willst, brauchen wir für diese Insel keinen neuen Anführer zu suchen.",
["If you don't want to slip away, you have to keep moving!"] = "Wenn du nicht wegrutschen willst, musst du in Bewegung bleiben!", -- Basic_Training_-_Movement
["If you get stuck, use your Desert Eagle or restart the mission!"] = "Wenn du hängenbleibst, benutze deine Desert Eagle|oder starte die Mission neu.", -- A_Classic_Fairytale:journey
["If you help us you can keep the device if you find it but we'll keep everything else."]="Wenn du uns hilfst, darfst du das Gerät behalten, wenn du es findest, aber wir werden alles andere behalten.", -- A_Space_Adventure:fruit02
["If you hurt an enemy, you'll get one third of the damage dealt."] = "Wenn du einen Feind verletzt, erhältst du ein Drittel des Schadens.", -- A_Space_Adventure:death02
["If you injure a hedgehog you'll get 35% of the damage dealt"]="Wenn du einen Igel verletzt, wirst du 35% des angerichteten Schadens erhalten", -- A_Space_Adventure:death02
["If you just don’t care …"] = "Wenn es dir völlig egal ist …", -- Continental_supplies
["If you kill a hedgehog with the respective weapon your health points will be set to 100"]="Wenn du einen Igel mit der entsprechenden Waffe tötest, wird deine Gesundheit auf 100 gesetzt", -- A_Space_Adventure:death02
["If you kill an enemy, your health will be set to 100."] = "Wenn du einen Gegner tötest, wird deine Gesundheit auf 100 gesetzt.", -- A_Space_Adventure:death02
["If you know what I mean..."]="Wenn du verstehst, was ich meine.",
["If you miss a shot while trying to|re-attach, your rope is gone, too!"] = "Wenn beim Versuch, ein Seil erneut zu befestigen,|ein Schuss danebengeht, ist dein Seil ebenfalls verloren!", -- Basic_Training_-_Rope
["If you say so..."]="Wenn du es sagst …",
["If you skip a turn then the turn time left will be added to your next turn."]="Wenn du einen Zug überspringst, wird die Zugzeit auf deinen nächsten Zug addiert.", -- A_Space_Adventure:fruit03
["If you skip the game your time left will be added to your next turn"]="Wenn du das Spiel überspringst, wird deine verbleibende Zeit für deinen nächsten Zug addiert.",
["If you wish to replay, there are other possible endings, too!"] = "Wenn du erneut spielen möchtest, gibt es auch andere Enden!", -- A_Classic_Fairytale:epil
["If you wish to restart the course, hold [Precise] while your turn ends (e.g with Skip)!|"]="Wenn du den Hindernislauf neustarten willst, drücke [Genaues Zielen], während dein Zug endet (z.B. mit Überspringen)!|",
["Igmund"] = "Igmund", -- User_Mission_-_Nobody_Laugh
["I grew sick of the oppression! I broke free!"] = "Ich hatte genug von der Unterdrückung! Ich bin ausgebrochen!", -- A_Classic_Fairytale:queen
["I guess I can't go far without fuel!"] = "Ich fürchte, ohne Treibstoff komme ich nicht weit!", -- A_Space_Adventure:cosmos
["I guess we lost him!"]="Ich glaube, wir haben ihn verloren!",
["I guess you'll have to kill them."]="Ich fürchte, du musst sie töten.",
["I have come to make you an offering..."]="Ich bin gekommen, um dir ein Angebot zu machen.",
["I have heard that the local tribes say that many years ago some PAotH scientists were dumping their waste here."]="Ich hörte, dass die örtlichen Stämme sagen, dass vor vielen Jahren einige PAdI-Wissenschaftler ihren Müll dort abgeliefert haben.", -- A_Space_Adventure:desert01
["I have more important things to do!"] = "Ich hab wichtigere Dinge zu erledigen!", -- A_Classic_Fairytale:queen
["I have no idea where that mole disappeared...Can you see it?"]="Ich habe keine Ahnung, wohin dieser Maulwurf verschwunden ist. Kannst du ihn sehen?",
["I have only 3 hogs available and they are all cadets."]="Ich habe nur 3 Igel, und sie sind alle Kadetten.", -- A_Space_Adventure:fruit01
["I have to follow that alien."]="Ich muss diesen Außerirdischen finden.",
["I have to get back to the village!"]="Ich muss ins Dorf zurückkehren!",
["I have to reach the surface as quickly as I can."]="Ich muss die Oberfläche so schnell wie möglich erreichen.", -- A_Space_Adventure:desert02
["I hope you are prepared for a small challenge, young one."]="Ich hoffe, du bist für eine kleine Herausforderung gewappnet, Jüngling.",
["I just don't want to sink to your level."]="Ich will nicht auf dein Niveau herabsinken.",
["I just forgot all checkpoints of incomplete missions."] = "Ich hab soeben alle Kontrollpunkte in meinen halbfertigen Missionen vergessen.", -- A_Space_Adventure:cosmos
["I just found out that they have captured your princess!"]="Ich habe gerade herausgefunden, dass sie deine Prinzessin gefangen haben!",
["I just want the strange device you found!"]="Ich will nur das seltsame Teil, das du gefunden hast.",
["I just wonder where Ramon and Spiky disappeared..."]="Ich frage mich lediglich, wohin Ramon und Stachli verschwunden sind.",
["I know and I'm terribly sorry!"] = "Ich weiß, und es tut mir schrecklich Leid!", -- A_Classic_Fairytale:epil
["I know, my hero!"] = "Ich weiß, mein Held!", -- A_Classic_Fairytale:epil
["I know that your resources are low due to the battle but I'll send two of my best hogs to assist you."]="Ich weiß, dass deine Ressourcen aufgrund der Schlacht begrenzt sind, aber ich werde dir zwei meiner besten Igel schicken, um dir zu helfen.",
["I … like being with you, too."] = "Ich … mag es auch, mit dir zusammen zu sein.", -- A_Classic_Fairytale:epil
["I'll get him!"]="Den schnapp ich mir!",
["I'll hold them off while you return to the village!"]="Ich halte sie zurück, während du zum Dorf zurückkehrst.",
["I'll let you know whatever I know about him if you manage to catch me 3 times."]="Ich lass dich wissen, was ich über ihn weiß, wenn du es schaffst, mich 3 mal zu fangen.", -- A_Space_Adventure:moon02
["I'll make good use of it."]="Ich werde es klug anwenden.", -- A_Space_Adventure:cosmos
["I'll protect you!"] = "Ich werde dich beschützen!", -- A_Classic_Fairytale:epil
["I love Dense Cloud now!"] = "Ich liebe jetzt Dichte Wolke!", -- A_Classic_Fairytale:epil
["I love you."] = "Ich liebe dich.", -- A_Classic_Fairytale:epil
["I'm afraid I can't let you proceed!"] = "Ich fürchte, ich kann euch nicht weitergehen lassen.", -- A_Classic_Fairytale:queen
["I'm afraid we cannot afford that."] = "Ich fürchte, wir können uns das nicht leisten.", -- A_Classic_Fairytale:queen
["Imagine those targets are the wolves that killed your parents! Take your anger out on them!"]="Stell dir vor, diese Zielscheiben sind die Wölfe, die eine Eltern getötet haben! Lass deine Wut an ihnen aus!",
["I'm...alive? How? Why?"]="Ich lebe? Wie? Warum?",
["I'm a ninja."]="Ich bin ein Ninja.",
["I marked the place of their arrival. You're welcome!"]="Ich habe ihren Ankunftsort markiert. Gern geschehen!",
["I may lost this battle, but I haven't lost the war yet!"]="Ich mag vielleicht diese Schlacht verloren haben, aber ich habe den Krieg noch nicht verloren!",
["I'm certain that this is a misunderstanding, fellow hedgehogs!"]="Ich bin mir sicher, dass das ein Missverständnis ist, liebe Igel.",
["I mean, none of you ceased to live."]="Ich meine, niemand von euch hat aufgehört, zu leben.",
["I'm getting old for this!"]="Ich werd zu alt dafür!",
["I'm getting thirsty..."]="Ich hab Durst.",
["I'm glad this is over!"] = "Ich bin froh, dass es vorbei ist!", -- A_Classic_Fairytale:epil
["I'm here to help you rescue her."]="Ich bin hier, um dir bei ihrer Rettung zu helfen.",
["I'm living a dream!"] = "Ich lebe einen Traum!", -- A_Classic_Fairytale:queen
["I'm not sure about that!"]="Ich bin mir darüber nicht so sicher.",
["IMPORTANT: To see the mission panel again, hold the mission panel key."] = "WICHTIG: Um die Missionstexte erneut zu sehen, halte die Missionsanzeigentaste.", -- Basic_Training_-_Movement
["IMPORTANT: To see the mission panel again, pause the game."] = "WICHTIG: Um die Missionstexte erneut zu sehen, pausiere das Spiel.", -- Basic_Training_-_Movement
["Impressive...you are still dry as the corpse of a hawk after a week in the desert..."]="Großartig! Du bist immer noch so trocken wie der Kadaver eines Adlers nach einer Woche in der Wüste.",
["%i ms"] = "%i ms", -- Gravity
["I'm so glad this is finally over!"] = "Ich bin so froh, dass es endlich vorbei ist!", -- A_Space_Adventure:final
["I'm so scared!"]="Ich hab solche Angst!",
["I'm still low on hogs. If you are not afraid I could use a set of extra hands."]="Ich habe immer noch wenige Igel. Wenn du keine Angst hast, könnte ich etwas Unterstützung gebrauchen.", -- A_Space_Adventure:fruit02
["I'm still with the aliens."] = "Ich bin immer noch auf der Seite der Außerirdischen.", -- A_Classic_Fairytale:queen
["I'm terribly sorry!"] = "Es tut mir fürchterlich Leid!", -- A_Classic_Fairytale:queen
["I'm the spy! I've been giving you out!"] = "Ich bin der Spion! Ich hab euch verraten!", -- A_Classic_Fairytale:queen
["In am also entrusting you with some rope"]="Ich werde dir auch etwas Seil anvertrauen.",
["In am also entrusting you with some rope."] = "Ich werde dir außerdem etwas Seil anvertrauen.", -- A_Space_Adventure:cosmos
["In case you haven't noticed, I'm a woman, too!"] = "Falls du es noch nicht bemerkt hast, ich bin auch eine Frau!", -- A_Classic_Fairytale:queen
["Increase the dust storm damage by sacrificing|your invulnerable ammo."] = "Erhöhe den Staubsturmschaden, indem|du deine Munition von Unverwundbarkeit opferst.", -- Continental_supplies
["Incredible..."]="Unglaublich.",
["Indestructible Girder: [2]"] = "Unzerstörbarer Bauträger: [2]", -- HedgeEditor
["Indestructible Land: [2]"] = "Unzerstörbares Land: [2]", -- HedgeEditor
["Indestructible Land"]="Unzerstörbares Gelände",
["In each round, the worst hedgehog of the round is eliminated."] = "In jeder Runde wird der schlechteste Igel der Runde eliminiert.", -- TrophyRace
["I need to find the others!"]="Ich muss die anderen finden!",
["I need to get to the other side of this island, fast!"]="Ich muss auf die andere Seite der Insel gelangen, und zwar schnell!",
["I need to move the tribe!"]="Ich muss den Stamm von hier fortführen.",
["I need to prevent their arrival!"]="Ich muss ihre Ankunft verhindern!",
["I need to warn the others."]="Ich muss die anderen warnen.",
["In fact, you are the only one that's been acting strangely."]="Tatsächlich bist du der Einzige, der sich seltsam benahm.",
["Initial health: %d"] = "Anfangsgesundheit: %d", -- Continental_supplies
["Initiate escape wish!"] = "Fluchtwunsch initiiert!", -- A_Classic_Fairytale:queen
["In order to get to the other side, you need to get rid of the crates first."] = "Um auf die andere Seite zu gelangen, musst du zuerst die Kisten los werden.", -- A_Classic_Fairytale:dragon
["Insanity!"] = "Wahnsinn!", -- Mutant
["Inside %d"] = "Innen %d", -- WxW
["Inside"] = "Innen", -- WxW
["Instructions"] = "Anleitung", -- Basic_Training_-_Flying_Saucer
["Instructor"]="Ausbilder",
["Insufficient Power"]="Unzureichende Energie",
["Interesting idea, haha!"]="Interessanter Gedanke, haha!",
["Interesting! Last time you said you killed a cannibal!"]="Interessant. Das letzte Mal sagtest du, dass du einen Kannibalen getötet hast.",
["In the meantime, take these and return to your \"friend\"!"]="In der Zwischenzeit, nimm diese und kehr zu deinem »Freund« zurück!",
["In the stadium, where the best pilots compete ..."] = "Im Stadion, wo sich die besten Piloten messen …", -- A_Space_Adventure:ice02
["In this accident, Professor Hogevil lost all his spines on his head!"]="Bei diesem Unfall hat Professor Bösigel all seine Stacheln auf seinem Kopf verloren!", -- A_Space_Adventure:moon02
["In this mission you get %d%% fuel."] = "In dieser Mission erhältst du %d%% Treibstoff.", -- User_Mission_-_Diver
["In this mission you have infinite time."] = "In dieser Mission hast du unendlich viel Zeit.", -- portal
["Invalid Placement"]="Ungültige Position",
["Invasion"]="Invasion",
["In your best (and only) flight you took out %d crates with one RC plane!"]="In deinem besten (und einzigem) Flug hast du %d Kisten mit einem Funkflugzeug zerstört!",
["In your best flight you took out %d crates with one RC plane."]="In deinem besten Flug hast du %d Kisten mit einem Funkflugzeug zerstört.",
["I of course will observe the battle and intervene if necessary"]="Ich werde natürlich die Schlacht beobachten und, wenn nötig, einschreiten.",
["I regret to end your little odyssey."] = "Ich bereue es, eure kleine Odyssee zu beenden.", -- A_Classic_Fairytale:queen
["I saw it with my own eyes!"]="Ich sah es mit meinen eigenen Augen!",
["I see..."]="Ich verstehe …",
["I see you already took care of your enemies."] = "Ich sehe, du hast dich bereits um deine Feinde gekümmert.", -- A_Classic_Fairytale:dragon
["I see you have already taken the leap of faith."]="Ich sehe, du hast bereits den Mutsprung absolviert.",
["I see you would like his punishment to be more...personal..."]="Ich sehe, du möchtest, dass seine Bestrafung etwas … persönlicher ausfällt.",
["I sense another wave of cannibals heading my way!"]="Ich nehme eine weitere Kannibalenwelle wahr, sie marschiert direkt auf mich zu!",
["I sense another wave of cannibals heading our way!"]="Ich nehme eine weitere Kannibalenwelle wahr, sie marschiert direkt auf uns zu!",
["I should get myself a portal device, maybe this crate has one."] = "Ich sollte mir ein Portalgerät holen, vielleicht hat diese Kiste ja eins.", -- portal
["I should go now, goodbye!"]="Ich sollte jetzt gehen. Tschüss!",
["I shouldn't have drunk that last pint."]="Ich sollte nicht die ganze Flasche ausgetrunken haben.",
["%i s"] = "%i s", -- Gravity
["Is this place in my head?"]="Ist dieser Ort in meinem Kopf?",
["I still can't believe he sold us out like that."] = "Ich kann immer noch nicht glauben, dass er uns so hintergangen hat.", -- A_Classic_Fairytale:epil
["I still can't believe you forgave her!"] = "Ich kann immer noch nicht glauben, dass du ihr vergeben hast!", -- A_Classic_Fairytale:epil
["I still have to collect the crates."] = "Ich muss immer noch die Kisten aufsammeln.", -- A_Classic_Fairytale:dragon
["I still have to get rid of the crates."] = "Ich muss immer noch die Kisten los werden.", -- A_Classic_Fairytale:dragon
["Itami"] = "Itami", -- 
["It doesn't matter. I won't let that alien hurt my daughter!"]="Es ist egal. Ich werde diesen Außerirdischen nicht meine Tochter weh tun lassen!",
["I think I love you!"] = "Ich denke, ich liebe dich!", -- A_Classic_Fairytale:epil
["I think we are safe here."]="Ich glaub, hier sind wir in Sicherheit.",
["I thought their shaman died when he tried our medicine!"]="Ich dachte, ihr Schamane starb, als er unsere Medizin probierte.",
["It is called 'Hogs of Steel'."]="Sie heißt »Igel aus Stahl«.",
["It is time to practice your fighting skills."]="Es ist Zeit, dein Kämpfen zu üben.",
["It must be a childhood trauma..."]="Es muss ein Kindheitstrauma sein.",
["It must be the aliens' deed."]="Das muss die Tat der Außerirdischen sein.",
["It must be the aliens!"]="Es müssen diese Außerirdischen sein!",
["It must be the cyborgs again!"]="Das müssen wohl wieder diese Cyborgs sein!",
["It needs some practice, but you have infinite lives."] = "Man braucht etwas Übung dafür, aber du hast unendlich viele Leben.", -- Basic_Training_-_Rope
["I told you, I just found them."]="Ich sag’s dir, ich habe sie gerade erst gefunden.",
["It only works in teleportation nodes of your own clan."] = "Dies funktioniert nur innerhalb Teleportations-|stationen deines eigenen Klans.", -- Construction_Mode
["It's a good thing SUDDEN DEATH is 99 turns away..."]="Gut, dass SUDDEN DEATH in 99 Runden ist …",
["It's all about the right carrots, you know."] = "Es kommt allein auf die richtigen Karotten an, weißt du?", -- A_Classic_Fairytale:epil
["It's always up to women to clear up the mess men created!"]="Es bleibt immer an Frauen hängen, das Chaos, das Männer hinterlassen haben, aufzuräumen!",
["It's amazing how quickly our lives can change."] = "Es ist erstaunlich, wie schnell sich unsere Leben ändern können.", -- A_Classic_Fairytale:epil
["It's an ancient ritual of theirs."] = "Das ist eines ihrer antiken Rituale.", -- A_Classic_Fairytale:queen
["IT'S A SERIOUS MEDICAL CONDITION!"] = "DAS IST EINE SEHR ERNSTE KRANKHEIT!", -- A_Classic_Fairytale:queen
["It's a shame, I forgot how to do that!"]="Zu dumm, ich habe vergessen, wie man das macht.",
["It's a shame, really!"] = "Das ist wirklich eine Schande!", -- A_Classic_Fairytale:queen
["It seems that Professor Hogevil has prepared for your arrival!"]="Es scheint, dass sich Professor Bösigel sich auf deine Ankunft vorbereitet hat!",
["It's empty!"] = "Leer!", -- Battalion
["It's impossible to communicate with the spirits without a shaman."]="Es ist unmöglich, ohne einen Schamanen mit den Geistern zu kommunizieren.",
["It's not that easy, so listen carefully:"] = "Ist nicht einfach, also pass auf:", -- Basic_Training_-_Flying_Saucer
["It's over..."]="Es ist vorbei.",
["It's precious to me!"] = "Es ist wertvoll für mich!", -- A_Classic_Fairytale:queen
["It's time you learned that your actions have consequences!"]="Es ist Zeit, dass du lernst, dass dein Handeln Konsequenzen haben wird!",
["It's worth more than wood!"]="Es ist wertvoller als Holz!",
["It's your fault you're there!"] = "Es ist deine Schuld, dass du dort bist!", -- A_Classic_Fairytale:epil
["It wants our brains!"]="Es will unsere Gehirne!",
["It was all a trick?!"] = "Es war alles ein Trick?", -- A_Classic_Fairytale:queen
["It was all just bad luck!"]="So ein Pech!",
["It was completely useless!"] = "Das war vollkommen nutzlos!", -- A_Space_Adventure:final
["It was fun to watch."] = "Es war lustig, zuzusehen.", -- A_Classic_Fairytale:queen
["It was fun to watch, though."] = "Aber es war lustig, zuzusehen.", -- A_Classic_Fairytale:queen
["It was not a dream, unwise one!"]="Es war kein Traum, du Tor!",
["It wasn't her fault!"] = "Es war nicht ihr Fehler!", -- A_Classic_Fairytale:epil
["It would be wiser to steal the space ship while the PAotH guards are taking a brake!"] = "Es wäre schlauer, das Raumschiff zu stehlen, während die PAdI-Wächter eine Pause machen!", -- A_Space_Adventure:cosmos
["Ivan"] = "Iwan", -- 
["I've made it! Yeah!"] = "Ich hab's geschafft! Hurra!", -- A_Space_Adventure:moon01
["I've seen this before. They just appear out of thin air."]="Ich hab das zuvor gesehen. Sie tauchen einfach aus dem Nichts auf.",
["I've thought that the best way to get the device is to let you collect most of the parts for me!"]="Ich dachte mir, dass es am einfachsten ist, wenn ich dich einfach die meisten Bauteile für mich sammeln lasse.",
["I want to play a game..."]="Ich möchte ein Spiel spielen.",
["I want to see how it handles this!"]="Ich will sehen, wie es damit klar kommt.",
["I was heading home, you see!"] = "Ich war auf dem Weg nach Hause, versteht ihr?", -- A_Classic_Fairytale:queen
["I was so scared."] = "Ich hatte solche Angst.", -- A_Classic_Fairytale:epil
["I was told that as the leader of the king's guard, no one knows this world better than you!"]="Mir wurde gesagt, dass, als der Führer der königlichen Garde, niemand diese Welt besser als du kennst!",
["I will never hand you the parts!"]="Niemals gebe ich dir die Teile!",
["I wish to help you, %s!"] = "Ich möchte dir helfen, %s!", -- A_Classic_Fairytale:dragon
["I wonder where Dense Cloud is..."]="Ich frag mich, wo Dichte Wolke ist.",
["I wonder why I'm so angry all the time..."]="Ich frag mich, warum ich die ganze Zeit so wütend bin.",
["I won't let you kill her!"]="Ich werde nicht zulassen, dass du sie umbringst!",
["I won't let you kill the tribe!"] = "Ich werde nicht zulassen, dass du den Stamm massakrierst!", -- A_Classic_Fairytale:queen
["I would gladly help you if we won this battle but under these circumstances I'll only help you if you fight for our side."]="Ich würde dir gerne helfen, wenn wir diese Schlacht gewinnen, aber unter diesen Bedingungen kann ich dir nur helfen, wenn du an unserer Seite kämpfst.",
["Jack"]="Jochen",
["Jason"] = "Jason", -- 
["Jeremiah"]="Jeremias",
["Jetpack"] = "Jetpack", -- Big_Armory
["Jigglypuff"] = "Pummeluff", -- 
["Jim Morgan"] = "Tim Morgen", -- 
["Jimmy"] = "Jimmy", -- 
["Jingo"] = "Dingo", -- 
["Joe"]="Sepp",
["John"]="Jonas",
["John Snow"]="Jonas Schnee",
["Jolly Roger"] = "Totenkopf", -- 
["Jones"] = "Jonas", -- 
["Judas"]="Judas",
["Juicy"] = "Saft", -- 
["Jumping is disabled"]="Sprünge sind deaktiviert!",
["Jumping"] = "Springen", -- Basic_Training_-_Movement
["Just kidding, none of you have died!"]="Nur ein Witz! Niemand von euch ist gestorben!",
["Just look at Leaks, may he rest in peace!"] = "Schau dir nur Undichte an, möge er in Frieden ruhen!", -- A_Classic_Fairytale:queen
["Just on a walk."]="Nur spazieren.",
["Just wait till I get my hands on that trauma! ARGH!"]="Warte nur, bis ich mein Trauma in die Finger kriege! ARGH!",
["Kaboom! Hahahaha! Take this, stupid meteorite!"] = "Krawumm! Hahahaha! Nimm das, blöder Meteorit!", -- A_Space_Adventure:final
["Kaboom!"] = "Kabumm!", -- Basic_Training_-_Flying_Saucer
["Kamikaze Expert! +15 points!"] = "Kamikazeexperte! +15 Punkte", -- Space_Invasion
["Keep it up!"]="Weiter so!",
["Ken"] = "Ken", -- 
["Kenshi"] = "Kenshi", -- 
["Kerguelen"]="Kerguelen",
["Kill all enemy hedgehogs in a single turn."] = "Töte alle gegnerischen Igel in einem Zug.", -- Big_Armory
["Kill him or skip your turn."] = "Töte ihn oder überspringe deinen Zug.", -- A_Classic_Fairytale:backstab
["Killing spree!"]="Blutrausch!",
["Killing the specialists"]="Die Spezialisten töten",
["KILL IT!"]="TÖTE ES!",
["Kills: %d"] = "Getötet: %d", -- Space_Invasion
["Kill the aliens!"]="Töte die Außerirdischen!",
["Kill the cannibal!"]="Töte den Kannibalen!",
["Kill The Leader"] = "Tötet Den Besten", -- WxW
["Kill The Leader: You must also hit the team with the most health."] = "Tötet Den Besten: Du musst zumindest das Team mit der höchsten Gesundheit treffen.", -- WxW
["Kill the traitor, %s, or spare his life!"] = "Töte den Verräter, %s, oder verschon sein Leben!", -- A_Classic_Fairytale:backstab
["King"]="König",
["--- King Mode ---"] = "--- Königsmodus ---", -- Battalion
["Knight"]="Ritter",
["Knives"] = "Messer", -- 
["Knockball"] = "Schlagball", -- Knockball
["Knockball weapon"] = "Schlagball-Waffe", -- Knockball
["Knock off the enemies from the left-most place of the map!"] = "Schubs die Feinde vom linken Kartenrand.", -- A_Space_Adventure:fruit01
["koda"] = "koda", -- 
["Kostya"] = "Kostya", -- 
["Lady Mango"]="Frau Mango",
["LandFlag Modification Mode"]="LandFlag-Modifikationsmodus",
["Land mines explode instantly."] = "Landminen explodieren sofort.", -- User_Mission_-_Teamwork_2
["Land Spray"]="Landkanone",
["Lassard"] = "Lampert", -- 
["Last Resort: Having less than 25% base health gives kamikaze"] = "Letzte Wahl: Igel mit unter 25% Grundgesundheit erhalten Kamikaze", -- Battalion
["Last Target!"]="Letzte Zielscheibe!",
["Launch a bouncy ball which explodes into a crate."] = "Feuere einen sprunghaften Ball, der zu einer Kiste wird.", -- Continental_supplies
["Launch some bazookas to destroy the targets!"] = "Feuere ein paar Bazookas ab, um die Zielscheiben zu zerstören!", -- Basic_Training_-_Bazooka
["Leaderbot"]="Führboter",
["Leader"]="Führer",
["Lead your allies to battle and eliminate all the enemies!"] = "Führ deine Verbündeten in die Schlacht und eliminiere alle Feinde!", -- A_Space_Adventure:fruit01
["Leaks A Lot, depressed for killing his loved one, failed to save the village..."]="Traurig darüber, sein Liebling getötet zu haben, versagte Undichte Stelle dabei, das Dorf zu retten.",
["Leaks A Lot gave his life for his tribe! He should have survived!"]="Undichte Stelle gab sein Leben für seinen Stamm! Er hätte überleben sollen!",
["Leaks A Lot must survive!"]="Undichte Stelle muss überleben!",
["Leaks A Lot"]="Undichte Stelle",
["Leap of Faith"] = "Mutsprung", -- Basic_Training_-_Movement
["Led Heart"]="Geführtes Herz",
["Lee"]="Leo",
["Left and right"] = "Links und rechts", -- WxW
["Left, right and roof"] = "Links, rechts und Decke", -- WxW
["[Left], [Right]: Change between identities."]="[Links], [Rechts]: Identitäten wechseln.",
["[Left], [Right]: Change between selection and placement mode."]="[Links], [Rechts]: Zwischen Auswahl- und Verlegungsmodus wechseln.",
["[Left], [Right]: Change between tagging modes."]="[Links], [Rechts]: Zwischen Markierungsmodi wechseln.",
["[Left], [Right]: Change health value."]="[Links], [Rechts]: Gesundheitswert auswählen",
["[Left], [Right]: Change sprite selection"]="[Links], [Rechts]: Sprite-Auswahl ändern",
["Left/right: Choose crate contents"] = "Links/rechts: Kisteninhalt wählen", -- Construction_Mode
["Left/right: Choose structure type"] = "Links/rechts: Gebäudetyp wählen", -- Construction_Mode
["Legs"] = "Beiner", -- 
["Less tools, more fun"] = "Weniger Werkzeuge, mehr Spaß", -- Battalion
["Lestat"] = "Lestat", -- portal
["Let a continent provide your weapons!"]="Lass einen Kontinent dich mit Waffen beliefern!",
["Let me test your skills a little, will you?"]="Lass mich deine Fertigkeiten ein wenig testen, okay?",
["Let's get started!"] = "Los geht’s!", -- Basic_Training_-_Bazooka
["Let's go home!"]="Lasst uns nach Hause gehen!",
["Let's go!"]="Los geht’s!",
["Let's go, %s!"] = "Los geht’s, %s!", -- WxW
["Let's head back to the village!"]="Lass uns zurück zum Dorf gehen!",
["Let's see what your comrade does now!"]="Sehen wir mal, was dein Kamerad jetzt anstellt.",
["Let's show those cannibals what we're made of!"]="Lass uns diesen Kannibalen zeigen, aus welchem Holz wir geschnitzt sind!",
["Let them have a taste of my fury!"]="Lasst sie von meinem Zorn kosten!",
["Let us help, too!"]="Lasst uns auch helfen!",
["Level 1 clear!"]="Level 1 abgeschlossen!",
["Level 2 clear!"]="Level 2 abgeschlossen!",
["Level Data Saved!"]="Leveldaten gesichert!",
["Lightbender"] = "Leuchte", -- 
["Light Cannfantry"]="Leichte Kannfanterie",
["Limited Ammo"] = "Begrenzte Munition", -- Basic_Training_-_Bazooka
["Listen carefully! The bandit leader, Thanta, has recently found a very strange device."]="Hör gut zu! Der Anführer der Banditen, Thanta, hat neulich ein sehr seltsames Gerät gefunden.", -- A_Space_Adventure:ice01
["Listen up, maggot!"] = "Aufgepasst, du Made!", -- User_Mission_-_Dangerous_Ducklings
["Little did they know that this hunt will mark them forever..."]="Sie ahnten nicht, dass diese Jagd sie für immer zusammenschweißen würde.",
["Little Obstacle Course"] = "Kleiner Hindernislauf", -- Basic_Training_-_Rope
["Lively Lifeguard"] = "Lebhafter Lebensretter", -- User_Mission_-_That_Sinking_Feeling
["Lonely Cries"] = "Einsame Heuler", -- Continental_supplies
["Long Jump: [Enter]"] = "Weitsprung: [Enter]", -- Basic_Training_-_Movement
["Long Jump: Tap the [Curvy Arrow] button for long"] = "Weitsprung: [Krummen Pfeil] lange drücken", -- Basic_Training_-_Movement, A_Classic_Fairytale:first_blood
["Long Live The Queen"] = "Lang lebe die Königin", -- A_Classic_Fairytale:queen
["Look around: [Mouse movement]"] = "Umsehen: [Mausbewegung]", -- Basic_Training_-_Movement
["Look around: [Tap or swipe on the screen]"] = "Umsehen: [Auf Bildschirm tippen oder wischen]", -- Basic_Training_-_Movement
["Look, boss! There is the target!"]="Sieh, Boss! Dort ist das Ziel!", -- A_Space_Adventure:moon01
["Look, I had no choice!"]="Versteh doch, ich hatte keine Wahl!",
["Look out! There's more of them!"]="Passt auf! Da sind noch mehr von ihnen!",
["Look out! We're surrounded by cannibals!"]="Passt auf! Wir sind von Kannibalen umzingelt!",
["Looks like the whole world is falling apart!"]="Es scheint, als würde die ganze Welt auseinanderfallen!",
["Look, someone is stealing the saucer!"]="Sieh, jemand stiehlt die Untertasse!",
["Look to the left and do a backwards jump towards the mushroom."] = "Blick nach links und mach einen Rückwärtssprung zum Pilz.", -- A_Classic_Fairytale:first_blood
["Loon"] = "Spinner", -- The_Specialists
["Loopy"] = "Gaga", -- 
["Losing Condition: Destroy"] = "Niederlagebedingung: Zerstören", -- HedgeEditor
["Low Gravity: Gravity is %i%%"] = "Niedrige Schwerkraft: Schwerkraft ist auf %i%%", -- Gravity
["Loyal Highlander: Eliminate enemy hogs to take their weapons"] = "Loyaler Hochländer: Eliminiere feindliche Igel, um ihre Waffen zu nehmen", -- Highlander
["Lt. Luke"] = "Lt. Lukas", -- 
["Lucifer"] = "Luzifer", -- portal
["Luck: %d%% (modifier for crates)"] = "Glück: %d%% (Modifikator für Kisten)", -- Battalion
["Luckily, I've managed to snatch some of them."]="Glücklicherweise konnte ich mir ein paar davon ergattern.",
["Ludicrous kill!"] = "Verrückter Killer!", -- Mutant
["Lugia"] = "Lugia", -- 
["Luigi"] = "Luigi", -- 
["Made it!"]="Geschafft!",
["Mahoney"] = "Maha", -- 
["Make fun of me when I fart …"] = "Macht euch über mich lustig, wenn ich furze …", -- A_Classic_Fairytale:queen
["Manual: https://hedgewars.org/hedgeeditor"] = "Anleitung (Englisch): https://hedgewars.org/hedgeeditor", -- HedgeEditor
["Many long forgotten things can be found in the same tunnels that we are about to explore!"]="Viele vergessene Dinge können in den selben Tunneln, die wir gleich erforschen werden, finden.",
["Many meters below the surface ..."]="Viele Meter unter der Oberfläche …", -- A_Space_Adventure:desert02
["Mario"] = "Mario", -- 
["Mark gears for win/lose conditions"] = "Markiere Gears für Sieg-/Niederlagebedingungen", -- HedgeEditor
["Mark/unmark gear: [Left Click]"] = "Gear markieren/demarkieren: [Linksklick]", -- HedgeEditor
["Max Citrus"]="Max Zitron",
["Maybe you should try an easier map next time."] = "Vielleicht solltet ihr beim nächsten Mal eine leichtere Karte ausprobieren.", -- Racer
["Maybe you should try an easier TechRacer map."] = "Vielleicht solltet ihr eine leichtere TechRacer-Karte ausprobieren.", -- TechRacer
["Maybe you should try easier waypoints next time."] = "Vielleicht solltet ihr beim nächsten Mal mit leichteren Wegpunkten spielen.", -- Racer
["May the spirits aid you in all your quests!"]="Mögen die Geister dich in all deinen Aufgaben begleiten!",
["Meals"] = "Mampf", -- 
["Medicine"] = "Medizin", -- Continental_supplies
["Medic"]="Sanitäter",
["Mega kill!"] = "Megakiller!", -- Mutant
["Meiwes"]="Meiwes",
["mikade"] = "mikade", -- 
["Mindy"]="Intellekta",
["Mine Deployer"]="Minenleger",
["Mine Placement Mode"]="Minenplatzierungsmodus",
["MINE PLACEMENT MODE"]="MINENPLATZIERUNGSMODUS",
["Mines explode after %d s."] = "Minen explodieren nach %d s.", -- Mutant
["Mines time: 0s-5s"] = "Minenzeitzünder: 0s-5s", -- SimpleMission
["Mines time: 0 seconds"] = "Minenzeitzünder: 0 Sekunden", -- portal, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork, User_Mission_-_The_Great_Escape, A_Space_Adventure:desert01, A_Space_Adventure:final, A_Space_Adventure:fruit02, A_Space_Adventure:ice01
["Mines time: 1.5 seconds"] = "Minenzeitzünder: 1,5 Sekunden", -- A_Space_Adventure:death01
["Mines time: %.1fs"] = "Minenzeitzünder: %.1fs", -- SimpleMission
["Mines time: 1 second"] = "Minenzeitzünder: 1 Sekunde", -- User_Mission_-_Diver, User_Mission_-_Newton_and_the_Hammock, A_Space_Adventure:desert02
["Mines time: %.2fs"] = "Minenzeitzünder: %.2fs", -- SimpleMission
["Mines time: 3 seconds"] = "Minenzeitzünder: 3 Sekunden", -- A_Classic_Fairytale:journey
["Mines time: 5 seconds"] = "Minenzeitzünder: 5 Sekunden", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:journey
["Mines time: %ds"] = "Minenzeitzünder: %ds", -- SimpleMission
["Minion"]="Lakai",
["Minions"]="Lakaien",
["Mission failed!"] = "Mission fehlgeschlagen!", -- portal, User_Mission_-_Bamboo_Thicket, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork_2, User_Mission_-_Teamwork, SimpleMission, HedgeEditor
["Mission"] = "Mission", -- HedgeEditor
["Mission Panel"] = "Missionsanzeige", -- Basic_Training_-_Movement
["Mission panel: [M]"] = "Missionsanzeige: [M]", -- Basic_Training_-_Movement
["Mission succeeded!"] = "Mission erfolgreich!", -- portal, User_Mission_-_Bamboo_Thicket, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork_2, User_Mission_-_Teamwork, SimpleMission, HedgeEditor
["Mister Pear"]="Herr Birne",
["Mixed %d"] = "Gemischt %d", -- WxW
["Mixed"] = "Gemischt", -- WxW
["Modes: Activate “highland”, “king” or “points” mode by putting mode=<name>|into the script parameter"] = "Modi: Aktiviere einen anderen Spielmodus, indem du|»highland«, »king« oder »points« als »mode=<name>«|in den Skriptparameter einträgst", -- Battalion
["Modifiers: Unlimited attacks, per-hog ammo"] = "Modifikatoren: Unbegrenzte Angriffe, Igelwaffen", -- Battalion
["Modifiers: Unlimited attacks, shared clan ammo"] = "Modifikatoren: Unbegrenzte Angriffe: Klanwaffen", -- Battalion
["Modify Sprite under Cursor: [Left Click]"] = "Sprite unter Cursor modifizieren: [Linksklick]", -- HedgeEditor
["Molly"] = "Molle", -- 
["Monster kill!"] = "Teuflisch!", -- Mutant
["Monsters"] = "Monster", -- 
["Mooney"] = "Finster", -- 
["Morris"] = "Moritz", -- 
["Most mines are not active."]="Die meisten Minen sind Blindgänger.", -- A_Space_Adventure:desert02
["Most of the destructible terrain is marked with dashed lines."] = "Der Großteil des zerstörbaren Landes ist mit gestrichelten Linien markiert.", -- A_Space_Adventure:desert01
["Most of the time you'll be able to use the freezer only."] = "Die meiste Zeit wirst du nur die Eiskanone benutzen können.", -- A_Space_Adventure:ice01
["Most of the time you'll be able to use the icegun only."] = "Die meiste Zeit wirst du nur die Eiskanone benutzen können.", -- A_Space_Adventure:ice01
["Movement: [Up], [Down], [Left], [Right]"]="Bewegen: [Hoch], [Runter], [Links], [Rechts]",
["Mr Mango"]="Mister Mango",
["Mudkip"] = "Hydropi", -- 
["Multi-shot! +15 points!"] = "Multischuss! +15 Punkte!", -- Space_Invasion
["Multi-Use: You can take and use the same ammo type multiple times in a turn"] = "Mehrfachverwendung: Du kannst den gleichen Munitionstyp im selben Zug|mehrmals aufsammeln und verwenden", -- Highlander
["Muriel"]="Muriel",
["Muscle Dissolver"]="Muskellöser",
["Mushroom Kingdom"] = "Pilzkönigreich", -- 
["Mutant"]="Mutant",
["My First Bazooka"] = "Meine erste Bazooka", -- Basic_Training_-_Bazooka
["My flying saucer stopped working!"] = "Meine fliegende Untertasse funktioniert nicht mehr!", -- A_Space_Adventure:ice01
["Nah, probably everyone was just stupid."] = "Ach was, wahrscheinlich waren alle nur doof.", -- A_Space_Adventure:final
["Name"]="Name",
["Nancy Screw"]="Lockere Schraube",
["Napalm Rocket"] = "Napalmrakete", -- Continental_supplies
["Naranja Jed"]="Orangus Otus",
["Naughty Ninja"]="Böser Ninja",
["Near a PAotH base on the moon ..."] = "In der Nähe einer PAdI-Basis auf dem Mond …", -- A_Space_Adventure:moon01
["Near Secret Base 17 of PAotH in the rural Hogland ..."]="In der Nähe der Geheimbasis 17 der PAdI im ländlichen Igelland …", -- A_Space_Adventure:cosmos
["nemo"] = "nemo", -- 
["Neutralize your enemies and be careful!"]="Neutralisiere deine Gegner und sei vorsichtig!",
["New barrels per turn: %d"] = "Neue Fässer pro Zug: %d", -- Tumbler
["New clan record: %.1fs"] = "Neuer Klanrekord: %.1fs", -- Racer, TechRacer
["New mines per turn: %d"] = "Neue Minen pro Zug: %d", -- Tumbler
["New race record: %.1fs"] = "Neuer Rennrekord: %.1fs", -- Racer, TechRacer
["Newton and the Hammock"] = "Newton und die Hängematte", -- User_Mission_-_Newton_and_the_Hammock
["Next target is ready!"] = "Das nächste Ziel ist bereit!", -- Basic_Training_-_Flying_Saucer
["Next time you play \"Searching in the dust\" you'll have an RC plane available."]="Das nächste Mal, wenn du die Mission »Suche im Staub« spielst, bekommst du ein Funkflugzeug.",
["Nicely done, meatbags!"]="Gut gemacht, Fleischkugeln!",
["Nice!"]="Nett!",
["Nice! Now hurry and get down! You have to rescue my friends!"]="Nett! Nun beeil dich und komm runter! Du musst meine Freunde retten!",
["Nice, then I should get the part as soon as possible!"]="Interessant, dann sollte ich besser das Teil so früh wie möglich holen!",
["Nice work!"]="Gute Arbeit!",
["Nice work, meatbags!"] = "Gute Arbeit, Fleischklumpen!", -- A_Classic_Fairytale:queen
["Nice work, %s!"] = "Gute Arbeit, %s!", -- A_Classic_Fairytale:dragon
["Nilarian"]="Nilarian",
["Ninja"]="Ninja",
["Ninpo"] = "Ninpo", -- 
["Nobody Laugh"]="Niemand darf lachen",
["Nobody managed to finish the race. What a shame!"] = "Niemand hat es geschafft, das Rennen abzuschließen. Welch ein Jammer!", -- Racer, TechRacer
["Nobody takes walks every day!"] = "Niemand geht den ganzen Tag lang spazieren!", -- A_Classic_Fairytale:epil
["No continent selected"] = "Kein Kontinent ausgewählt", -- Continental_supplies
["No, I am afraid I had to travel light."]="Nein, ich fürchte, dass ich mit wenig Gepäck reisen musste.", -- A_Space_Adventure:moon01
["No, I came back to help you out..."]="Nein, ich kam zurück, um dir zu helfen.",
["No...I wonder where they disappeared?!"]="Nein. Ich frage mich, wohin sie verschwunden sind?!",
["NomNom"]="Mjamjam",
["Nom-Nom"]="Mjam-Mjam",
["No Multi-Use: Once you used an ammo, you can’t take it again in this turn"] = "Keine Mehrfachverwendung: Sobald du einen Munitionstyp benutzt hast, kannst|du ihn im selben Zug nicht erneut aufsammeln", -- Highlander
["Noooo, Thanta has to stay alive!"]="Nein, Thanta muss am Leben bleiben!",
["Noo, Thanta has to stay alive!"] = "Nein, Thanta muss am Leben bleiben!", -- A_Space_Adventure:ice01
["Nope. It was one fast mole, that's for sure."]="Nee. Es war ein schneller Maulwurf, das ist klar.",
["No! Please, help me!"]="Nein! Bitte hilf mir!",
["No problem, Captain!"] = "Kein Problem, Leutnant!", -- A_Space_Adventure:fruit01
["No problem, I would do anything for H!"]="Kein Problem, ich würde alles für H tun!",
["No radar pings left!"] = "Keine Radarpings übrig!", -- Space_Invasion
["Normal Girder: [1]"] = "Normaler Bauträger: [1]", -- HedgeEditor
["Normal Land: [1]"] = "Normales Gelände: [1]", -- HedgeEditor
["Normal Land"]="Normales Gelände",
["Normally, the mission panel disappears after a few seconds."] = "Normalerweise verschwindet die Missionsanzeige nach ein paar Sekunden.", -- Basic_Training_-_Movement
["Normal Rubber: [1]"] = "Normales Gummi: [1]", -- HedgeEditor
["Normal Sticky Mine"]="Normale Haftmine",
["North America"]="Nordamerika",
["Not being able to fight or hunt."] = "Nicht in der Lage, zu kämpfen oder zu jagen.", -- A_Classic_Fairytale:queen
["Note: This basic training assumes default controls."] = "Beachte: Diese Übung geht von der Standardsteuerung aus.", -- Basic_Training_-_Movement
["Note: Walking is disabled in this mission."] = "Beachte: Gehen ist in dieser Mission deaktiviert.", -- Basic_Training_-_Grenade
["Note: We only give you grenades if you stay in your flying saucer."] = "Beachte: Wir geben dir nur Granaten, wenn du in der|fliegenden Untertasse bleibst.", -- Basic_Training_-_Flying_Saucer
["Nothing of interest has happened."] = "Es ist nichts nennenswertes passiert.", -- Space_Invasion
["Not now, Fiery Water!"]="Nicht jetzt, Feuerwasser!",
["Not So Friendly Match"]="Kein-so-Freundschaftsspiel",
["Not you again! My head still hurts from last time!"]="Nicht du schon wieder! Mein Kopf tut mir immer noch vom letzten Mal weh!",
["No waypoint to be removed!"] = "Es gibt keine Wegpunkte zum Entfernen!", -- Racer
["Now collect the 2 crates to the far left and right."] = "Nun sammle die 2 Kisten weit links und rechts auf.", -- Basic_Training_-_Flying_Saucer
["Now collect the next crate!"] = "Und jetzt sammle die nächste Kiste ein!", -- Basic_Training_-_Flying_Saucer
["Now dive just one more time and collect the next crate."] = "Jetzt tauch noch einmal ab und sammle die nächste Kiste ein.", -- 
["No, we made sure of that!"]="Nein, wir hatten extra aufgepasst.",
["Now for the supreme discipline of saucer flying, the underwater attack."] = "Jetzt kommt die ultimative Disziplin der fliegenden Untertasse, der Unterwasserangriff.", -- Basic_Training_-_Flying_Saucer
["Now go and don't waste more of my time, you coward!"] = "Jetzt geh, und vergeude meine Zeit nicht noch weiter, du Feigling!", -- A_Space_Adventure:fruit01
["Now go and play the menu mission to complete the campaign."] = "Geh jetzt und spiele die Menümission, um die Kampagne zu beenden.", -- A_Space_Adventure:death01
["Now go to the next crate."] = "Jetzt geh zur nächsten Kiste.", -- Basic_Training_-_Movement
["No! What have I done?! What have YOU done?!"]="Nein! Was habe ich getan?! Was hast DU getan?!",
["No. Where did he come from?"]="Nein. Woher kam er?",
["Now how do I get on the other side?!"]="Aber wie komme ich auf die andere Seite?!",
["Now I have to climb these trees"]="Jetzt muss ich diese Bäume hochklettern.",
["No Wind Influence"] = "Kein Einfluss vom Wind", -- Basic_Training_-_Grenade
["Now let's try to drop weapons while flying!"] = "Jetzt versuch mal, Waffen während des Flugs abzuwerfen!", -- Basic_Training_-_Flying_Saucer
["Now listen carefully! Below us there are tunnels that have been created naturally over the years"]="Jetzt hör gut zu! Unter uns sind Tunnel, welche über die Jahre natürlich entstanden sind.",
["Now try to get out of this bounce house|and take the next crate."] = "Jetzt versuch, aus dieser Hüpfburg zu fliehen|und hol dir die nächste Kiste.", -- Basic_Training_-_Movement
["Now use it and go to the moon PAotH station to get more fuel!"]="Benutze sie jetzt und komme zur PAdI-Mondbasis, um mehr Treibstoff zu holen!",
["Now you have the chance to try and claim the place that you deserve among the best."]="Jetzt hast du die Gelegenheit, es selbst zu versuchen, und dir einen Rang unter den Besten zu verdienen.", -- A_Space_Adventure:ice02
["No. You and the rest of the tribe are safer there!"]="Nein. Du und der Rest deines Stammes sind hier sicherer!",
["Objective completed! Now land safely."] = "Aufgabe erledigt! Lande jetzt vorsichtig.", -- Basic_Training_-_Flying_Saucer
["Objectives"]="Ziele",
["Object Placer"] = "Objektplatzierer", -- Construction_Mode
["Obliterate them!|Hint: You might want to take cover..."]="Vernichte sie!|Tipp: Du solltest in Deckung gehen.",
["Obstacle course"]="Hindernisstrecke",
["Obstacle"] = "Hindernis", -- Basic_Training_-_Rope
["Of course, but you're … special."] = "Natürlich, aber du bist … besonders.", -- A_Classic_Fairytale:epil
["Of course I am!"] = "Natürlich bin ich das!", -- A_Classic_Fairytale:queen
["Of course I have to save her. What did I expect?!"]="Natürlich muss ich sie retten. Was habe ich erwartet?",
["Of course! It's all obvious now!"] = "Natürlich! Jetzt ergibt alles einen Sinn!", -- A_Classic_Fairytale:epil
["Of course, I will observe the battle and intervene if necessary."] = "Natürlich werde ich dem Kampf zusehen und eingreifen, falls es nötig sein sollte.", -- A_Space_Adventure:fruit01
["OH, COME ON!"]="ACH, KOMM!",
["Oh man! Learn how to fly!"]="Oh, Mann! Lern erstmal fliegen!",
["Oh, my! I forgot something!"] = "Oha! Ich habe etwas vergessen!", -- A_Classic_Fairytale:queen
["Oh, my!"]="Ohje!",
["Oh, my! This is even more entertaining than I've expected!"]="Haha! Das ist sogar noch lustiger, als ich erwartet hatte!",
["Oh no, not %s!"] = "Oh nein, nicht %s!", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
["Oh no, the companions have betrayed %s and stole the anti-gravity device part!"] = "Oh nein, die Begleiter haben %s betrogen und das Antischwerkraftgerät gestohlen!", -- A_Space_Adventure:fruit02
["Oh no! You have died. Try again!"] = "Oh nein, du bist tot. Versuch es nochmal!", -- Basic_Training_-_Flying_Saucer
["Oh! Please spare me. You can take all my treasures!"]="Oh, bitte verschone mich! Du kannst all meine Schätze nehmen.",
["Oh, silly me! I forgot that I'm the shaman."]="Ach, ich Dummkopf! Ich hab vergessen, dass ich der Schamane bin.",
["Oh, that. We were just having fun!"] = "Oh, das. Wir hatten nur Spaß!", -- A_Classic_Fairytale:queen
["Oh yeah! You sure know how to rope!"] = "Jawoll! Jetzt weißt du, wie man das Seil richtig benutzt!", -- Basic_Training_-_Rope
["Oh yes! I got the device part! Now it belongs to me alone."] = "Jawoll! Ich hab das Geräteteil! Nun gehört es mir ganz allein.", -- A_Space_Adventure:fruit02
["Okay, I'll be extra careful!"] = "In Ordnung, ich werde besonders vorsichtig sein!", -- A_Space_Adventure:desert01
["Okay, now destroy the target|using the baseball bat."] = "Okay, nun zerstöre die Zielscheibe|mit dem Baseballschläger.", -- Basic_Training_-_Rope
["Okay then!"] = "Okay!", -- A_Space_Adventure:fruit02
["Okay, then you have to go and take some of the weapons we have hidden in case of an emergency!"] = "Okay, dann musst du gehen und ein paar der Waffen, die wir für Notfälle versteckt haben, nehmen.", -- A_Space_Adventure:moon01
["OK, I'll be extra careful!"]="Okay, ich werde besonders vorsichtig sein!",
["Ok then!"]="Alles klar!",
["Ok, then you have to go and take some of the weapons we have hidden in case of an emergency!"]="Okay, dann musst du gehen und ein paar der Waffen, die wir für den Notfall versteckt haben, nehmen.",
["Old One Eye"] = "Alter Einaug", -- 
["Oleg"] = "Oleg", -- 
["Olive"]="Olive",
["Omnivore"]="Allesfresser",
["Once upon a time, on an island with great natural resources, lived two tribes in heated conflict..."]="Es waren einmal zwei Stämme, die lebten auf einer Insel mit vielen natürlichen Rohstoffen und waren in einem bitteren Konflikt …",
["Once you set off the proximity trigger, Mr. Mine is not your friend"] = "Sobald du den Auslöser betätigst, ist Herr Mine nicht mehr dein Freund.", -- ClimbHome
["One does not simply rope to the moon!"] = "Niemand schwingt sich einfach so mit dem Seil zum Mond hinauf!", -- A_Space_Adventure:cosmos
["One flower: Incomplete side missions"] = "Eine Blume: Unfertige Nebenmissionen", -- A_Space_Adventure:cosmos
["One shall not judge one by one's appearance!"] = "Man sollte Andere nicht nach ihrem Aussehen beurteilen.", -- A_Classic_Fairytale:epil
["One tribe was peaceful, spending their time hunting and training, enjoying the small pleasures of life..."]="Ein Stamm war friedlich und verbrachte die Zeit mit der Jagd, Übungen und den kleinen Freuden des Lebens.",
["Oneye"] = "Einauge", -- portal
["Only one hog per team allowed! Excess hogs will be removed."] = "Nur ein Igel pro Team erlaubt! Überschüssige Igel werden entfernt.", -- Mutant
["Only %s can be trusted with the crate."] = "Die Kiste kann nur %s anvertraut werden.", -- A_Space_Adventure:fruit02
["Only the best pilots can master the following stunts."] = "Nur die besten Piloten können die folgenden Stunts meistern.", -- Basic_Training_-_Flying_Saucer
["Only two clans allowed! Excess hedgehogs will be removed."] = "Nur zwei Klans erlaubt! Überschüssige Igel werden entfernt.", -- CTF_Blizzard
["On the Desert Planet, Hog Solo found some time to play with his RC plane"] = "Auf dem Wüstenplaneten hat Igel Einsam etwas Zeit gefunden, um mit seinem Funkflugzeug zu spielen.", -- A_Space_Adventure:desert03
["On the Ice Planet, where ice rules ..."]="Auf dem Eisplaneten, wo das Eis herrscht …", -- A_Space_Adventure:ice01
["On the other side of the moon ..."]="Auf der anderen Seite des Mondes …", -- A_Space_Adventure:moon02
["On the Planet of Sand, you have to double check your moves ..."] = "Auf dem Planeten des Sandes musst du deine Züge doppelt überdenken …", -- A_Space_Adventure:desert01
["On this map you get %d%% fuel."] = "Auf dieser Karte erhältst du %d%% Treibstoff.", -- TechRacer
["On this map you get infinite fuel."] = "Auf dieser Karte erhältst du unbegrenzten Treibstoff.", -- TechRacer
["Oops...I dropped them."]="Upps, ich habe sie fallen gelassen.",
["Oops, I've been spotted and I have no weapons! I am doomed!"]="Upps! Ich wurde entdeckt und ich habe keine Waffen! Ich bin verloren!",
["Oops! You have selected the wrong hedgehog! Just try again."] = "Upps! Du hast den falschen Igel ausgewählt! Versuch es einfach erneut.", -- Basic_Training_-_Movement
["Open ammo menu: [Right click]"] = "Munitionsmenü öffnen: [Rechtsklick]", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
["Open ammo menu: Tap the [Suitcase]"] = "Munitionsmenü öffnen: [Koffer] antippen", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
["Open that crate and we will continue!"]="Öffne diese Kiste und wir werden fortfahren!",
["Orange"] = "Orange", -- 
["Orlando Boom!"]="Orlando Bumm!",
["Or let the next player place waypoints|if less than 2 waypoints have been placed."] = "Oder lass den nächsten Spieler Wegpunkte platzieren,|wenn weniger als 2 Wegpunkte platziert worden sind.", -- Racer
["Or maybe this was all part of an evil plan, so evil that even Prof. Hogevil can't think of it!"] = "Oder vielleicht war all das ein böser Plan, so böse, dass selbst Prof. Bösigel nicht drauf gekommen wäre.", -- A_Space_Adventure:final
["Oscillating Gravity: Gravity periodically changes within a range from %i%% to %i%% with a period of %s"] = "Oszillierende Schwerkraft: Schwerkraft ändert sich periodisch von %i%% bis %i%% mit einer Periode von %s", -- Gravity
["Ouch! That must have hurt. %s (%s) hit the ground with %d damage points."]="Autsch! Das muss wehgetan haben. %s (%s) ist mit %d auf den Boden aufgeschlagen.",
["Ouch! That must have hurt. You mutilated your poor hedgehog hog with %d damage."]="Autsch! Das muss wehgetan haben. Du hast deinen armen Igel mit %d Schaden verstümmelt.",
["Ouch! You just took fall damage."] = "Autsch! Du hast Fallschaden genommen.", -- Basic_Training_-_Movement
["Our tribe, our beautiful island!"]="Unser Stamm, unsere schöne Insel!",
["Out of ammo!"] = "Munition ist alle!", -- Tumbler
["Out of ammo! Try again!"] = "Munition ist alle! Versuch’s noch mal!", -- Basic_Training_-_Bazooka
["Over the Water"] = "Über dem Wasser", -- Basic_Training_-_Rope
["PAotH has sent explosives but unfortunately the trigger mechanism seems to be faulty!"]="PAdI hat Sprengstoffe geschickt, aber leider scheint der Auslöser defekt zu sein.",
["PAotH"]="PAdI",
["Patches"] = "Flick", -- 
["Paul McHoggy"]="Paul McIgel",
["Pause: [P]"] = "Pause: [P]", -- Basic_Training_-_Movement
["Pause: Tap the [Pause] button"] = "Pause: [Pause]-Taste antippen", -- Basic_Training_-_Movement
["Pause the game by pressing the pause key (default \"P\") for more details"]="Pausiere das Spiel, indem du die Pausetaste (standardmäßig »P«) drückst, um mehr zu erfahren.",
["Penalty: If you violate above rule, you have to skip in the next turn."] = "Strafe: Wenn du obige Regel verletzt, musst du den nächsten Zug aussetzen.", -- WxW
["Penguin Roar"] = "Pinguinröhren", -- Continental_supplies
["Perfect! Now try to get the next crate without hurting yourself!"]="Perfekt! Jetzt versuch, zur nächsten Kiste zu gelangen, ohne dich zu verletzen!",
["Per-hog Ammo: Weapons are not shared between hogs"] = "Igelwaffen: Igel teilen sich Waffen nicht untereinander", -- User_Mission_-_Nobody_Laugh
["Personal best: %.3f seconds"] = "Persönliche Bestzeit: %.3f Sekunden", -- A_Space_Adventure:ice02
["Pfew! That was close!"]="Puh! Das war knapp!",
["Phosphat"] = "Phosphat", -- portal
["Physicist"]="Physiker",
["PickHammer"]="Presslufthammer",
["Pikachu"] = "Pikachu", -- 
["Pings left: %d"] = "Verbleibende Pings: %d", -- Space_Invasion
["Pink"] = "Rosa", -- 
["Pirates"] = "Piraten", -- 
["Place 2-%d waypoints using the waypoint placement tool."] = "Platziere 2-%d Wegpunkte mit dem Wegpunktplatzierungswerkzeug.", -- Racer
["Place 2 waypoints using the waypoint placement tool."] = "Platziere 2 Wegpunkte mit dem Wegpunktplatzierungswerkzeug.", -- Racer
["Place air mines"] = "Platziere Luftminen", -- HedgeEditor
["Place barrels"] = "Platziere Pulverfässer", -- HedgeEditor
["Place cleavers"] = "Platziere Hackebeile", -- HedgeEditor
["Place/Delete Waypoint: [Left Click]"] = "Wegpunkt platzieren/löschen: [Linksklick]", -- HedgeEditor
["Place dud mines"] = "Platizere Blindgängerminen", -- HedgeEditor
["Place Gear: Air Attack"]="Gear platzieren: Luftangriff",
["Place Gears (and more): Gear Placement Tool"] = "Gears (und mehr) platzieren: Gear-Platzierungswerkzeug", -- HedgeEditor
["Place Girder: Girder"]="Bauträger platzieren: Bauträger",
["Place Girder: [Left Click]"]="Bauträger platzieren: [Linksklick]",
["Place girders"] = "Platziere Bauträger", -- HedgeEditor
["Place health crates"] = "Platziere Gesundheitskisten", -- HedgeEditor
["Place hedgehogs: Place your hedgehogs at the start of the game."] = "Igel platzieren: Platziere deine Igel zu Spielbeginn.", -- WxW
["Placement Mode"]="Platzierungsmodus",
["Place mines"] = "Platziere Minen", -- HedgeEditor
["Place, modify and delete gears (e.g. objects)|and waypoints, edit hedgehog settings, values,|victory conditions, and more."] = "Platziere, ändere und lösche Gears (z.B. Objekte)|und Wegpunkte, ändere Igeleinstellungen, Werte,|Siegbedingungen und mehr.", -- HedgeEditor
["Place Object: [Left Click]"]="Objekt platzieren: [Linksklick]",
["Place or delete waypoints"] = "Platziere oder lösche Wegpunkte", -- HedgeEditor
["Place rubber"] = "Platziere Gummis", -- HedgeEditor
["Place Rubber: Rubber"]="Gummi platzieren: Gummi",
["Place Sprite: [Left Click]"] = "Sprite platzieren: [Linksklick]", -- HedgeEditor
["Place sprites to build land"] = "Platziere Sprites, um Land zu bauen", -- HedgeEditor
["Place sticky mines"] = "Platziere Haftminen", -- HedgeEditor
["Place targets"] = "Platziere Zielscheiben", -- HedgeEditor
["Place utility crates"] = "Platziere Werkzeugkisten", -- HedgeEditor
["Place Waypoint: [Left Click]"]="Wegpunkt platzieren: [Linksklick]",
["Place Waypoint"] = "Wegpunkt platzieren", -- HedgeEditor
["Place waypoint"] = "Wegpunkt platzieren", -- Racer
["Place weapon crates"] = "Platziere Waffenkisten", -- HedgeEditor
["- Place your clan flag at the end of your first turn"] = "- Platziere deine Klanflagge am Ende deines ersten Zuges", -- Capture_the_Flag
["Planes used: %d"]="Verwendete Flugzeuge: %d",
["Planets with all missions completed will be marked with two flowers."] = "Planeten, bei denen alle Missionen erledigt wurden, werden mit zwei Blumen markiert.", -- A_Space_Adventure:cosmos
["Planets with completed main missions will be marked with a flower."]="Planeten, bei denen die Hauptmissionen erledigt wurden, werden mit einer Blume markiert.", -- A_Space_Adventure:cosmos
["Play with me!"]="Spiel mit mir!",
["Please click on a crate."]="Bitte klick auf eine Kiste.",
["Please click on a gear."] = "Bitte klicke ein Gear an.", -- HedgeEditor
["Please click on a hedgehog, barrel, health crate or dud mine."] = "Bitte klicke auf einen Igel, einem Fass, einer Gesundheitskiste oder Blindgängermine.", -- HedgeEditor
["Please click on a hedgehog."]="Bitte klick auf einen Igel.",
["Please place the waypoint further away from the waterline"] = "Bitte platziere den Wegpunkt weiter weg von der Wasseroberfläche", -- Racer, TechRacer
["Please place the waypoint in the air and within the map boundaries"] = "Bitte platziere den Wegpunkt in der Luft und innerhalb der Kartengrenzen", -- TechRacer
["Please place the waypoint in the air, within the map boundaries"] = "Bitte platziere den Wegpunkt in der Luft und innerhalb der Kartengrenzen", -- Racer
["Please place your hedgehog first!"] = "Bitte platziere zuerst deinen Igel!", -- WxW
["Please, stop releasing your \"smoke signals\"!"]="Bitte hör mit deinen »Rauchzeichen« auf!",
["Please wait …"] = "Bitte warten …", -- WxW
["Point Blank Combo! +5 points!"] = "Ganz-Schön-Dicht-Dran-Kombi! +5 Punkte!", -- Space_Invasion
["--- Points Mode ---"] = "--- Punktemodus ---", -- Battalion
["Poison"]="Gift",
["Poisonous Apple"]="Giftapfel",
["Poisonous, deals no damage."] = "Giftig, macht keinen Schaden.", -- Continental_supplies
["Pokémon"] = "Pokémon",
["Poor %s (%s) died %d times."] = "%s (%s) war arm dran und ist %d mal gestorben.", -- Mutant
["Porkey"] = "Igelchen", -- 
["Portal hint: One goes to the destination, the other one is the entrance.|"] = "Portaltipp: Eins geht zum Ziel, das andere ist der Eingang.|", -- A_Classic_Fairytale:dragon
["Portal Mind Challenge"] = "Knifflige Portalherausforderung", -- portal
["Precise Aim: [Left Shift]"] = "Genaues Zielen: [Umschalt links]", -- Basic_Training_-_Movement
["Precise Aim: [Left Shift] + [Up]/[Down]"] = "Genaues Zielen: [Umschalt links] + [Hoch]/[Runter]", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["Precise flying"]="Präzisionsfliegen",
["Precise: Remove previous waypoint"] = "Genaues Zielen: Vorherigen Wegpunkt entfernen", -- Racer
["Precise shooting"]="Präzisionsschießen",
["Predator"] = "Jäger", -- portal
["Prepare for battle!"]="Bereitmachen zum Kämpfen!",
["Prepare to fight"]="Bereitmachen zum Kämpfen",
["Prepare to flee!"]="Bereitmachen zum Fliehen!",
["Prepare yourself, %s!"] = "Mach dich bereit, %s!", -- The_Specialists
["Press [Attack] (space bar by default) to start,|repeatedly tap the up, left and right movement keys to accelerate."] = "Drücke [Angriff] (standardmäßig die Leertaste) zum Starten,|drücke wiederholt die Bewegungstasten oben,|links und rechts zum Beschleunigen.", -- Basic_Training_-_Flying_Saucer
["Press [Attack] to begin."] = "Drücke [Angreifen], um anzufangen.", -- A_Classic_Fairytale:first_blood
["Press [Attack] to confirm."] = "Drücke [Angreifen] zum Bestätigen.", -- Continental_supplies
["Press [Attack] to select this continent!"] = "Drücke [Angreifen], um diesen Kontinent auszuwählen!", -- Continental_supplies
["Press [Left] and [Right] to change the difficulty."] = "Drücke [Links] und [Rechts], um den Schwierigkeitsgrad zu ändern.", -- A_Classic_Fairytale:first_blood
["Press [Left] or [Right] to move around, [Long Jump] to jump forwards."] = "Drücke [Links]/[Rechts] zum Bewegen, [Weitsprung], um vorwärts zu springen.", -- A_Classic_Fairytale:first_blood
["Press [Long jump] to accept this configuration and begin placing hedgehogs."] = "Drücke [Weitsprung], um diese Konfiguration zu akzeptieren|und mit der Igelplatzierung anzufangen.", -- WxW
["Press [Long jump] to accept this configuration and start the game."] = "Drücke [Weitsprung], um diese Konfiguration zu akzeptieren|und das Spiel zu starten.", -- WxW
["Press [M] to see the mission texts"] = "Drücke [M], um die Missionstexte zu sehen", -- Basic_Training_-_Movement
["Press [Precise] to skip intro"]="Drücke [Genaues Zielen], um das Intro zu überspringen",
["Press [Up] and [Down] to move between menu items.|Press [Attack], [Left], or [Right] to toggle."] = "Drücke [Hoch] und [Runter], um zwischen Menüpunkten zu wechseln.|Drücke [Angriff], [Links] oder [Rechts] zum Wechseln.", -- WxW
["Prestigious Pilot"]="Prestigeträchtiger Pilot",
["Princess Peach"] = "Prinzessin Peach", -- 
["Princess"] = "Prinzessin", -- A_Classic_Fairytale:family, A_Classic_Fairytale:journey
["Problems, dude? Chillax!"] = "Mann, hast du ein Problem? Chill mal!", -- A_Classic_Fairytale:epil
["Professional pilot"]="Profipilot",
["Professional stunt pilot"]="Profi-Stuntpilot",
["Professor Hogevil, then known as James Hogus, worked for PAotH back in my time."]="Professor Bösigel, früher bekannt als Jakobus Iglus, arbeitete in meiner Zeit für PAdI.", -- A_Space_Adventure:moon02
["Professor"]="Professor",
["Professor's Team"] = "Professors Team", -- A_Space_Adventure:death01
["Prof. Hogevil"]="Prof. Bösigel",
["Protect the King: When the king dies, so does the team"] = "Beschützt den König: Wenn der König stirbt, stirbt das Team mit", -- Battalion
["Purple"] = "Violett", -- 
["Pyromancer"]="Feuermacher",
["Pyro"]="Pyromane",
["Quit: [Esc]"] = "Verlassen: [Esc]", -- Basic_Training_-_Movement
["Race complexity limit reached"] = "Rennkomplexitätslimit erreicht", -- Racer, TechRacer
["Race failed!"] = "Rennen gescheitert!", -- A_Space_Adventure:moon02
["Racer tool"] = "Wettrennwerkzeug", -- Racer
["Racer"] = "Wettrennen", -- Racer
["Race"] = "Wettrennen", -- TrophyRace
["Rachel"]="Ramona",
["Radar: Off"] = "Radar: Aus", -- WxW
["Radar: On"] = "Radar: Ein", -- WxW
["Radar Ping: [High jump]"] = "Radarping: [Hochsprung]", -- Space_Invasion
["Radar: Show after crate drop"] = "Radar: Nach Kistenabwurf zeigen", -- WxW
["Raging Buffalo"]="Wütender Büffel",
["Ramesses"] = "Ramesses", -- 
["Ramon"]="Ramon",
["Random continent"] = "Zufälliger Kontinent", -- Continental_supplies
["Rank: %s"]="Rang: %s",
["Razac"] = "Rasak", -- portal
["RC Plane Challenge"] = "Funkflugzeugsherausforderung", -- User_Mission_-_RCPlane_Challenge
["Reach and destroy the final target to win."] = "Erreiche und zerstöre die letzte Zielscheibe, um zu gewinnen.", -- Basic_Training_-_Rope
["Read the challenge objectives from within the mission for more details."]="Lies die Herausforderungsziele in der Mission für mehr Details.", -- A_Space_Adventure:death02, A_Space_Adventure:desert03, A_Space_Adventure:fruit03
["Ready for Battle?"]="Bereit für die Schlacht?",
["Really?! You thought you could harm me with your little toys?"]="Wirklich? Du dachtest, du könntest mich mit deinen kleinen Spielzeugen verletzen?",
["Red"] = "Rot", -- 
["Reflector Shield: Reflects enemy projectiles."] = "Reflektorschild: Reflektiert Feindprojektile.", -- Construction_Mode
["Reflector Shield"]="Reflektorschild",
["Regurgitator"]="Hochwürger",
["Reinforcements! +2 of each weapon!"] = "Nachschub! +2 von jeder Waffe!", -- A_Space_Adventure:death02
["Reinforcements"]="Verstärkung",
["Release rope: [Attack]"] = "Seil loslassen: [Angriff]", -- Basic_Training_-_Rope
["Remember: Hold down [Left Shift] to prevent slipping"] = "Denk dran: Halte [Umschalt links], um nicht zu rutschen", -- Basic_Training_-_Movement
["Remember! Many will seek the anti-gravity device! Now go, hurry up!"]="Denk dran: Viele werden das Antischwerkraftgerät begehren! Geh jetzt! Beeilung!",
["Remember this, pathetic animal: When the day comes, you will regret your blind loyalty!"] = "Höre meine Worte, du erbärmliches Tier: Eines Tages wirst du deine blinde Loyalität bitter bereuen!", -- A_Classic_Fairytale:shadow
["Replenishment: Weapons are restocked on turn start of a new hog"] = "Aufstockung: Waffen werden am Zugbeginn eines neuen Igels aufgestockt", -- Highlander
["Repositioning Mode"] = "Repositionierungsmodus", -- HedgeEditor
["REPOSITIONING MODE"] = "REPOSITIONIERUNGSMODUS", -- HedgeEditor
["Rescue the imprisoned PAotH team and get the fuel!"]="Rette das gefangene PAdI-Team und hol dir den Treibstoff!",
["Respawner: Resurrects dead hogs."] = "Wiederbeleber: Belebt tote Igel wieder.", -- Construction_Mode
["Respawner"]="Wiederbeleber",
["Retract/Extend rope: [Up]/[Down]"] = "Seil einziehen/ausfahren: [Hoch]/[Runter]", -- Basic_Training_-_Rope
["- Return the enemy flag to your base to score"] = "- Bring die Feindesflagge zu deiner Basis, um zu punkten", -- Capture_the_Flag
["Return to Leaks A Lot!"] = "Kehre zu Undichte Stelle zurück!", -- A_Classic_Fairytale:shadow
["Return to the mission menu by pressing the \"Go back\" button."]="Kehre zum Missionsmenü zurück, indem du den »Zurück«-Knopf drückst.", -- A_Space_Adventure:cosmos
["Return to the Surface"]="Zurück an die Oberfläche",
["Return to the training menu by pressing the “Go back” button."] = "Kehre zum Trainingsmenü zurück, indem du den »Zurück«-Knopf drückst.", -- Basic_Training_-_Movement
["Rider"] = "Reiter", -- portal
["Rifleman"]="Schütze",
["Righteous Beard"]="Redlicher Bart",
["Ripe"] = "Reif", -- 
["Rise the water if nobody else is in the circle and deal 6 damage to all enemy hogs."] = "Lass das Wasser steigen, wenn sonst keiner im Kreis ist, und richte 6 Schaden auf alle Feinde an.", -- Continental_supplies
["Robert Yellow Apple"]="Robert Gelbapfel",
["Rocket"] = "Rakete", -- Big_Armory
["Ronald"] = "Ronald", -- portal
["Roof"] = "Decke", -- WxW
["Rope-knocking Challenge"] = "Seilschubsen", -- User_Mission_-_Rope_Knock_Challenge
["Ropes and Crates"]="Seile und Kisten",
["Ropes can be fired again in the air!"] = "Seile können in der Luft erneut gefeuert werden!", -- A_Classic_Fairytale:first_blood
["Rope Weapons"] = "Seilwaffen", -- Basic_Training_-_Rope
["Rope won't get reset"]="Seil wird nicht zurückgesetzt.",
["Roshi"] = "Roschi", -- 
["Rot Molester"]="Rottiger Störenfried",
["Rotten"] = "Verdorben", -- 
["Round draw"] = "Unentschieden", -- Racer, TechRacer
["Round limit: %d"] = "Rundenbegrenzung: %d", -- Racer
["Round Limit: %d"] = "Rundenbegrenzung: %d", -- Space_Invasion
["Round limit:"] = "Rundenbegrenzung:", -- TechRacer
["Rounds complete: %d/%d"] = "Gespielte Runden: %d/%d", -- Racer, Space_Invasion, TechRacer
["Round's slowest lap: %.3fs by %s"] = "Schlechteste Zeit der Runde: %.3fs von %s", -- TrophyRace
["RS1"]="RE1",
["RS2"]="RE2",
["Rubber"]="Gummi",
["Rubber Placement Mode"]="Gummiplatzierungsmodus",
["RUBBER PLACEMENT MODE"]="GUMMIPLATZIERUNGSMODUS",
["Rules:"] = "Regeln:", -- Capture_the_Flag
["RULES:"] = "REGELN:", -- Frenzy
["Run away, you coward!"]="Lauf weg, du Feigling!", -- A_Space_Adventure:desert01
["Running displacement algorithm …"] = "Führe Deplatzierungsalgorithmus aus …", -- A_Classic_Fairytale:queen
["Running for survival"]="Lauf um dein Leben",
["Rusted Diego"] = "Rost-Diego", -- 
["Rusty Joe"]="Rostjonas",
["Ryu"] = "Ryu", -- 
["%s: %.1fs"] = "%s: %.1fs", -- Racer, TechRacer
["%s (+1)"] = "%s (+1)", -- A_Space_Adventure:fruit03
["Sabotage all hogs in the circle and fire a cluster above you.|Sabotaged hogs lose health and have to deal with a very high gravity during their turn."] = "Sabotiere alle Igel im Kreis und feuere einen Bombensplitter nach oben.|Sabotierte Igel verlieren Gesundheit und leiden während ihres Zuges unter einer sehr hohen Schwerkraft.", -- Continental_supplies
["Saint"]="Sankt",
["Salivaslurper"]="Speichelschlürfer",
["Salty Dog"] = "Versalzene Suppe", -- 
["Salvation"]="Erlösung",
["Salvation was one step closer now..."]="Die Erlösung war nun einen Schritt näher.",
["Sam"]="Steffen",
["Sandals?! I thought you left your ring!"] = "Sandalen?! Ich dachte, du hattest deinen Ring vergessen!", -- A_Classic_Fairytale:queen
["%s and GB"] = "%s und GB", -- A_Space_Adventure:fruit02
["%s and %s enter the battlefield"] = "%s und %s betreten das Schlachtfeld", -- A_Space_Adventure:fruit01
["Sandstorm"]="Sandsturm",
["Sandy"]="Sandi",
["%s arrived at the Desert Planet!"] = "%s ist auf dem Wüstenplaneten angekommen!", -- A_Space_Adventure:cosmos
["%s arrived at the Fruit Planet!"] = "%s ist auf dem Obstplaneten angekommen!", -- A_Space_Adventure:cosmos
["%s arrived at the Ice Planet!"] = "%s ist auf dem Eisplaneten angekommen!", -- A_Space_Adventure:cosmos
["%s arrived at the meteorite!"] = "%s ist auf dem Meteoriten angekommen!", -- A_Space_Adventure:cosmos
["%s arrived at the moon!"] = "%s ist auf dem Mond angekommen!", -- A_Space_Adventure:cosmos
["%s arrived at the Planet of Death!"] = "%s ist auf dem Planeten des Todes angekommen!", -- A_Space_Adventure:cosmos
["Save as many hogs as possible!"] = "Rette so viele Igel, wie du kannst!", -- User_Mission_-_That_Sinking_Feeling
["Save Fell From Heaven!"]="Rette Fiel Vom Himmel!",
["Save Leaks A Lot!|Hint: The switch hedgehog utility might be of help to you."] = "Rette Undichte Stelle!|Tipp: Das Werkzeug »Igel wechseln« könnte von Nutzen sein.", -- A_Classic_Fairytale:shadow
["Save Level: Precise+4"]="Level sichern: Genaues Zielen + 4",
["Save Level: [Precise]+[4]"] = "Level speichern: [Genaues Zielen]+[4]", -- HedgeEditor
["Save the princess! All your hogs must survive!|Hint: Kill the cyborgs first! Use the ammo very carefully!|Hint: You might want to spare a girder for cover!"]="Rette die Prinzessin! All deine Igel müssen überleben!|Tipp: Töte die Cyborgs zuerst! Benutze die Munition sehr sparsam!|Tipp: Du solltest vielleicht einen Träger als Deckung behalten!",
["Save the princess by collecting the crate in under 12 turns!"]="Rette die Prinzessin, indem du die Kiste vor Ablauf von 12 Zügen einsammelst!",
["Saving Hogera"]="Hogera retten",
["%s barely made it past the hogosphere."]="%s hat es so gerade noch über die Igelsphäre geschafft.",
["%s bravely climbed up to a dizzy height of %d to reach home."]="Mutig erklomm %s eine schwindelerregende Höhe von %d, um das Zuhause zu erreichen.",
["Scallywag"] = "Tunichtgut", -- 
["Scalp Muncher"]="Skalpknabberer",
["Scenario"] = "Szenario", -- Big_Armory, portal, User_Mission_-_Bamboo_Thicket, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Newton_and_the_Hammock, User_Mission_-_Nobody_Laugh, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork_2, User_Mission_-_Teamwork, User_Mission_-_The_Great_Escape
["Scientist"]="Wissenschaftler",
["%s climbed home in %d seconds!"] = "%s ist in %d Sekunden nach Hause geklettert!", -- ClimbHome
["%s (contd.)"] = "%s (mehr)", -- A_Classic_Fairytale:epil
["Score: %d"] = "Punktzahl: %d", -- Space_Invasion
["Score goal: %d"] = "Punkteziel: %d", -- Control
["Score graph"] = "Punktegraph", -- Mutant
["Score points by killing other hedgehogs."] = "Hole Punkte, indem du andere Igel tötest.", -- Mutant
["Scores:"] = "Punktestand:", -- Mutant
["Scoring: "] = "Punktewertung: ", -- Mutant
["%s couldn't escape, try again!"] = "%s konnte nicht fliehen, versuch es erneut!", -- A_Space_Adventure:fruit01
["Script parameter examples:"] = "Skriptparameterbeispiele:", -- Gravity
["%s: %d (deaths: %d)"] = "%s: %d (Tode: %d)", -- Mutant
["%s (%d), %d sec"] = "%s (%d), %d s", -- Continental_supplies
["%s: Did not finish"] = "%s: Wurde nicht fertig", -- Racer, TechRacer
["%s did not finish the race."] = "%s hat das Rennen nicht abgeschlossen.", -- Racer, TechRacer
["%s didn't expect that."] = "%s hat damit nicht gerechnet.", -- User_Mission_-_Rope_Knock_Challenge
["%s died … and lives again!"] = "%s ist gestorben … und lebt wieder!", -- Construction_Mode
["%s doesn’t really know how to handle a rope properly."]="%s weiß nicht, wie man mit einem Seil umgeht.",
["%s (+%d)"] = "%s (+%d)", -- Battalion
["%s (%d)"] = "%s (%d)", -- Continental_supplies
["%s, %d sec"] = "%s, %d s", -- Continental_supplies
["Search for the device with the help of the other hedgehogs."] = "Such nach dem Gerät mit der Hilfe der anderen Igel.", -- A_Space_Adventure:fruit02
["Searching in the dust"]="Suche im Staub",
["Searching the stars!"]="Suche in den Sternen",
["Seems like every time you take a \"walk\", the enemy finds us!"] = "Es scheint, dass jedes Mal, wenn du »spazieren« gehst, der Feind uns findet!", -- A_Classic_Fairytale:backstab
["See that crate farther on the right?"]="Siehst du die Kiste weiter rechts?",
["See ya!"]="Mach's gut!",
["Segmentation Paul"]="Se Gmentf Ehler",
["Select a placement mode and read the infos|in the mission panel to learn how to use it."] = "Wähle einen Platzierungsmodus und lies die Infos|in der Missionsanzeige, um zu erfahren, wie man ihn benutzt.", -- HedgeEditor
["Select continent"] = "Kontinent auswählen", -- Continental_supplies
["Selection Mode"]="Auswahlmodus",
["Select, modify, or delete girders, rubbers and sprites"] = "Wähle, modifiziere oder lösche Träger, Gummis und Sprites", -- HedgeEditor
["Select/Place/Delete Gear: [Left Click]"] = "Gear wählen/platzieren/löschen: [Linksklick]", -- HedgeEditor
["Select, reposition and delete gears"] = "Wähle, repositioniere und lösche Gears", -- HedgeEditor
["Select Rope"] = "Seil auswählen", -- Basic_Training_-_Rope
["Select “Switch Hedgehog” from the ammo menu and|hit the “Attack” key to proceed."] = "Wähle »Igel wechseln« aus dem Munitionsmenü und|drücke [Angriff], um fortzufahren.", -- Basic_Training_-_Movement
["Select “Switch Hedgehog” from the ammo menu and|hit the “Attack” key."] = "Wähle »Igel wechseln« aus dem Munitionsmenü und|drücke [Angriff].", -- Basic_Training_-_Movement
["Select the current continent."] = "Wählt den jetzigen Kontinent aus.", -- Continental_supplies
["Select the rope to begin!"] = "Wähle das Seil aus, um anzufangen!", -- Basic_Training_-_Rope
["Select this item for a random continent."] = "Wähle diesen Eintrag, um einen zufälligen Kontinent auszuwählen.", -- Continental_supplies
["Select weapon: [Left click]"] = "Waffe auswählen: [Linksklick]", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["Select Weapon"] = "Waffe auswählen", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
["Select win/lose condition: [Left], [Right]"] = "Sieg-/Niederlagebedingung wählen: [Links], [Rechts]", -- HedgeEditor
["Select your continent with [Up]/[Down] or by selecting a representative weapon."] = "Wähle deinen Kontinent mit [Hoch]/[Runter]. Alternativ kannst du eine repräsentative Waffe wählen.", -- Continental_supplies
["%s enters the battlefield"] = "%s betritt das Schlachtfeld", -- A_Space_Adventure:fruit01
["Sergey"] = "Sergey", -- 
["%s escaped successfully!"] = "%s ist erfolgreich geflohen!", -- A_Space_Adventure:fruit01
["Set bounciness: [Left Shift] + [1]-[5]"] = "Sprunghaftigkeit setzen: [Umschalt links] + [1]-[5]", -- Basic_Training_-_Grenade
["Set detonation timer: [1]-[5]"] = "Explosionszeitzünder einstellen: [1]-[5]", -- Basic_Training_-_Grenade
["Set Health: [Left Click]"]="Gesundheit setzen: [Linksklick]",
["Set Identity: [Left Click]"]="Identität setzen: [Linksklick]",
["Set LandFlag: [1], [2], [3], [4]"]="LandFlag setzen: [1], [2], [3], [4]",
["Set period to negative value for random gravity."] = "Setze »period« auf negativen Wert für zufällige Schwerkraft.", -- Gravity
["Set the health of hogs, health crates, barrels and duds"] = "Setze die Gesundheit von Igeln und Objekten", -- HedgeEditor
["Set to %d"] = "Auf %d setzen", -- HedgeEditor
["%s exploded."] = "%s ist explodiert.", -- User_Mission_-_Rope_Knock_Challenge
["%s fell from a high cliff."] = "%s fiel von einer hohen Klippe.", -- User_Mission_-_Rope_Knock_Challenge
["%s fell too fast."] = "%s fiel zu schnell.", -- User_Mission_-_Rope_Knock_Challenge
["%s fell victim to a weapon filter"] = "%s ist einem Waffenfilter zum Opfer gefallen", -- Construction_Mode
["%s felt unstable."] = "%s war nicht ganz standfest.", -- User_Mission_-_Rope_Knock_Challenge
["%s felt victim to rope-knocking."] = "%s fiel dem Seilschubsen zum Opfer.", -- User_Mission_-_Rope_Knock_Challenge
["%s flew like a rock."] = "%s fiel wie ein Stein.", -- User_Mission_-_Rope_Knock_Challenge
["%s gets an extra life"] = "%s erhält ein Extraleben", -- Construction_Mode
["%s goes the way of the lemming."] = "%s geht den Weg der Lemminge.", -- User_Mission_-_Rope_Knock_Challenge
["Sgt. Smith"] = "Gfr. Schmidt", -- 
["%s had it coming."] = "%s hat’s verdient.", -- User_Mission_-_Rope_Knock_Challenge
["%s had no chance."] = "%s hatte keine Chance.", -- User_Mission_-_Rope_Knock_Challenge
["... share your beauty with the world every morning, my princess!"]="…, ja, wie du deine Schönheit mit dem Rest der Welt teilst, meine Prinzessin!",
["%s has been killed before taking enough damage first."] = "%s ist vor dem Erleiden des erforderlichen Schadens gestorben.", -- SimpleMission
["%s has been knocked out."] = "%s wurde eliminiert.", -- User_Mission_-_Rope_Knock_Challenge
["%s has been rescued from death"] = "%s wurde wiederbelebt", -- Construction_Mode
["%s has dropped the flag!"] = "%s ließ die Flagge fallen!", -- CTF_Blizzard
["%s has fallen victim to gravity."] = "%s fiel der Schwerkraft zum Opfer.", -- User_Mission_-_Rope_Knock_Challenge
["%s has mutated! +2 points"] = "%s mutierte! +2 Punkte", -- Mutant
["%s has passed the best height of %s!"]="%s hat die Besthöhe von %s überschritten!",
["%s has scored!"] = "%s hat gepunktet!", -- Capture_the_Flag
["%s has to refuel the saucer."] = "%s muss die Untertasse auftanken.", -- A_Space_Adventure:moon01
["%s hates Newton."] = "%s hasst Newton", -- User_Mission_-_Rope_Knock_Challenge
["She endangered the whole tribe!"] = "Sie hatte den ganzen Stamm in Gefahr gebracht!", -- A_Classic_Fairytale:epil
["sheepluva"] = "sheepluva", -- 
["Sheepy"] = "Schafi", -- 
["She's behind that tall thingy."]="Sie ist hinter diesem großen Dingsda.",
["Shield boosted! +%d power"] = "Schild aufgesammelt! +%d Energie", -- Space_Invasion
["Shield depleted"] = "Schild aufgebraucht", -- Space_Invasion
["Shield is fully recharged!"]="Schild vollständig aufgeladen!",
["Shield Master! +10 points!"] = "Schildmeister! +10 Punkte!", -- Space_Invasion
["Shield Miser! +%d points!"] = "Schildgeiz! +%d Punkte!", -- Space_Invasion
["Shield OFF: %d power remaining"] = "Schild AUS: %d Energie verbleibend", -- Space_Invasion
["Shield ON: %d power remaining"] = "Schild EIN: %d Energie verbleibend", -- Space_Invasion
["Shield Seeker! +10 points!"] = "Schildsucher! +10 Punkte!", -- Space_Invasion
["Shinobi"] = "Shinobi", -- 
["%s hit the ground."] = "%s traf den Boden.", -- User_Mission_-_Rope_Knock_Challenge
["Shoppa Love"]="Seilliebe",
["Sigh."] = "Seufz.", -- A_Classic_Fairytale:epil
["Silly"]="Doofi",
["Silver"] = "Silber", -- 
["Sinky"]="Blubb",
["Sirius Lee"]="Leo Ernst",
["%s is dead, who was critical to this mission!"] = "%s ist tot, war aber kritisch für diese Mission!", -- SimpleMission
["%s is eliminated!"] = "%s wurde eliminiert!", -- User_Mission_-_Rope_Knock_Challenge
["%s is now as poor as a church mouse"] = "%s ist jetzt so arm wie eine Kirchenmaus", -- Construction_Mode
["%s is now a zombie hedgehog"] = "%s ist jetzt ein Zombie-Igel", -- Construction_Mode
["%s is suddenly low on ammo"] = "%s fehlt es plötzlich an Munition", -- Construction_Mode
["Skulls"] = "Schädels", -- Bazooka_Battlefield
["Slimer"] = "Schleimer", -- 
["Slippery"]="Rutschig",
["%s lost all the weapons"] = "%s hat alle Waffen verloren", -- Construction_Mode
["%s lost, try again!"] = "%s hat verloren, versuch es nochmal!", -- A_Space_Adventure:death01, A_Space_Adventure:death02, A_Space_Adventure:desert01, A_Space_Adventure:desert02, A_Space_Adventure:desert03, A_Space_Adventure:final, A_Space_Adventure:fruit01, A_Space_Adventure:fruit02, A_Space_Adventure:fruit03, A_Space_Adventure:ice01, A_Space_Adventure:moon01
["Slot %d: %s"] = "Slot %d: %s", -- Frenzy
["Slot keys save time! (F1-F10 by default)"]="Schnelltasten, um Zeit zu sparen! (standardmäßig F1–F10)",
["Slowpoke"] = "Flegmon", -- 
["%s made it past the hogosphere."]="%s hat es über die Igelsphäre geschafft.",
["%s managed to pass half of the distance towards home."]="%s hat die Hälfte des Weges nach Hause absolviert.",
["%s may choose the rules."] = "%s darf die Regeln bestimmen.", -- WxW
["Smith 0.97"]="Smith 0.97",
["Smith 0.98"]="Smith 0.98",
["Smith 0.99a"]="Smith 0.99a",
["Smith 0.99b"]="Smith 0.99b",
["Smith 0.99f"]="Smith 0.99f",
["Smith 1.0"]="Smith 1.0",
["Smugglers"]="Schmuggler",
["%s must collect the final crates."] = "%s muss die letzten Kisten aufsammeln.", -- A_Space_Adventure:fruit02
["%s must skip this turn for rule violation."] = "%s muss wegen einer Regelverletzung aussetzen.", -- WxW
["Sneaks"] = "Schleichs", -- Bazooka_Battlefield
["%s never got the ninja diploma."]="%s ist bei der Ninjaprüfung durchgefallen.",
["%s never wanted to reach for the sky in the first place."]="%s wollte nie nach den Sternen greifen.",
["Sniper! +8 points!"] = "Scharfschütze! +8 Punkte!", -- Space_Invasion
["Sniper"]="Heckenschütze",
["Sniper Training"]="Scharfschützen-Training",
["So, as promised I have brought you where I think that the device you are looking for is hidden."]="Nun, wie versprochen habe ich dich an den Ort gebracht, von dem ich glaube, dass das Gerät dort versteckt ist.",
["So far, you had infinite ropes, but in the|real world, ropes are usually limited."] = "Bisher hattest du unendlich viele Seile,|aber in der realen Welt sind Seile normalerweise begrenzt.", -- Basic_Training_-_Rope
["So humiliating..."]="Welch Demütigung!",
["So, I believe that it's a good place to start."]="Also glaube ich, dass es ein guter Ort zum Anfangen ist.", -- A_Space_Adventure:desert01
["So, I kindly ask for your help."]="Also bitte ich dich ergebenst um Hilfe.",
["So I shook my fist in the air!"] = "Und so schlug ich die Faust gen Himmel!", -- A_Classic_Fairytale:epil
["Soldier"]="Soldat",
["So, let me tell you what I know about Professor Hogevil."]="Also, lass mich erzählen, was ich über Professor Bösigel weiß.",
["Some parts of the land are indestructible"]="Einige Teile des Landes sind unzerstörbar",
["Some parts of the land are indestructible."]="Einige Teile des Landes sind unzerstörbar.",
["Some sick game of yours?!"] = "Ein krankes Spiel von euch?!", -- A_Classic_Fairytale:queen
["Some weapons can be dropped from the rope."] = "Einige Waffen können vom Seil aus fallen gelassen werden.", -- Basic_Training_-_Rope
["Somewhere else on the planet of fruits, Captain Lime helps %s"] = "Irgendwo anders auf dem Planeten des Obstes hilft Leutnant Limone %s", -- A_Space_Adventure:fruit02
["Somewhere else on the planet of fruits, %s gets closer to the device"] = "Irgendwo anders auf dem Planeten des Obstes kommt %s näher an das Gerät", -- A_Space_Adventure:fruit02
["Somewhere in the Fruit Planet Hog Solo got lost ..."]="Irgendwo auf dem Obstplaneten hat sich Igel Einsam verlaufen …",
["Somewhere in the Planet of Death..."]="Irgendwo auf dem Todesplaneten …",
["Somewhere on the Planet of Death ..."] = "Irgendwo auf dem Planeten des Todes …", -- A_Space_Adventure:death02
["Somewhere on the Planet of Fruits a terrible war is about to begin ..."]="Irgendwo auf dem Obstplaneten steht ein fürchterlicher Krieg bevor",
["Somewhere on the uninhabitable Death Planet ..."]="Irgendwo auf dem unbewohnbaren Todesplaneten …",
["So, now I got the last part and I have your friends captured."]="Und jetzt habe ich das letzte Teil und deine Freunde gefangengenommen.",
["So, %s, here we are ..."] = "Nun, %s, hier wären wir …", -- A_Space_Adventure:cosmos
["So the princess was never heard of again ..."] = "Und so hörte man nie wieder von der Prinzessin …", -- A_Classic_Fairytale:family
["So, uhmm, how did you manage to teleport them so far?"] = "Und, ähm, wie hast du es geschafft, sie so weit zu teleportieren?", -- A_Classic_Fairytale:epil
["Sour"] = "Sauer", -- 
["South America"]="Südamerika",
["So? What will it be?"]="Also? Was ist deine Entscheidung?",
["So you are able to launch projectiles into your aiming direction, always at full power."] = "Somit bist du in der Lage, Projektile in Zielrichtung zu feuern, immer mit voller Kraft.", -- Basic_Training_-_Flying_Saucer
["So you are interested in Professor Hogevil, huh?"]="Also bist du an Professor Bösigel interessiert, nicht wahr?", -- A_Space_Adventure:moon02
["So you basically did the dirty work for us."] = "Also hast du praktisch unsere Drecksarbeit erledigt.", -- A_Classic_Fairytale:dragon
["Space Invasion"] = "Weltrauminvasion", -- Space_Invasion
["SPACE INVASION"] = "WELTRAUMINVASION", -- Space_Invasion
["Spacetrip"]="Weltraumreise",
["Spawn the crate and attack!"] = "Lass die Kiste auftauchen und greif an!", -- WxW
["Specials: Kings and air generals drop helpers, not weapons"] = "Besonderheiten: Könige und Luftgeneräle lassen Helfer statt Waffen fallen", -- Battalion
["Special weapons:"] = "Sonderwaffen:", -- Continental_supplies
["Speckles"] = "Flecken", -- 
["Specs Appeal"] = "Doppelpunkt", -- 
["Specs"] = "Punkte", -- 
["Spectator"] = "Zuschauer", -- 
["Speed Roping"] = "Schnelles Seil", -- Basic_Training_-_Rope
["Speed Shoppa"] = "Rasender Kistensammler", -- 
["Spikes"] = "Stacheln", -- 
["Spike"]="Stachel",
["Spiky Cheese"]="Stachliger Käse",
["%s, place the first hedgehog!"] = "%s, platziere den ersten Igel!", -- WxW
["Spleenlover"]="Milzlieber",
["Sponge"]="Schwamm",
["Spooky Tree"]="Spukiger Baum",
["Sprite Erasure Mode"]="Sprite-Löschmodus",
["Sprite Modification Mode"]="Sprite-Modifikationsmodus",
["SPRITE MODIFICATION MODE"]="SPRITE-MODIFIKATIONSMODUS",
["Sprite Placement Mode"]="Sprite-Platzierungsmodus",
["SPRITE PLACEMENT MODE"]="SPRITE-PLATZIERUNGSMODUS",
["Sprite Testing Mode"]="Sprite-Testmodus",
["Squirtle"] = "Schiggy", -- 
["Squishy"] = "Matschig", -- 
["%s reached home in %.3f seconds. Congratulations!"]="%s hat das Zuhause in %.3f Sekunden erreicht. Gratulation!",
["%s (%s) destroyed %d invaders in one round."] = "%s (%s) hat %d Invasoren in einer Runde zerstört.", -- Space_Invasion
["%s (%s) does not have to feel ashamed for their best height of %d."]="%s (%s) braucht sich für die Besthöhe von %d nicht zu schämen.",
["%s, select your continent!"] = "%s, wähl deinen Kontinent!", -- Continental_supplies
["%s (%s) gave short shrift to the invaders: Longest combo of %d!"] = "%s (%s) machte kurzen Prozess mit den Invasoren: Beste Kombi von %d!", -- Space_Invasion
["%s (%s) has been invited to join the Planetary Association of the Hedgehogs, it destroyed a staggering %d invaders in just one round!"] = "%s (%s) wurde in die Planetare Assoziation der Igel eingeladen für die Zerstörung von erstaunlichen %d Invasoren in nur einer Runde!", -- Space_Invasion
["%s (%s) has captured the flag %d times."] = "%s (%s) hat die Flagge %d mal erobert.", -- Capture_the_Flag
["%s (%s) hate life and suicided %d times."] = "%s (%s) hasst das Leben und begang gleich %d mal Suizid.", -- Mutant
["%s should try the rope training mission first."]="%s sollte wohl zuerst das Seiltraining absolvieren.",
["%s (%s) is addicted to killing: %d invaders destroyed in one round."] = "%s (%s) ist im Tötungsrausch: %d Invasoren in einer Runde zerstört .", -- Space_Invasion
["%s (%s) is a hardened hunter: No misses and %d hits in its best round!"] = "%s (%s) ist ein abgehärteter Jäger: Kein Schuss verfehlt und %d Treffer in der besten Runde!", -- Space_Invasion
["%s (%s) is a tumbleweed: %d points in one round."] = "%s (%s) schlägt Purzelbäume: %d Punkte in einer Runde.", -- Space_Invasion
["%s (%s) is good at this: %d points in only one round!"] = "%s (%s) hat’s echt drauf: %d Punkte in nur einer Runde.", -- Space_Invasion
["%s (%s) is Rambo in a hedgehog costume! He destroyed %d invaders in one round."] = "%s (%s) ist Rambo im Igelkostüm: Er zerstörte %d Invasoren in nur einer Runde.", -- Space_Invasion
["%s skipped ninja classes."]="%s hat den Ninjaunterricht geschwänzt.",
["%s spawned at a really bad position."] = "%s hatte eine sehr schlechte Startposition.", -- User_Mission_-_Rope_Knock_Challenge
["%s splatted."] = "%s wurde zerschmettert.", -- User_Mission_-_Rope_Knock_Challenge
["%s (%s) reached a decent peak height of %d."]="%s (%s) erreichte eine gute Besthöhe von %d.",
["%s (%s) reached a peak height of %d."]="%s (%s) erreichte eine Besthöhe von %d.",
["%s (%s) reached for the sky and beyond with a height of %d!"]="%s (%s) griff nach den Sternen mit einer Höhe von %d!",
["%s (%s) reached home in %.3f seconds."] = "%s (%s) erreichte das Zuhause in %.3f Sekunden.", -- ClimbHome
["%s (%s) shot %d invaders and never missed in the best round!"] = "%s (%s) hat in der besten Runde %d Invasoren abgeschossen, ohne einmal daneben zu schießen!", -- Space_Invasion
["%s: %s"] = "%s: %s", -- Continental_supplies
["%s (%s) struck like a meteor: %d points in only one round!"] = "%s (%s) schlug ein wie ein Meteor: %d Punkte in nur einer Runde!", -- Space_Invasion
["%s still had a long way to go."]="%s hatte noch einen langen Weg.",
["%s stumbled."] = "%s ist gestolpert.", -- User_Mission_-_Rope_Knock_Challenge
["%s (%s) tumbles like no other: %d points in one round."] = "%s (%s) kämpft wie kein Anderer: %d Punkte in einer Runde.", -- Space_Invasion
["%s (%s) was certainly not afraid of heights: Peak height of %d!"]="%s (%s) hatte ganz bestimmt keine Höhenangst: Besthöhe von %d!",
["%s (%s) was lightning-fast! Longest combo of %d, absolutely insane!"] = "%s (%s) ist blitzschnell! Längste Kombi von %d, absolut verrückt!", -- Space_Invasion
["%s (%s) was on fire: Longest combo of %d."] = "%s (%s) hatte Hummeln im Hintern: Längste Kombi von %d.", -- Space_Invasion
["%s (%s) was panicly afraid of the water and decided to get in a safe distance of %d from it."]="%s (%s) hatte panische Angst vorm Wasser und hatte einen Sicherheitsabstand von %d erreicht.",
["%s (%s) was the best baby tumbler: %d points in one round."] = "%s (%s) war der beste Nachwuchspurzler: %d Punkte in einer Runde.", -- Space_Invasion
["%s (%s) was the greediest hedgehog and collected %d crates."] = "%s (%s) war der gierigste Igel und sammelte %d Kisten auf.", -- Mutant
["%s (%s) was undoubtedly the very best professional tumbler in this game: %d points in one round!"] = "%s (%s) war zweifelsfrei der beste Profipurzler im ganzen Spiel: %d Punkte in einer Runde!", -- Space_Invasion
["Standard Cleaver"]="Standardhackebeil",
["Standard Target"]="Standardziel",
["Standard Waypoint"]="Standard-Wegpunkt",
["Star"] = "Stern", -- Big_Armory
["Status update"] = "Statusaktualisierung", -- Racer, TechRacer
["Stay away from our weapons!"] = "Bleibt weg von unseren Waffen!", -- A_Classic_Fairytale:queen
["Stay there, comrades!"] = "Keinen Schritt weiter, Kameraden!", -- A_Classic_Fairytale:queen
["Stay there to flee!"] = "Bleib hier, um zu fliehen!", -- A_Space_Adventure:fruit01
["Steel Eye"]="Stahlauge",
["Step 1: Activate your flying saucer but do NOT move yet!"] = "1.: Aktiviere deine fliegende Untertasse, aber beweg dich noch NICHT.", -- Basic_Training_-_Flying_Saucer
["Step 1: Start roping"] = "1.: Befestige dich am Seil", -- Basic_Training_-_Rope
["Step 2: Select grenade"] = "2.: Wähl die Granate", -- Basic_Training_-_Rope
["Step 2: Select your grenade."] = "2.: Wähl eine Granate aus.", -- Basic_Training_-_Flying_Saucer
["Step 3: Drop the grenade"] = "3.: Lass die Granate fallen", -- Basic_Training_-_Rope
["Step 3: Start flying and get yourself right above the target."] = "3.: Flieg los und flieg direkt über der Zielscheibe.", -- Basic_Training_-_Flying_Saucer
["Step 4: Drop your grenade by pressing the [Long jump] key."] = "4.: Lass deine Granate fallen, indem du [Weitsprung] drückst.", -- Basic_Training_-_Flying_Saucer
["Step 5: Get away quickly and land safely anywhere."] = "5.: Flieh schnell und lande an einem sicheren Ort.", -- 
["Step By Step"]="Schritt für Schritt",
["Steve"]="Steffen",
["Sticky Mine Placement Mode"]="Haftminenplatzierungsmodus",
["STiCKY MINE PLACEMENT MODE"]="HAFTMINENPLATZIERUNGSMODUS",
["STICKY MINE PLACEMENT MODE"] = "HAFTMINENPLATZIERUNGSMODUS", -- HedgeEditor
["Stop, comrades!"] = "Anhalten, Kameraden!", -- A_Classic_Fairytale:queen
["Stop right there, puny worms!"] = "Schluss jetzt, ihr mickrigen Würmer!", -- A_Classic_Fairytale:queen
["Street Fighters"] = "Straßenboxer", -- 
["Strength: %d (multiplier for ammo)"] = "Stärke: %d (Faktor für Munition)", -- Battalion
["Strong knockback, but no poison."] = "Starker Rückschlag, aber kein Gift.", -- Continental_supplies
["Stronglings"]="Stärklinge",
["Structure Placement Mode"]="Gebäudeplatzierungsmodus",
["Structure Placer"] = "Gebäudeplatzierer", -- Construction_Mode
["Stupid, stupid Hogerians!"] = "Dumme, dumme Hogerianer!", -- A_Space_Adventure:final
["Subtract %d"] = "%d subtrahieren", -- HedgeEditor
["--- Sudden Death ---"] = "--- Sudden Death ---", -- Battalion
["Summer Squash"]="Sommerkürbis",
["Sundaland"]="Sunda",
["Sunflame"] = "Sonnenflamme", -- Big_Armory
["Super weapons: A few crates contain very powerful weapons."] = "Superwaffen: Ein paar Kisten enthalten sehr starke Waffen.", -- WxW
["Super weapons: %s"] = "Superwaffen: %s", -- WxW
["Supplies: Each continent gives you unique weapons, specials and health."] = "Versorgungsgüter: Jeder Kontinent gibt dir einzigartige Waffen, Extras und Gesundheit.", -- Continental_supplies
["Support Station: Allows placement of crates."] = "Waffenstation: Ermöglicht Kistenplatzierung.", -- Construction_Mode
["Support Station"]="Waffenstation",
["Sure!"] = "Sicher!", -- A_Classic_Fairytale:epil
["Surf Before Crate: %s"] = "Surfen Vor Kiste: %s", -- WxW
["Surf Before Crate: You must bounce off the water once before you can get crates."] = "Surfen Vor Kiste: Du musst vom Wasser einmal abprallen, bevor du Kisten bekommst.", -- WxW
["Surfer! +15 points!"]="Surfer! +15 Punkte",
["Surfer!"]="Surfer!",
["Surprise supplies: Get 1-3 random weapons each turn."] = "Überraschungsnachschub: Erhalte 1-3 zufällige Waffen pro Zug.", -- Continental_supplies
["Survive!"] = "Überlebe!", -- A_Classic_Fairytale:shadow
["%s violated the “All But Last” rule and will be penalized."] = "%s verletzte die »Nicht Den Letzten«-Regel und wird aussetzen müssen.", -- WxW
["%s violated the “Kill The Leader” rule and will be penalized."] = "%s verletzte die »Tötet Den Besten«-Regel und wird aussetzen müssen.", -- WxW
["Swap place with a random enemy in the circle."] = "Vertausch die Plätze mit einem zufälligen Gegner im Kreis.", -- Continental_supplies
["%s was a good target."] = "%s war ein gutes Zielobjekt.", -- User_Mission_-_Rope_Knock_Challenge
["%s was close to home."]="%s war nah an Zuhause.",
["%s was damn close to home."]="%s war verdammt nah an Zuhause.",
["%s was doomed from the beginning."] = "%s war von Anfang an dem Untergang geweiht.", -- User_Mission_-_Rope_Knock_Challenge
["%s was extracted from the scheme"] = "%s wurde vom Schema extrahiert", -- Continental_supplies
["%s was good, but not good enough."]="%s war gut, aber nicht gut genug.",
["%s was knocked away."] = "%s wurde weggeschubst.", -- User_Mission_-_Rope_Knock_Challenge
["%s was really unlucky."] = "%s hatte großes Pech.", -- User_Mission_-_Rope_Knock_Challenge
["%s was shoved away."] = "%s wurde hinweggefegt.", -- User_Mission_-_Rope_Knock_Challenge
["%s was smashed."] = "%s wurde zerschmettert.", -- User_Mission_-_Rope_Knock_Challenge
["Sweet"] = "Süß", -- 
["%s went over a quarter of the way towards home."]="%s hat mehr als ein Viertel des Weges nach Hause absolviert.",
["%s! Why?!"] = "%s! Warum!", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
["Swing, Leaks A Lot, on the wings of the wind!"]="Schwing, Undichte Stelle, auf den Flügeln des Windes!",
["Swing: [Left]/[Right]"] = "Schwingen: [Links]/[Rechts]", -- Basic_Training_-_Rope
["%s wins, congratulations!"] = "%s gewinnt, Gratulation!", -- A_Space_Adventure:moon01
["%s wins!"]="%s gewinnt!",
["%s wins with a best time of %.1fs."] = "%s gewinnt mit einer Bestzeit von %.1fs.", -- Racer, TechRacer
["Switch: Drop ball of dirt from parachute (once)"] = "Wechseln: Erdklumpen fallen lassen (ein mal)", -- Continental_supplies
["Switch Hedgehog (1/3)"] = "Igel wechseln (1/3)", -- Basic_Training_-_Movement
["Switch Hedgehog (2/3)"] = "Igel wechseln (2/3)", -- Basic_Training_-_Movement
["Switch Hedgehog (3/3)"] = "Igel wechseln (3/3)", -- Basic_Training_-_Movement
["Switch Hedgehog (Failed!)"] = "Igel wechseln (Fehlgeschlagen!)", -- Basic_Training_-_Movement
["Switch hedgehog: [Tabulator]"] = "Igel wechseln: [Tabulator]", -- Basic_Training_-_Movement
["Switch: Select weapon special"] = "Wechseln: Waffenextra auswählen", -- Continental_supplies
["Switch: Toggle crate radar"] = "Wechseln: Kistenradar umschalten", -- WxW
["%s won!"] = "%s gewinnt!", -- A_Space_Adventure:fruit01
["Swords"] = "Schwerter", -- Bazooka_Battlefield
["Syntax Errol"]="Syntaxfehlel",
["%s, you may choose the rules."] = "%s, du darfst die Regeln bestimmen", -- WxW
["szczur"] = "szczur", -- 
["Tackleberry"] = "Terrorbeere", -- 
["Tag Collection Mode"]="Markiermodus: Einsammeln",
["Tag Failure Mode"]="Markiermodus: Niederlage",
["Tag Gear: [Left Click]"]="Gear markieren: [Linksklick]",
["TAGGING MODE"]="MARKIERUNGSMODUS",
["Tag Victory Mode"]="Markiermodus: Sieg",
["Tails"] = "Fuß", -- 
["Talk about mixed signals..."]="Zuckerbrot und Peitsche …",
["Tall Potato"]="Großkartoffel",
["Tap [Pause] to see the mission texts"] = "[Pause] antippen, um Missionstexte zu sehen", -- Basic_Training_-_Movement
["Tap the “rotating arrow” button on the left|until you have selected Cappy, the hedgehog with the cap!"] = "Tippe den Knopf mit den rotierenden Pfeilen links unten an,|bis du Käppi ausgewählt hast, dem Igel mit der Mütze!", -- Basic_Training_-_Movement
["Target Placement Mode"]="Zielscheibenplatzierungsmodus",
["TARGET PLACEMENT MODE"] = "ZIELSCHEIBENPLATZIERUNGSMODUS", -- HedgeEditor
["Target Practice: Bazooka (easy)"] = "Zielübung: Bazooka (einfach)", -- Target_Practice_-_Bazooka_easy
["Target Practice: Bazooka (hard)"] = "Zielübung: Bazooka (schwer)", -- Target_Practice_-_Bazooka_hard
["Target Practice: Grenade (easy)"] = "Zielübung: Granate (einfach)", -- Target_Practice_-_Grenade_easy
["Target Practice: Grenade (hard)"] = "Zielübung: Granate (schwer)", -- Target_Practice_-_Grenade_hard
["Target Practice: Homing Bee"] = "Zielübung: Zielsuchende Biene", -- Target_Practice_-_Homing_Bee
["Target Practice: Shotgun"] = "Zielübung: Schrotflinte", -- Target_Practice_-_Shotgun
["Target Puncher"] = "Zielscheibenzerstörer", -- Basic_Training_-_Rope
["Targets left: %d"] = "Verbleibende Ziele: %d", -- 
["Target"] = "Zielscheibe", -- HedgeEditor
["Tatsujin"] = "Tatsujin", -- 
["Tatters"] = "Lumpen", -- 
["Team %d"] = "Team %d", -- SimpleMission
["Team highscore: %d"] = "Team-Punkterekord: %d", -- Utils
["Team Identity Mode"]="Team-Identitätsmodus",
["TEAM IDENTITY MODE"]="TEAMIDENTITÄTSMODUS",
["Team lowscore: %d"] = "Niedrigste Team-Punktzahl: %d", -- Utils
["Teams are tied! Continue playing rounds until we have a winner!"] = "Gleichstand! Spielt weiter Runden, bis wir einen Sieger haben!", -- Space_Invasion
["Team’s best heights per round"]="Die Besthöhen der Teams pro Runde",
["Team's best time: %.3fs"] = "Team-Bestzeit: %.3fs", -- Utils
["Team's longest time: %.3fs"] = "Längste Zeit des Teams: %.3fs", -- Utils
["Team's top accuracy: %d%"] = "Beste Treffgenauigkeit des Teams: %d%", -- Utils
["Teamwork 2"] = "Teamwork 2", -- User_Mission_-_Teamwork_2
["Teamwork"] = "Teamwork", -- User_Mission_-_Teamwork
["TechRacer"] = "TechRacer", -- TechRacer
["Teleporation Node"]="Teleporterstation",
["Teleportation Node: Allows teleportation|    between other nodes."] = "Teleportationsstation: Ermöglicht Teleportation|    zwischen anderen Stationen.", -- Construction_Mode
["Teleportation Node"]="Teleportationsstation",
["Teleport hint: Just use the mouse to select the destination!"] = "Teleportertipp: Benutze einfach den Mauszeiger, um das Ziel auszuwählen!", -- A_Classic_Fairytale:dragon
["Teleport to the impact location."] = "Teleportier dich zum Einschlagskrater.", -- Continental_supplies
["Teleport to the top of the map, expect fall damage!"] = "Teleportier dich nach ganz oben, rechne mit Fallschaden!", -- Continental_supplies
["Teleport unsuccessful. Please teleport within a clan teleporter's sphere of influence."] = "Teleportation fehlgeschlagen. Bitte teleportiere dich nur im Einzugsbereich der Teleporter deines Klans.", -- Construction_Mode
["Tentacle Terror"] = "Tentakel-Terror", -- Tentacle_Terror
["Textile industry: Will give you a parachute every second turn."] = "Textilindustrie: Gibt dir einen Fallschirm alle 2 Züge.", -- Continental_supplies
["Thanks!"]="Danke!",
["Thanks, dude! It really means a lot to me."] = "Danke, Mann! Das bedeutet mir wirklich sehr viel.", -- A_Classic_Fairytale:epil
["Thanks, man! It really means a lot to me."] = "Danke, Mann! Das bedeutet mir wirklich sehr viel.", -- A_Classic_Fairytale:epil
["Thank you, Dr. Cornelius."]="Danke, Dr. Cornelius!", -- A_Space_Adventure:cosmos
["Thank you for meeting me on such a short notice!"]="Danke, dass du mich so kurzfristig getroffen hast!",
["Thank you, my hero!"]="Danke dir, mein Held!",
["Thank you, oh, thank you, Leaks A Lot!"]="Danke, oh, danke, Undichte Stelle!",
["Thank you, oh, thank you, my heroes!"]="Habt Dank, oh, habt Dank, meine Helden!",
["Thanta"]="Thanta",
["That is, indeed, very weird..."]="Das ist tatsächlich sehr merkwürdig.",
["That makes it almost invaluable!"]="Das macht es fast unbezahlbar!",
["That ought to show them!"]="Das wird ihnen eine Lehre sein!",
["That's all, folks!"] = "Das war’s, Leute!", -- A_Classic_Fairytale:epil
["That's for my father!"]="Das ist für meinen Vater!",
["That shaman sure knows what he's doing!"]="Dieser Schamane weiß genau, was er tut!",
["That Sinking Feeling"]="Land unter",
["That's just the way it works, you know."] = "So laufen die Dinge halt, versteht ihr?", -- A_Classic_Fairytale:queen
["That's not our problem!"]="Das ist nicht unser Problem!",
["That's typical of you!"]="Das ist so typisch für euch!",
["That's why he always wears a hat since then."]="Deshalb trägt er seitdem immer einen Hut.",
["That traitor won't be killing us anymore!"] = "Der Verräter wird uns nicht mehr ermorden!", -- A_Classic_Fairytale:queen
["That was just mean!"]="Das war einfach nur gemein!",
["That was pointless. The flag will respawn next round."] = "Das war sinnlos. Die Flagge wird nächste Runde wieder auftauchen.", -- CTF_Blizzard, CTF_Blizzard
["The adventure begins!"]="Das Abenteuer beginnt!",
["The air bombs are weaker than usual."] = "Die Luftbomben sind schwächer als normal.", -- Battalion
["The aliens respect me, even worship me!"] = "Die Außerirdischen respektieren mich, ja sie beten mich sogar an!", -- A_Classic_Fairytale:queen
["The ally units share their ammo."]="Die verbündeten Einheiten teilen sich ihre Munition.",
["The ammo of %s has been vaporized"] = "Die Munition von %s wurde vaporisiert", -- Construction_Mode
["The answer is ... entertainment. You'll see what I mean."] = "Die Antwort lautet: Unterhaltung. Du wirst verstehen, was ich meine.", -- A_Classic_Fairytale:backstab
["The anti-portal surface is all over the floor, and I have nothing to kill him. Dropping something could hurt him enough to kill him."] = "Die Anti-Portal-Oberfläche ist auf dem ganzen Boden verteilt und ich habe nichts, um ihn zu töten. Wenn ich etwas auf ihn fallen lassen könnte, könnte es ihn genug verletzen, um ihn zu töten.", -- portal
["The big bang"]="Der große Knall",
["The Boss"] = "Der Boss", -- 
["The boss has fallen! Retreat!"]="Der Anführer ist gefallen! Rückzug!",
["The Bull's Eye"]="Ins Schwarze",
["The caves are well hidden, they won't find us there!"]="Die Höhlen sind gut versteckt, sie werden uns hier nicht finden!",
["The clan of the Red Strawberry wants to take over the dominion and overthrow King Pineapple."]="Der Klan der Roten Erdbeere will die Herrschaft an sich reißen und König Ananas stürzen.",
["The continent of cowards"] = "Der Kontinent der Feiglinge", -- Continental_supplies
["The continent of dust"] = "Der Kontinent des Staubes", -- Continental_supplies
["The continent of firearms"] = "Der Kontinent der Schusswaffen", -- Continental_supplies
["The continent of greed"] = "Der Kontinent der Gier", -- Continental_supplies
["The continent of guerilla tactics"] = "Der Kontinent der Guerillataktik", -- Continental_supplies
["The continent of ice and science"] = "Der eisige Kontinent der Wissenschaft", -- Continental_supplies
["The continent of medicine"] = "Der Kontinent der Medizin", -- Continental_supplies
["The continent of ninjas"] = "Der Kontinent der Ninjas", -- Continental_supplies
["The continent of sports"] = "Der Kontinent des Sports", -- Continental_supplies
["The Crate Frenzy"]="Der Kistenrausch",
["The Customer is King"] = "Der Kunde ist König", -- Challenge_-_Speed_Shoppa_-_ShoppaKing
["the Desert Planet"]="der Wüstenplanet",
["The device part has been stolen!"] = "Das Geräteteil wurde gestohlen!", -- A_Space_Adventure:fruit02
["The device part is hidden in one of the crates! Go and get it!"]="Das Bauteil ist in eine der Kisten versteckt. Geh und hole es!",
["The Devs"] = "Die Proggers", -- 
["The Dilemma"]="Das Dilemma",
["The editor weapons and tools have been added!"]="Die Editorwaffen und -werkzeuge wurden hinzugefügt!",
["The editor weapons and tools have been removed!"]="Die Editorwaffen und -werkzeuge wurden entfernt!",
["The enemies aren't many anyway, it is going to be easy!"]="Es sind eh nicht so viele Feinde, es wird einfach sein!",
["The enemy can't move but it might be a good idea to stay out of sight!"] = "Der Feind kann sich nicht bewegen, aber du solltest besser aus der Schusslinie bleiben!", -- A_Classic_Fairytale:dragon
["The enemy has taken a crate which we really needed!"] = "Der Feind hat sich eine Kiste geholt, die wir wirklich gebraucht hätten!", -- SimpleMission
["The enemy hogs play in a random order."] = "Die Feinde spielen in zufälliger Reihenfolge.", -- A_Space_Adventure:death02
["The enemy is hiding out on yonder ducky!"]="Der Feind versteckt sich auf dem Entlein dort drüben!",
["The Enemy Of My Enemy"]="Der Feind meines Feindes",
["The explosion is weaker than usual."] = "Die Explosion ist schwächer als gewöhnlich.", -- Battalion
["The fastest hedgehog was %s from %s with a time of %.3fs."] = "Der schnellste Igel war %s von %s mit einer Zeit von %.3fs.", -- TrophyRace
["The fight begins!"]="Die Schlacht beginnt!",
["The final part"]="Das letzte Bauteil",
["The final targets are quite tricky. You need to aim well."] = "Die letzten Zielscheiben sind echt knifflig. Du musst gut zielen.", -- Basic_Training_-_Bazooka
["The First Blood"]="Der erste Zusammenstoß",
["The First Encounter"]="Das erste Zusammentreffen",
["The first hedgehog to kill someone becomes the Mutant."] = "Der erste Igel, der einen anderen tötet, mutiert.", -- Mutant
["The first stop"]="Der erste Halt",
["The first turn will last 25 sec and every other turn 15 sec"]="Der 1. Zug wird 25 Sek., jeder andere Zug 15 Sek. dauern",
["The first turn will last 25 sec and every other turn 15 sec."]="Der 1. Zug wird 25 Sek., jeder andere Zug 15 Sek. dauern.",
["The flag will respawn next round."]="Die Flagge wird nächste Runde wieder auftauchen.",
["The flood has stopped! Challenge over."] = "Die Flut ist vorbei! Herausforderung beendet.", -- User_Mission_-_That_Sinking_Feeling
["The food bites back"]="Das Essen beißt zurück",
["The forgotten continent"] = "Der vergessene Kontinent", -- Continental_supplies
["the Fruit Planet"]="der Obstplanet",
["The giant umbrella from the last crate should help break the fall."]="Der Riesenschirm aus der letzten Kiste sollte helfen, den Sturz abzubremsen.",
["The Great Escape"]="Gesprengte Ketten",
["- The green target must survive"] = "- Das grüne Ziel muss überleben", -- HedgeEditor
["- The green targets must survive"] = "- Die grünen Ziele müssen überleben", -- HedgeEditor
["The guardian"]="Der Wächter",
["The hardships of the war turned %s (%s) into a killing machine: %d invaders destroyed in one round!"] = "Die Grauen des Krieges verwandelten %s (%s) in eine Tötungsmaschine: %d Invasoren in einer Runde getötet!", -- Space_Invasion
["The health of your current hedgehog|is shown at the top right corner."] = "Die Gesundheit deines aktiven Igels|wird oben rechts angezeigt.", -- Basic_Training_-_Movement
["The hedgehog with least points (or most deaths) becomes the Bottom Feeder."] = "Der Igel mit den wenigsten Punkten (oder meisten Toden) wird zum Versager.", -- Mutant
["The Hospital"] = "Das Krankenhaus", -- 
["the Ice Planet"]="der Eisplanet",
["The Individualist"]="Der Individualist",
["Their buildings were very primitive back then, even for an uncivilised island."]="Ihre Gebäude waren damals sehr primitiv, selbst für eine unzivilisierte Insel.",
["The Iron Curtain"] = "Der eiserne Vorhang", -- 
["The Journey Back"]="Die Rückreise",
["The king of %s has died!"] = "Der König von %s ist gestorben!", -- Battalion
["The last encounter"]="Das letzte Gefecht",
["The last surviving clan wins."] = "Der letzte überlebende Klan gewinnt.", -- TrophyRace
["The leader escaped. Defeat the rest of the aliens!"] = "Der Anführer floh. Besieg den Rest der Außerirdischen.", -- A_Classic_Fairytale:queen
["The leader seems scared, he will probably flee."] = "Der Anführer scheint verängstigt zu sein, er wird wahrscheinlich fliehen.", -- A_Classic_Fairytale:queen
["The Leap of Faith"]="Der Mutsprung",
["the meteorite"]="der Meteorit",
["The meteorite has come too close and the anti-gravity device isn't powerful enough to stop it now."]="Der Meteorit kam zu nah und das Antischwerkraftgerät ist zu schwach, um ihn jetzt zu stoppen.",
["the moon"]="der Mond",
["The Moonwalk"]="Der Mondspaziergang",
["The Mutant has super weapons and a lot of health."] = "Der Mutant hat Superwaffen und eine hohe Gesundheit.", -- Mutant
["The Mutant loses health quickly, but gains health by killing."] = "Der Mutant verliert schnell Gesundheit, heilt sich aber für jeden Abschuss.", -- Mutant
["The Navy greets %s for managing to get in a distance of %d away from the mainland!"]="Die Marine grüßt %s für einen Abstand von %d vom Festland!",
["The next 4 times you play the \"The last encounter\" mission you'll get 20 more hit points and a laser sight."]="Die nächsten 4 Male, die du die Mission »Das letzte Gefecht« spielst, wirst du 20 weitere Trefferpunkte und ein Laservisier erhalten.",
["The next crate is an utility crate."] = "Die nächste Kiste ist eine Werkzeugkiste.", -- Basic_Training_-_Movement
["The next target can only be reached by something called “bouncing bomb”."] = "Die nächste Zielscheibe kann nur von einer »hüpfenden Bombe« erreicht werden.", -- Basic_Training_-_Bazooka
["The next target is high in the sky."] = "Die nächste Zielscheibe ist hoch im Himmel.", -- Basic_Training_-_Bazooka
["Then how do they keep appearing?"]="Also woher kommen sie?",
["The Ninja-Samurai Alliance"] = "Die Ninja-Samurai-Allianz", -- 
["Then prepare for battle!"]="Dann mach dich bereit für die Schlacht!",
["Then what am I?"] = "Was bin ich dann?", -- A_Classic_Fairytale:epil
["The only woman, huh?"] = "Die einzige Frau, wie?", -- A_Classic_Fairytale:epil
["The oppression of the elders, of course!"] = "Die Unterdrückung der Ältesten natürlich!", -- A_Classic_Fairytale:queen
["The other hog has died, he should have survived!"] = "Der andere Igel ist gestorben, er hätte überleben müssen!", -- A_Space_Adventure:moon02
["The other one were all cannibals, spending their time eating the organs of fellow hedgehogs..."]="Der andere Stamm bestand nur aus Kannibalen, sie verbrachten ihre Zeit damit, die Organe anderer Igel aufzufressen.",
["The part device is hidden in one of the crates! Go and get it!"]="Das Bauteil ist in einer der Kisten versteckt. Geh und hole es!",
["the Planet of Death"]="der Todesplanet",
["The Police"] = "Die Polizei", -- 
["The power of love! No, wait, the power of the aliens!"] = "Die Macht der Liebe! Ach, Quatsch, die Macht der Aliens!", -- A_Classic_Fairytale:queen
["The RC plane only carries 2 weak bombs."] = "Das Funkflugzeug trägt nur 2 schwache Bomben.", -- Battalion
["There are a variety of structures available to aid you."]="Es gibt verschiedene Gebäude, um dich zu unterstützen.",
["There are no snarky comments this time."] = "Diesmal gibt es keine hämischen Kommentare.", -- Space_Invasion
["There is one below us!"]="Da ist eine unter uns!",
["There is the tunnel entrance"]="Hier ist der Tunneleingang.",
["There must be a spy among us!"]="Es muss ein Spion unter uns sein!",
["There's more of them? When did they become so hungry?"]="Es gibt mehr von ihnen? Seit wann wurden sie so hungrig?",
["There's nothing more satisfying for me than seeing you share your beauty with the world every morning, my princess!"]="Es gibt nichts befriedigenderes für mich, als dich jeden Morgen zu sehen, wie du deine Schönheit mit dem Rest der Welt teilst, meine Prinzessin!",
["There's nothing more satisfying to us than seeing you share your beauty..."]="Es gibt nichts befriedigenderes für uns, als dich jeden Morgen zu sehen, wie du deine Schönheit …",
["There's nothing more satisfying to us than seeing you share your beauty with the world every morning, my princess!"]="Es gibt nichts befriedigenderes für uns, als dich jeden Morgen zu sehen, wie du deine Schönheit mit dem Rest der Welt teilst, meine Prinzessin!",
["The respawner respawns %s"] = "Der Wiederbeleber belebt %s wieder", -- Construction_Mode
["The Rising"]="Der Aufstieg",
["The Savior"]="Der Erlöser",
["The score and deaths are shown next to the team bar."] = "Die Punkte und Tode werden neben der Teamleiste angezeigt.", -- Mutant
["These girders are slippery, like ice."] = "Diese Träger sind so rutschig wie Eis.", -- Basic_Training_-_Movement
["These primitive people are so funny!"]="Diese primitiven Leute sind so lustig!",
["These weapon specials cannot be used close to other hogs."] = "Diese Waffenextras können nicht in der Nähe anderer Igel benutzt werden.", -- Continental_supplies
["The Shadow Falls"]="Die Schattenfälle",
["The Showdown"]="Das Showdown",
["The Slaughter"]="Die Schlachtung",
["The Society of Perfectionists greets %s (%s): No misses and %d hits in its best round."] = "Die Gesellschaft der Perfektionisten grüßt %s (%s): In der besten Runde %d Treffer, kein Schuss ging daneben.", -- Space_Invasion
["The Specialists: Each hedgehog starts with its own weapon set"] = "Die Spezialisten: Jeder Igel startet mit seinen eigenen Waffen", -- The_Specialists
["The spinning arrows above your hedgehog show|which hedgehog is selected right now."] = "Die rotierenden Pfeile über deinen Igel zeigen an,|welcher Igel jetzt ausgewählt ist.", -- Basic_Training_-_Movement
["The spirits of the ancestors are surely pleased, Leaks A Lot."] = "Die Geister der Ahnen sind sicherlich erfreut, Undichte Stelle.", -- A_Classic_Fairytale:first_blood
["The targets will guide you through the training."] = "Die Zielscheiben führen dich durch die Übung.", -- Basic_Training_-_Rope
["The team continued their quest of finding the rest of the tribe."] = "Das Team setzte die Suche nach dem Rest ihres Stammes fort.", -- A_Classic_Fairytale:queen
["The teams are tied for the fastest time."] = "Die Teams hatten die gleich schnellste Zeit.", -- Racer, TechRacer
["The teams were tied, so an additional round has been played to determine the winner."] = "Die Teams hatten Gleichstand, also wurde eine weitere Runde gespielt, um den Sieger zu bestimmen.", -- Space_Invasion
["The teams were tied, so %d additional rounds have been played to determine the winner."] = "Die Teams hatten Gleichstand, also wurden %d weitere Runden gespielt, um den Sieger zu bestimmen.", -- Space_Invasion
["The time that you have left when you reach the blue hedgehog will be added to the next turn."]="Deine verbleibende Zeit wird zu deinem nächsten Zug addiert, sobald du den blauen Igel erreichst.",
["The Torment"]="Die Qual",
["The truth about Professor Hogevil"]="Die Wahrheit über Professor Bösigel",
["The tunnel entrance is over there."] = "Der Eingang zum Tunnel ist dort drüben!", -- A_Space_Adventure:desert01
["The tunnel is about to get flooded!"]="Der Tunnel wird gleich geflutet!",
["The Tunnel Maker"]="Der Tunnelbauer",
["The Ultimate Weapon"]="Die Ultimative Waffe",
["The Union"]="Die Einheit",
["The Union: You can select a hedgehog at the start of your turns."] = "Die Vereinigung: Du kannst einen Igel zu Zugbeginn auswählen.", -- Continental_supplies
["The village, unprepared, was destroyed by the cyborgs..."]="Das unvorbereitete Dorf wurde von den Cyborgs zerstört.",
["The walk of Fame"]="Die Ruhmesmeile",
["The wasted youth"]="Die vergeudete Jugend",
["The way you handled your little internal conflicts …"] = "Wie ihr euren kleinen internen Konflikte gehandhabt habt …", -- A_Classic_Fairytale:queen
["The weapon in that last crate was bestowed upon us by the ancients!"]="Die Waffe in der letzten Kiste wurde uns von den Urahnen übergeben!",
["The what?!"]="Das was?!",
["The wind whispers that you are ready to become familiar with tools, now..."]="Der Wind flüstert, dass du jetzt bereit bist, mit den Werkzeugen vertraut zu werden.",
["The wrong hedgehog has taken the crate."] = "Der falsche Igel hat sich die Kiste genommen.", -- SimpleMission
["They are all waiting back in the village, haha."]="Sie warten alle im Dorf, haha.",
["They are up there! Take this rope and hurry!"]="Sie sind da oben! Nimm dieses Seil und beeil dich!",
["They Call Me Bullseye! +16 points!"] = "Sie nennen mich »Adlerauge«! +16 Punkte!", -- Space_Invasion
["They have weapons we've never seen before!"]="Sie haben Waffen, die wir noch nie zuvor gesehen haben!",
["They keep appearing like this. It's weird!"]="Sie tauchen einfach so auf. Es ist seltsam!",
["They killed %s! You bastards!"] = "Sie haben %s getötet! Ihr Schweine!", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
["They must be trying to weaken us!"]="Sie müssen versuchen, uns zu schwächen!",
["They never learn"]="Sie lernen es nie",
["They stumbled upon a pile of weapons, they seemed to be getting closer."] = "Sie stolperten über einen Stapel voller Waffen und schienen näher zu kommen.", -- A_Classic_Fairytale:queen
["They told us to wear these clothes. They said that this is the newest trend."]="Sie sagten uns, dass wir diese Kleidung tragen sollten. Sie sagten, dass es der neueste Trend sei.",
["They've been manipulating us all this time!"]="Sie haben uns die ganze Zeit manipuliert!",
["They won't hesitate to attack you in order to rob you!"]="Sie werden nicht zögern, dich anzugreifen, um dich auszurauben!",
["The Zoo"] = "Der Zoo", -- 
["Thighlicker"]="Schenkelschlecker",
["Things are going to get messy around here."]="Es wird hier gleich richtig hässlich werden.",  -- A_Space_Adventure:fruit01
["This allows to select any hedgehog in your team!"] = "Damit kannst du einen beliebigen Igel in deinem Team auswählen.", -- Basic_Training_-_Movement
["This allows you to create a crate anywhere|within your clan's area of influence,|at the cost of energy."] = "Hiermit erzeugst du eine Kiste an einem|beliebigen Ort im Einflussgebiet deines Klans,|auf Kosten von Energie.", -- Construction_Mode
["This allows you to create and place mines,|sticky mines and barrels anywhere within your|clan's area of influence at the cost of energy."] = "Damit kannst du Minen, Haftminen, und Fässer|innerhalb des Einflussbereichs deines Klans|erzeugen und platzieren, auf Kosten von Energie.", -- Construction_Mode
["This almost concludes our tutorial."] = "Damit ist unsere Übung fast abgeschlossen.", -- Basic_Training_-_Flying_Saucer
["This also increases the effectiveness of Medicine."] = "Dies erhöht außerdem die Wirksamkeit von Medizin.", -- Continental_supplies
["This game wasn’t really exciting."] = "Diese Runde war nicht so aufregend.", -- Space_Invasion
["This is a new personal best, congratulations!"] = "Das ist eine neue persönliche Bestleistung, Gratulation!", -- A_Space_Adventure:death02, A_Space_Adventure:desert02, A_Space_Adventure:fruit03
["This is a new personal best time, congratulations!"] = "Das ist eine neue persönliche Bestzeit, Gratulation!", -- A_Space_Adventure:ice02, A_Space_Adventure:moon02
["This is Cappy."] = "Das ist Käppi.", -- Basic_Training_-_Movement
["This is it! It's time to make Fell From Heaven fall for me..."]="Das ist es! Es ist an der Zeit, Fiel Vom Himmel in mich verfallen zu lassen …",
["This island is the only place left on Earth with grass on it!"]="Diese Insel ist der einzige Ort auf der Welt, der noch Gras hat!",
["This is the mission panel."] = "Dies ist die Missionsanzeige.", -- Basic_Training_-_Movement
["This is the Olympic Stadium of Saucer Flying."] = "Dies ist das Olympische Stadion des Untertassenflugs.", -- A_Space_Adventure:ice02
["This is the wrong way!"]="Das ist die falsche Richtung!",
["This is typical!"]="Typisch!",
["This must be some kind of sorcery!"]="Das muss wohl eine Art Zauberei sein!",
["This must be the caves!"]="Dies müssen die Höhlen sein!",
["This one's tricky."]="Die hier ist knifflig.",
["This planet seems dangerous!"]="Dieser Planet scheint gefährlich zu sein!",
["This rain is really something..."]="Das nenne ich mal einen Regenschauer …",
["This round’s award for ultimate disappointment goes to: Everyone!"]="Der ultimative Enttäuschungspreis geht in dieser Runde an: alle!",
["This seems like a wealthy hedgehog, nice ..."] = "Das scheint ein reicher Igel zu sein, nett …", -- A_Space_Adventure:desert01
["This %s is so naive! I'm going to shoot this fool so I can keep that device for myself!"] = "%s ist so naiv! Ich werde diesen Deppen abknallen, damit ich das Gerät für mich behalten kann!", -- A_Space_Adventure:fruit02
["This was an awesome performance! But this challenge can be finished with even just one RC plane. Can you figure out how?"]="Das war eine großartige Vorstellung! Aber diese Herausforderung kann sogar mit nur einem Funkflugzeug gemeistert werden. Kannst du herausfinden, wie?",
["This will be fun!"]="Das wird Spaß machen!",
["This will be useful when I need a new platform or if I want to rise."] = "Das wird sich als nützlich erweisen, wenn ich eine neue Plattform brauche oder ich nach oben muss.", -- portal
["This will certainly come in handy."] = "Das wird bestimmt nützlich sein.", -- User_Mission_-_Teamwork_2
["Thompson"] = "Thomas", -- 
["Those aliens are destroying the island!"]="Diese Außerirdischen zerstören die Insel!",
["Those were scheduled for disposal anyway."] = "Sie waren eh für den Schrottplatz bestimmt.", -- A_Classic_Fairytale:dragon
["Throw a 1 second mine!"] = "Wirf eine 1-Sekunden-Mine!", -- Continental_supplies
["Throw a baseball at your foes|and send them flying!"] = "Wirf einen Baseball auf deine|Gegner und lass sie fliegen!", -- Knockball
["Throw a grenade to destroy the target!"] = "Wirf eine Granate, um die Zielscheibe zu zerstören!", -- Basic_Training_-_Grenade
["Thug #%d"] = "Rowdy %d", -- A_Space_Adventure:death01
["thug"]="Rowdy",
["Tie-breaking round %d"] = "%d. Stichrunde", -- Space_Invasion
["Timbers"] = "Holz", -- 
["Time: %.1fs"] = "Zeit: %.1fs", -- Racer, TechRacer
["Time: %.3fs by %s"] = "Zeit: %.3fs von %s", -- TrophyRace
["Time: %.3fs"] = "Zeit: %.3fs", -- TrophyRace
["Timed Kamikaze! +10 points!"] = "Rechtzeitiges Kamikaze: +10 Punkte!", -- Space_Invasion
["Time extended! +%dsec"] = "Zeitbonus! +%ds", -- Space_Invasion
["Time extension: %ds"] = "Zeitbonus: %ds", -- Tumbler
["Time for a more interesting stunt, but first just collect the next crate!"] = "Zeit für einen interessanteren Stunt, aber sammle zuerst die nächste Kiste auf!", -- Basic_Training_-_Flying_Saucer
["Timer"] = "Zeitzünder", -- Basic_Training_-_Grenade
["Time's up!"]="Die Zeit ist um!",
["Time’s up!"]="Die Zeit ist um!",
["Time to run!"]="Zeit, zu fliehen!",
["Tip: Changing your aim while flying is very difficult, so adjust it before you take off."] = "Tipp: Es ist sehr schwer, beim Fliegen die Zielrichtung zu ändern,|also pass sie an, bevor du abhebst.", -- Basic_Training_-_Flying_Saucer
["Tip: Don't remain for too long in the water, or you won't make it."] = "Tipp: Bleib nicht zu lang im Wasser, sonst schaffst du es nicht.", -- Basic_Training_-_Flying_Saucer
["Tip: If you get stuck in this training, use \"Skip turn\" to restart the current objective."] = "Tipp: Wenn du hängenbleibst, benutze »Zug überspringen«,|um das aktuelle Ziel erneut zu versuchen.", -- Basic_Training_-_Flying_Saucer
["Tip: You can change your flying saucer|in mid-flight by hitting the [Attack] key twice."] = "Tipp: Du kannst die fliegende Untertasse|im Flug wechseln, drücke einfach [Angriff] zwei mal.", -- Basic_Training_-_Flying_Saucer
["Tiyuri"] = "Tiyuri", -- 
["Toad"] = "Toad", -- 
["To begin, walk to the crate to the right."] = "Um loszulegen, geh zur Kiste rechts.", -- Basic_Training_-_Movement
["To begin with the training, hit the attack key!"] = "Um mit der Übung anzufangen, drücke die Angriffstaste.", -- Basic_Training_-_Movement
["To begin with the training, select the bazooka from the ammo menu!"] = "Um mit dem Training anzufangen, wähl die Bazooka aus dem Munitionsmenü aus!", -- Basic_Training_-_Bazooka
["To begin with the training, select the grenade from the ammo menu!"] = "Um mit dem Training anzufangen, wähl die Granate aus dem Munitionsmenü aus!", -- Basic_Training_-_Grenade
["To begin with the training, tap the attack button!"] = "Um mit dem Training anzufangen, tippe die Angriffstaste an!", -- Basic_Training_-_Movement
["To finish hedgehog selection, just do anything|with him, like walking."] = "Um die Igelwahl zu beenden, mach irgendwas mit dem Igel, z.B. gehen.", -- Basic_Training_-_Movement
["To get over the next obstacles, keep some distance from the wall before you back jump."] = "Um über die nächsten Hindernisse zu kommen, halte etwas Abstand von der Wand,|bevor du rückwärts springst.", -- Basic_Training_-_Movement
["To get over the water, you have to do multiple|rope shots and swings."] = "Um über das Wasser zu gelangen, brauchst du mehrere Seilschüsse|und musst mehrfach schwingen.", -- Basic_Training_-_Rope
["Toggle Editing Weapons and Tools: [Precise]+[2]"] = "Editorwaffen- und Werkzeuge umschalten: [Genaues Zielen]+[2]", -- HedgeEditor
["Toggle Editing Weapons and Tools: Precise+2"]="Waffen- und Werkzeugbearbeitung umschalten: Genaues Zielen + 2",
["Toggle Help: Precise+1"]="Hilfe umschalten: Genaues Zielen + 1",
["Toggle Help: [Precise]+[1]"] = "Hilfe umschalten: [Genaues Zielen]+[1]", -- HedgeEditor
["Toggle Help: Precise+1 (While a tool is selected)"]="Hilfe umschalten: Genaues Zielen + 1 (Während ein Werkzeug ausgewählt ist)",
["Toggle Placement/Deletion: [Left], [Right]"] = "Platzierungs-/Löschmodus umschalten: [Links], [Rechts]", -- HedgeEditor
["Toggle Shield: [Long jump]"] = "Schild umschalten: [Weitsprung]", -- Space_Invasion
["To help you, of course!"]="Natürlich, um dir zu helfen!",
["To launch a projectile in mid-flight, hold [Precise] and press [Long jump]."] = "Um ein Projektil im Flug zu starten, halte [Genaues Zielen] gedrückt|und drücke [Weitsprung].", -- Basic_Training_-_Flying_Saucer
["Tony"] = "Toni", -- 
["Too bad! Then you should really leave!"] = "Schade. Dann solltest du wirklich gehen!", -- A_Space_Adventure:fruit01
["Too slow! Try again ..."]="Zu langsam! Versuch es nochmal.",
["Top-class elite pilot"]="Elitepilot der Spitzenklasse",
["To reach higher ground, walk to a ledge, look to the left, then do a back jump."] = "Um auf höheres Gelände zu kommen, geh zur Kante,|blicke nach links und mach einen Rückwärtssprung.", -- Basic_Training_-_Movement
["Torn Muscle"]="Loser Muskel",
["To the caves..."]="Zu den Höhlen …",
["Touch all waypoints as fast as you can!"] = "Berühre alle Wegpunkte so schnell du kannst!", -- Racer
["- Touch the sparkles near your base to teleport"] = "- Berühre die Funken in der Nähe deiner Basis zum Teleportieren", -- CTF_Blizzard
["To win the game, %s has to get the bottom crates and come back to the surface."] = "Um das Spiel zu gewinnen, muss %s die unteren Kisten erreichen und zurück an die Oberfläche gelangen.", -- A_Space_Adventure:fruit02
["To win the game you had to collect the 2 crates with no specific order."]="Um das Spiel zu gewinnen, musstest du die 2 Kisten in beliebiger Reihenfolge einsammeln.",
["To win the game you have to eliminate Professor Hogevil."] = "Um das Spiel zu gewinnen, musst du Professor Bösigel eliminieren.", -- A_Space_Adventure:death01
["To win the game you have to find the right crate."]="Um das Spiel zu gewinnen, musst du die richtige Kiste finden.",
["To win the game you have to go next to Thanta."]="Um das Spiel zu gewinnen, musst du neben Thanta stehen.",
["To win the game you have to go to the surface."]="Um das Spiel zu gewinnen, musst du an die Oberfläche gelangen.",
["To win the game you have to pass into the rings in time"]="Um das Spiel zu gewinnen, musst du rechtzeitig durch die Ringe fliegen",
["To win the game you have to pass into the rings in time."]="Um das Spiel zu gewinnen, musst du rechtzeitig durch die Ringe fliegen.",
["To win the game you have to stand next to Thanta."] = "Um das Spiel zu gewinnen, musst du neben Thanta stehen.", -- A_Space_Adventure:ice01
["Toxic Team"]="Giftige Gegner",
["Track completed!"] = "Strecke durchlaufen!", -- Racer, TechRacer
["Training complete!"] = "Übung abgeschlossen!", -- Basic_Training_-_Flying_Saucer
["Training"] = "Übung", -- Basic_Training_-_Flying_Saucer, Basic_Training_-_Rope
["Traitors don't get to shout around here!"] = "Verräter haben hier nicht das Recht, herumzubrüllen!", -- A_Classic_Fairytale:epil
["Traitors"]="Verräter",
["Trapper"]="Trapper",
["Travel carefully as your fuel is limited"]="Reise vorsichtig, da dein Treibstoff begrenzt ist.",
["Travel to all the neighbor planets and collect all the pieces"]="Reise zu allen Nachbarplaneten und sammle alle Bauteile ein.",
["Treasure: Massive weapon bonus in first turn."] = "Schatz: Riesiger Waffenbonus im ersten Zug.", -- Continental_supplies
["Tribe"]="Stamm",
["TrophyRace"]="TrophyRace",
["Trunks"] = "Rüssel", -- 
["Try again!"] = "Versuch es noch mal!", -- Basic_Training_-_Flying_Saucer
["Try it now and dive here to collect the crate on the right girder."] = "Versuch es jetzt und tauch hier ab, um die Kiste auf dem rechten Träger aufzusammeln.", -- Basic_Training_-_Flying_Saucer
["Try not to get spotted by the guards!"]="Versuch, von den Wächtern unentdeckt zu bleiben!",
["Try out different bounciness levels to reach difficult targets."] = "Probiere mehrere Sprungstärken aus, um verschiedene Ziele zu treffen.", -- Basic_Training_-_Grenade
["Try to be smart and eliminate them quickly. This way you might scare off the rest!"]="Versuch, schlau zu sein und sie schnell zu erledigen. Auf diese Weise könntest du den Rest abschrecken!",
["Try to keep as many allies alive as possible."]="Versuch, so viele Verbündete wie möglich am Leben zu erhalten.",
["Try to land softly, as you can still take fall damage!"] = "Lande vorsichtig, da du immer noch Fallschaden nehmen könntest!", -- Basic_Training_-_Flying_Saucer
["Try to protect the chief! You won't lose if he dies, but it is advised that he survives."]="Versuche, den Häuptling zu beschützen! Du wirst nicht verlieren, wenn er stirbt, aber es ist ratsam, dass er überlebt.",
["Try to reach and destroy the next target quickly."] = "Versuch, das nächste Ziel möglichst schnell|zu erreichen und zu zerstören.", -- Basic_Training_-_Rope
["Tumbler"] = "Purzler", -- Tumbler
["Turn around: [Left Shift] + [Left]/[Right]"] = "Umdrehen: [Umschalt links] + [Links]/[Rechts]", -- Basic_Training_-_Movement
["Turning Around"] = "Umdrehen", -- Basic_Training_-_Movement
["Turns: Hogs get %d random weapon(s) from their pool"] = "Züge: Igel erhalten %d zufällige Waffe(n) aus ihrem Waffenpool", -- Battalion
["Turns: King's health is set to %d%% of the team health"] = "Züge: Königsgesundheit ist %d%% der Teamgesundheit", -- Battalion
["Turns left: %d"] = "Verbleibende Züge: %d", -- A_Classic_Fairytale:journey
["Turns: Refill %d weapon and %d helper points|and randomize weapons and helpers based on team points"] = "Züge: Füllen %d Waffen- und %d Helferpunkte auf und verteilen|Waffen zufällig, basierend auf den vorhandenen Teampunkten", -- Battalion
["Turns until arrival: %d"] = "Züge bis zur Ankunft: %d", -- A_Classic_Fairytale:backstab
["Turns until Sudden Death: %d"] = "Züge bis Sudden Death: %d", -- A_Classic_Fairytale:dragon
["Twenty-Twenty"] = "Zwanzig-Zwanzig", -- 
["Two flowers: All missions complete"] = "Zwei Blumen: Alle Missionen abgeschlossen", -- A_Space_Adventure:cosmos
["Two little hogs cooperating, getting past obstacles..."]="Zwei Igelchen, sie arbeiten zusammen, bewältigen Hindernisse gemeinsam …",
["Ugly Mug"] = "Schmutzkrug", -- 
["Uhm...I met one of them and took his weapons."]="Ähm, ich hab einen von ihnen getroffen und nahm seine Waffen.",
["Uhmm, it's … uhm … my ring!"] = "Ähm, es ist … ähm … mein Ring!", -- A_Classic_Fairytale:queen
["Uhmm...ok no."]="Ähm, okay, nein.",
["Ukemi"] = "Ukemi", -- 
["Ultra kill!"] = "Ultra-Killer!", -- Mutant
["unC0Rr"] = "unC0Rr", -- 
["Under Construction"]="Baustelle",
["Under normal circumstances we could easily defeat them but we have kindly sent most of our men to the Kingdom of Sand to help with the annual dusting of the king's palace."]="Unter normalen Bedingungen könnten wir sie leicht besiegen, aber wir hatten freundlicherweise die meisten unserer Männer zum Sandkönigreich geschickt, um bei der jährlichen Entstaubung des Königspalasts zu helfen.",
["Under the meteorite’s shadow ..."] = "Unter dem Schatten des Meteoriten …", -- A_Space_Adventure:cosmos
["Unexpected Igor"]="Ausnahmefelix",
["Unit 0x0007"]="Einheit 0x0007",
["Unit 189"] = "Einheit 189", -- 
["Unit 234"] = "Einheit 234", -- 
["Unit 333"] = "Einheit 333", -- 
["Unit 334a$7%;.*"]="Einheit 334a$7%;,*",
["Unit 3378"]="Einheit 3378",
["Unit 485"] = "Einheit 485", -- 
["Unit 527"] = "Einheit 527", -- 
["Unit 638"] = "Einheit 638", -- 
["Unit 709"] = "Einheit 709", -- 
["Unit 835"]="Einheit 835",
["Unit 881"] = "Einheit 881", -- User_Mission_-_Newton_and_the_Hammock
["Unit 883"] = "Einheit 883", -- 
["United We Stand"]="Gemeinsam sind wir stark",
["Unlike bazookas, grenades are not influenced by wind."] = "Anders als Bazookas werden Granaten nicht vom Wind beeinflusst.", -- Basic_Training_-_Grenade
["Unlimited Attacks: Attacks don't end your turn"] = "Unbegrenzte Angriffe: Angriffe beenden deinen Zug nicht", -- User_Mission_-_Diver, User_Mission_-_Nobody_Laugh, User_Mission_-_Spooky_Tree
["Unlucky Sods"]="Arme Schweine",
["Unstoppable!"]="Unaufhaltsam!",
["Unsuspecting Louts"]="Nichtsahnende Lümmel",
["Up/Down: Adjust dust storm damage"] = "Hoch/Runter: Staubsturmschaden anpassen", -- Continental_supplies
["Up/Down: Browse through continents"] = "Hoch/Runter: Durch Kontinente blättern", -- Continental_supplies
["Up/Down: Change placement mode"] = "Hoch/Runter: Platzierungsmodus wechseln", -- HedgeEditor
["Up/down: Choose crate type"] = "Hoch/Runter: Kistentyp wählen", -- Construction_Mode
["Up/down: Choose object type|1-5/Switch/Left/Right: Choose mine timer|Cursor: Place object"] = "Hoch/Runter: Objekttyp auswählen|1-5/Wechseln/Links/Rechts: Minenzeitzünder wählen|Cursor: Objekt platzieren", -- Construction_Mode
["Upper-class elite pilot"]="Elitepilot der Oberklasse",
["Upside-Down World"] = "Verkehrte Welt", -- Continental_supplies
["Use it wisely!"]="Benutze sie weise!",
["Use it with precaution!"]="Benutze sie weise.",
["User Challenge"]="Benutzerherausforderung",
["!"] = "!", -- User_Mission_-_Dangerous_Ducklings
["User Mission"] = "Benutzermission", -- HedgeEditor
["Use space button twice to change flying saucer while being in air."]="Drücke die Angriffstaste 2 mal, um die fliegende Untertasse im Flug zu wechseln",
["Use space button twice to change flying saucer while floating in mid-air."]="Drücke die Angriffstaste 2 mal, um die fliegende Untertasse im Flug zu wechseln.",
["Use the attack key twice to change the flying saucer while being in air."] = "Benutze die Angriffstaste 2 mal, um die fliegende Untertasse in der Luft zu wechseln.", -- A_Space_Adventure:ice02
["Use the attack key twice to change the flying saucer while floating in mid-air"] = "Benutze die Angriffstaste 2 mal, um die Fliegende Untertasse während des Fluges zu wechseln", -- A_Space_Adventure:ice02
["Use the attack key twice to change the flying saucer while floating in mid-air."] = "Benutze die Angriffstaste 2 mal, um die Fliegende Untertasse während des Fluges zu wechseln.", -- A_Space_Adventure:ice02
["Use the bazooka and the flying saucer to get the freezer."] = "Benutze die Bazooka und die fliegende Untertasse, um die Eiskanone zu ergattern.", -- A_Space_Adventure:ice01
["Use the bazooka and the flying saucer to get the icegun."]="Benutze die Bazooka und die fliegende Untertasse, um die Eiskanone zu ergattern",
["Use the flying saucer from the crate to fly to the moon."] = "Benutze die fliegende Untertasse aus der Kiste, um zum Mond zu fliegen.", -- A_Space_Adventure:cosmos
["Use the flying saucer to fly to the other planets."] = "Benutze die fliegende Untertasse, um zu den anderen Planeten zu fliegen.", -- A_Space_Adventure:cosmos
["Use the parachute to get the next crate."] = "Benutze den Fallschirm, um zur nächsten Kiste zu gelangen.", -- A_Classic_Fairytale:first_blood
["Use the portal gun to get to the next crate, then use the new gun to get to the final destination!|"]="Benutze das Portalgewehr, um zur nächsten Kiste zu kommen,|dann benutze das nächste Werkzeug, um zum letzten Ziel zu kommen.|",
["Use the RC plane and destroy the all the targets"]="Benutze das Funkflugzeug und zerstöre alle Zielscheiben",
["Use the RC plane and destroy the all the targets."]="Benutze das Funkflugzeug und zerstöre alle Zielscheiben.",
["Use the rope in order to catch the blue hedgehog"]="Benutze das Seil, um den blauen Igel zu fangen.",
["Use the rope to complete the obstacle course!"] = "Benutze das Seil, um die Hindernisstrecke abzuschließen!", -- Basic_Training_-_Rope
["Use the rope to get on the head of the mole, young one!"]="Benutze das Seil, um auf den Kopf des Maulwurfs zu gelangen, Jüngling!",
["Use the rope to get to the crate"]="Benutze das Seil, um zur Kiste zu gelangen.",
["Use the rope to get to the target!"] = "Benutze das Seil, um zur Zielscheibe zu gelangen!", -- Basic_Training_-_Rope
["Use the rope to knock your enemies to their doom."]="Benutze das Seil, um deine Gegner in ihr Verderben zu stürzen!",
["Use the rope to quickly get to the surface!"]="Benutze das Seil, um schnell zur Oberfläche zu gelangen!",
["Use the saucer and fly away"]="Benutze die Untertasse und flieg davon!",
["Use the saucer and fly to the moon"]="Benutze die Untertasse und flieg zum Mond.",
["Use the saucer and pass through the rings."]="Benutze die Untertasse und passiere die Ringe.",
["Use the shield to protect yourself from bazookas."] = "Benutze das Schild, um dich vor Bazookas zu schützen.", -- Space_Invasion
["Use the structure placer to place structures."] = "Benutze den Gebäudeplatzierer, um Gebäude zu platzieren.", -- Construction_Mode
["Use this mode to give a hog a preset identity and weapons."]="Benutze diesen Modus, um einem Igel eine voreingestellte Identität sowie Waffen zu geben.",
["Use this mode to give an entire team themed hats and names."]="Benutze diesen Modus, um einem Team einen Satz Hüte und Namen zu geben.",
["Use this mode to place air mines"]="Benutze diesen Modus, um Luftminen zu platzieren",
["Use this mode to place barrels"]="Benutze diesen Modus, um Pulverfässer zu platzieren",
["Use this mode to place cleavers"]="Benutze diesen Modus, um Hackebeile zu platzieren",
["Use this mode to place custom sprites."]="Benutze diesen Modus, um benutzerdefinierte Sprites zu platzieren.",
["Use this mode to place girders"]="Benutze diesen Modus, um Bauträger zu platzieren",
["Use this mode to place mines"]="Benutze diesen Modus, um Minen zu platzieren",
["Use this mode to place rubberbands"]="Benutze diesen Modus, um Gummibalken zu platzieren",
["Use this mode to place sticky mines"]="Benutze diesen Modus, um Haftminen zu platzieren",
["Use this mode to place targets"]="Benutze diesen Modus, um Zielscheiben zu platzieren",
["Use this mode to place utility crates"]="Benutze diesen Modus, um Werkzeugkisten zu platzieren",
["Use this mode to place weapon crates"]="Benutze diesen Modus, um Waffenkisten zu platzieren",
["Use this mode to select and reposition gears"]="Benutze diesen Modus, um Gears auszuwählen und zu verlegen",
["Use this mode to set the health of hogs."]="Benutze diesen Modus, um die Igelgesundheit einzustellen.",
["Use this mode to tag gears for win/lose conditions."]="Benutze diesen Modus, um Gears für Sieg-/Niederlagebedingungen zu markieren.",
["Use this mode to waypoints"]="Benutze diesen Modus, um Wegpunkte zu platzieren",
["Use your ammo wisely."]="Benutze deine Munition weise.",
["Use your available weapons in order to eliminate the enemies"]="Benutze deine verfügbaren Waffen, um die Gegner zu eliminieren",
["Use your available weapons in order to eliminate the enemies."]="Benutze deine verfügbaren Waffen, um die Gegner zu eliminieren.",
["Use your ready time to think."]="Benutze deine Vorbereitungszeit zum Denken.",
["Use your rope to collect all crates as fast as possible."] = "Benutze dein Seil, um alle Kisten so schnell wie möglich einzusammeln.", -- 
["Use your rope to get from start to finish as fast as you can!"]="Nutze das Seil, um von Start zu Ziel zu gelangen – so schnell du kannst!",
["Use your rope to get to the next target, then destroy it!"] = "Benutze dein Seil, um zur nächsten Zielscheibe zu gelangen,|dann zerstöre sie!", -- Basic_Training_-_Rope
["Utility Crate Placement Mode"]="Werkzeugkistenplatzierungsmodus",
["UTILITY CRATE PLACEMENT MODE"]="WERKZEUGKISTENPLATZIERUNGSMODUS",
["Utility crates extend your time."] = "Werkzeugkisten erhöhen deine Zeit.", -- Tumbler
["Variants: Hogs will be randomized from 12 different variants"] = "Varianten: Igel werden aus 12 verschiedenen Varianten zufällig ausgewählt", -- Battalion
["Variants: Kings and air generals are disabled"] = "Varianten: Könige und Luftgeneräle sind deaktiviert", -- Battalion
["Vedgies"]="Früchties",
["Vegan Jack"]="Veganer-Jochen",
["Vega"] = "Vega", -- 
["Very valuable, haha!"] = "Sehr wertvoll, haha!", -- A_Classic_Fairytale:queen
["Victory Condition: Collect"] = "Siegbedingung: Einsammeln", -- HedgeEditor
["Victory Condition: Destroy"] = "Siegbedingung: Zerstören", -- HedgeEditor
["Victory for %s!"] = "Sieg für %s!", -- Capture_the_Flag
["Victory!"]="Sieg!",
["Violence is not the answer to your problems!"]="Gewalt ist nicht die Antwort auf deine Probleme!",
["Visit the Death Planet after completing all the other planets' main missions"]="Besuche den Todesplaneten, nachdem du die Hauptmissionen aller anderen Planeten fertiggestellt hast.",
["Visit the planets of Ice, Desert and Fruit before you proceed to the Death Planet"]="Besuche den Eis-, Wüsten- und Obstplaneten, bevor du mit dem Todesplaneten fortfährst.",
["Vladimir"] = "Vladimir", -- 
["Void"] = "Leere", -- Big_Armory
["Voldemort"] = "Voldemort", -- portal
["Voltorb"] = "Voltobal", -- 
["Wait a moment …"] = "Moment mal …", -- A_Space_Adventure:final
["Walking on Ice"] = "Auf dem Eis laufen", -- Basic_Training_-_Movement
["Walk left if you want to join Captain Lime or right if you want to decline his offer."]="Geh nach links, wenn du Leutnant Limone beitreten willst, oder nach rechts, wenn du sein Angebot ablehnen möchtest.",
["Walk: [Left]/[Right]"] = "Gehen: [Links]/[Rechts]", -- Basic_Training_-_Bazooka
["Wall Before Crate: You must touch the marked wall before you can get crates."] = "Wand Vor Kiste: Du musst die markierte Wand berühren, bevor du Kisten erhältst.", -- WxW
["Walls Before Crate: You must touch the %d marked walls before you can get crates."] = "Wände Vor Kiste: Du musst die %d markierten Wände berühren, bevor du Kisten erhältst.", -- WxW
["Wall set: No walls"] = "Wandgruppe: Keine Wände", -- WxW
["Wall set: %s (%d walls)"] = "Wandgruppe: %s (%d Wände)", -- WxW
["Wall set: %s"] = "Wandgruppe: %s", -- WxW
["Walls left: %d"] = "Verbleibende Wände: %d", -- WxW
["Wall to wall"] = "Wand zu Wand", -- WxW
["Waluigi"]="Waluigi",
["Wario"] = "Wario", -- 
["Warming Up"] = "Aufwärmübungen", -- Basic_Training_-_Grenade
["Warning: Deletition Mode Active"]="Achtung: Löschmodus aktiv",
["Warning: Fire cake detected"]="Achtung: Feuertorte gesichtet", -- ClimbHome
["Warning: Never ever leave the flying saucer while in water!"] = "Achtung: Verlasse niemals die fliegende Untertasse im Wasser!", -- Basic_Training_-_Flying_Saucer
["Warrior"]="Krieger",
["WatchBot 4000"] = "Wachboter 4000", -- User_Mission_-_Teamwork_2
["Watch your steps, young one!"]="Pass auf deine Schritte auf, Jüngling!",
["Watermelon Heart"]="Wassermelonenherz",
["Water: Rises by 37 per turn"] = "Wasser: Steigt um 37 pro Zug", -- Battalion
["Waypoint Deletion Mode"]="Wegpunktlöschmodus",
["Waypoint Editing Mode"] = "Wegpunktbearbeitungsmodus", -- HedgeEditor
["WAYPOINT EDITING MODE"] = "WEGPUNKTBEARBEITUNGSMODUS", -- HedgeEditor
["Waypoint placed. Available points remaining: %d"] = "Wegpunkt platziert. Verbleibende verfügbare Wegpunkte: %d", -- Racer
["Waypoint Placement Mode"]="Wegpunktplatzierungsmodus",
["WAYPOINT PLACEMENT MODE"]="WEGPUNKTPLATZIERUNGSMODUS",
["Waypoint placement phase"] = "Wegpunktplatzierungsphase", -- Racer
["Waypoint removed. Available points: %d"] = "Wegpunkt entfernt. Verfügbare Wegpunkte: %d", -- Racer
["Waypoints remaining: %d"] = "Verbleibende Wegpunkte: %d", -- Racer, TechRacer
["Weaklings"]="Schwächlinge",
["We all know what happens when you get frightened..."]="Wir wissen alle, was passiert, wenn du Angst kriegst.",
["Weapon Crate Placement Mode"]="Waffenkistenplatzierungsmodus",
["WEAPON CRATE PLACEMENT MODE"] = "WAFFENKISTENPLATZIERUNGSMODUS", -- HedgeEditor
["Weapon Filter: Dematerializes all ammo|    carried by enemies entering it."] = "Waffenfilter: Dematerialisiert sämtliche Munition,|    die Gegner in seinem Einflussbereich tragen.", -- Construction_Mode
["Weapon Filter"]="Waffenfilter",
["Weapons: Each team starts with %d weapon points"] = "Waffen: Jedes Team beginnt mit %d Waffenpunkten", -- Battalion
["Weapons: Hogs will get 1 out of 3 weapons randomly each turn"] = "Waffen: Igel erhalten zufällig 1 aus 3 Waffen pro Zug", -- Battalion
["Weapons: Nearly every hog variant gets 1 kamikaze"] = "Waffen: Fast jede Igelvariante erhält 1 Kamikaze", -- Battalion
["Weapon specials: Some weapons have special modes (see weapon description)."] = "Waffenextras: Einige Waffen haben Sondermodi (siehe Waffenbeschreibung).", -- Continental_supplies
["Weapons reset: The weapons are reset after each turn."] = "Gleichbleibende Bewaffnung: Die Waffen werden nach jedem Zug zurückgesetzt.", -- WxW
["We are indeed."]="Das sind wir in der Tat.",
["We can't defeat them!"]="Wir können sie nicht besiegen!",
["We can't hold them up much longer!"]="Wir können sie nicht länger aufhalten!",
["We can't let them take over our little island!"]="Wir können sie nicht unsere kleine Insel erobern lassen!",
["We come in peace! Just let our friends go!"] = "Wir kommen in Frieden! Lass einfach nur unsere Freunde gehen!", -- A_Classic_Fairytale:queen
["We could just have blown up the meteorite from the the beginning!"] = "Wir hätten doch gleich den Meteoriten in die Luft jagen können!", -- A_Space_Adventure:final
["We don't have time for that now!"] = "Wir haben jetzt keine Zeit dafür!", -- A_Classic_Fairytale:queen
["We have lost an object which was critical to this mission."] = "Wir haben ein missionskritisches Objekt verloren!", -- SimpleMission
["We have no time to waste..."]="Wir haben keine Zeit zu verlieren.",
["We have nowhere else to live!"]="Wir haben sonst keinen Ort zu leben!",
["We have spotted the enemy! We'll attack when the enemies start gathering!"]="Wir haben den Feind gesichtet! Wir werden angreifen, sobald sich die Feinde versammeln.",
["We have to find our folk!"] = "Wir müssen unsere Leute finden!", -- A_Classic_Fairytale:queen
["We have to hurry! Are you armed?"]="Wir müssen uns beeilen! Bist du bewaffnet?",
["We have to protect the village!"]="Wir müssen das Dorf schützen!",
["We have to unite and defeat those cylergs!"]="Wir müssen uns zusammentun, und diese Cylergs besiegen!",
["Welcome home! Please take a seat"] = "Willkommen zu Hause! Bitte nimm Platz", -- ClimbHome
["Welcome, Leaks A Lot!"]="Willkommen, Undichte Stelle!",
["Welcome, %s, surprised to see me?"] = "Willkommen, %s, überrascht, mich zu sehen?", -- A_Space_Adventure:death01
["Welcome to the Death Planet!"]="Willkommen auf dem Todesplaneten!",
["Welcome to the Desert Planet!"]="Willkommen auf dem Wüstenplaneten!",
["Welcome to the Fruit Planet!"]="Willkommen auf dem Obstplaneten!",
["Welcome to the meteorite!"]="Willkommen auf dem Meteoriten!",
["Welcome to the moon!"]="Willkommen auf dem Mond!",
["Welcome to the Planet of Ice!"]="Willkommen auf dem Eisplaneten!",
["Well done."]="Gut gemacht.",
["Well done! Let's destroy the next target!"] = "Gut gemacht! Lasst uns die nächste Zielscheibe zerstören!", -- Basic_Training_-_Rope
["Well done! The next target awaits."] = "Sehr gut! Die nächste Zielscheibe wartet schon!", -- Basic_Training_-_Rope
["We'll give you a problem then!"]="Dann geben wir euch ein Problem!",
["(well... kind of...)"]="(naja, sozusagen …)",
["We'll play a game first."]="Wir werden zuerst ein Spiel spielen.",
["We'll spare your life for now!"]="Wir werden dein Leben verschonen. Noch.",
["Well, that escalated quickly!"]="Das ging aber schnell in die Hose!",
["Well, that was an unnecessary act of violence."] = "Naja, das war wohl ein unnötiger Gewaltakt.", -- A_Classic_Fairytale:epil
["Well, that was a waste of time."]="Tja, das war wohl Zeitverschwendung.",
["We'll use our communicators to contact you."]="Wir werden unsere Kommunikatoren benutzen, um dich zu kontaktieren.",
["Well, well! Isn't that the cutest thing you've ever seen?"]="Sieh mal einer an! So was putziges hab ich ja schon lange nicht mehr gesehen.",
["Well, yes. This was a cyborg television show."]="Ähm, ja. Es war eine Cyborg-Fernsehsendung.",
["Well, you're about to wake up!"] = "Tja, du bist gerade im Begriff, aufzuwachen.", -- A_Classic_Fairytale:queen
["We made sure noone followed us!"]="Wir waren uns sicher, dass uns niemand gefolgt ist!",
["We need it to get split into at least two parts."]="Wir müssen ihn in mindestens zwei Teile zerbrechen.",
["We need to go back!"] = "Wir müssen zurück gehen!", -- A_Classic_Fairytale:queen
["We need to hurry!"] = "Wir müssen uns beeilen!", -- A_Classic_Fairytale:queen
["We need to move!"]="Wir müssen weiter!",
["We need to prevent their arrival!"]="Wir müssen ihre Ankunft verhindern!",
["We need to warn the village."]="Ich muss das Dorf warnen.",
["We need you to go there and detonate them yourself! Good luck!"]="Du musst dorthin gehen und sie selbst detonieren. Viel Glück!",
["We oppressed her, the only woman in the tribe!"] = "Wir haben sie unterdrückt, die einzige Frau im Stamm!", -- A_Classic_Fairytale:epil
["We're terribly sorry!"] = "Es tut uns fürchterlich Leid!", -- A_Classic_Fairytale:epil
["We risk our lives going through challenges."] = "Wir riskieren unsere Leben und bewältigen Herausforderungen.", -- A_Classic_Fairytale:queen
["We should better report this and continue our watch!"]="Wir sollten dies besser melden und unsere Wache fortsetzen.",
["We should head back to the village now."]="Wir sollten zum Dorf zurückkehren.",
["We, the youth, have to constantly prove our value."] = "Wir, die Jugend, müssen ständig unseren Wert beweisen.", -- A_Classic_Fairytale:queen
["We trusted you, you fool!"] = "Wir haben dir vertraut, du Narr!", -- A_Classic_Fairytale:queen
["We were trying to save her and we got lost."]="Wir versuchten, sie zu retten, aber haben uns verlaufen.",
["We were your home! Your family!"] = "Wir waren dein Zuhause! Deine Familie!", -- A_Classic_Fairytale:queen
["We won't accept you destroying our village!"] = "Wir werden es nicht hinnehmen, dass du unser Dorf zerstörst!", -- A_Classic_Fairytale:queen
["We won't let you hurt any more of us!"] = "Wir werden dich nicht noch mehr von uns schaden lassen!", -- A_Classic_Fairytale:queen
["We won't let you hurt her!"]="Wir werden nicht zulassen, dass du ihr wehtust!",
["We work and work until we sweat blood."] = "Wir arbeiten hart, bis wir Blut und Wasser schwitzen.", -- A_Classic_Fairytale:queen
["What?! A cannibal? Here? There is no time to waste! Come, you are prepared."]="Was?! Ein Kannibale? Hier? Es gibt keine Zeit zu verlieren! Komm, du bist vorbereitet.",
["What a douche!"]="Was für ein Blödian!",
["What am I gonna...eat, yo?"]="Was werde ich … essen?",
["What are you doing at a distance so great, young one?"]="Was tust du hier in so großer Entfernung, Jüngling?",
["What are you doing? Let her go!"]="Was tust du? Lass sie gehen!",
["What a ride!"]="Was für eine Reise!",
["What a strange cave!"]="Was für eine seltsame Höhle!",
["What a strange feeling!"]="Was für ein seltsames Gefühl!",
["What could you possibly forget in that cage?"] = "Was könntest du bloß im Käfig vergessen haben?", -- A_Classic_Fairytale:queen
["What does it look like?"] = "Wonach sieht es aus?", -- A_Classic_Fairytale:queen
["What do my faulty eyes observe? A spy!"]="Was sehen meine alten Augen? Einen Spion!",
["What do you say? Are you in?"]="Was sagst du? Bist du dabei?",
["What do you say? Will you fight for us?"]="Was sagst du? Wirst du für uns kämpfen?",
["What do you want to do?"] = "Was willst du tun?", -- A_Space_Adventure:fruit01
["Whatever floats your boat..."]="Worauf immer du Lust hast.",
["What?! For all this struggle I just win some ... time? Oh dear!"] = "Was?! Für all diese Mühen gewinne ich nur etwas … Zeit? Oh, Mann!", -- portal
["What has %s ever done to you?"] = "Was hat %s euch jemals angetan?", -- A_Classic_Fairytale:backstab
["What? Here? How did they find us?!"]="Was? Hier? Wie haben sie uns gefunden?",
["What? Is it over already?"]="Wie? Ist es schon vorbei?",
["What is it that you forgot?"] = "Was hast du vergessen?", -- A_Classic_Fairytale:queen
["What is this place?"]="Was ist dieser Ort?",
["What oppression? You were the most unoppressed member of the tribe!"] = "Welche Unterdrückung? Der Stamm hat dich überhaupt nicht unterdrückt!", -- A_Classic_Fairytale:queen
["What shall we do with the traitor?"]="Was sollen wir mit dem Verräter tun?",
["What's in the box, you ask? Let's find out!"] = "Was wohl in der Kiste ist? Finde es heraus!", -- Basic_Training_-_Movement
["What the?"] = "Was zum?", -- A_Classic_Fairytale:queen
["What?!"] = "Was?!", -- A_Classic_Fairytale:queen
["WHAT?! You're the ones attacking us!"]="WAS?! Ihr seid diejenigen, die uns angreifen!",
["When I find it..."]="Wenn ich ihn in die Finger kriege …",
["When?"]="Wann?",
["When you're in mid-air, you can continue to aim|and fire another rope if you're not attached."] = "Wenn du in der Luft bist, kannst du weiterhin zielen|und das Seil erneut schießen, wenn du nicht schon eins festhältst.", -- Basic_Training_-_Rope
["Where are all these crates coming from?!"]="Woher kommen all die Kisten?!",
["Where are they?!"]="Wo sind sie?!",
["Where did that alien run?"]="Wohin ist dieser Außerirdische gelaufen?",
["Where did you get the exploding apples and the magic bow that shoots many arrows?"]="Woher hast du die explodierenden Äpfel und den magischen Bogen, der so viele Pfeile verschießt?",
["Where did you get the exploding apples?"]="Woher hast du die explodierenden Äpfel?",
["Where did you get the magic bow that shoots many arrows?"]="Woher hast du den magischen Bogen, der so viele Pfeile verschießt?",
["Where did you get the weapons in the forest, Dense Cloud?"]="Woher hast du die Waffen im Wald gefunden, Dichte Wolke?",
["Where do you get that?!"]="Wo habt ihr das her?",
["Where have you been?!"]="Wo warst du?!",
["Where have you been?"]="Wo warst du?",
["While in modification mode, you can change|the LandFlag by clicking on an object."] = "Im Modifikationsmodus kannst du das LandFlag|ändern, indem du auf ein Objekt klickst.", -- HedgeEditor
["White Tee"]="Schneeweiß",
["Who's there?! I'll get you!"]="Wer ist da? Ich krieg dich …",
["Why are you doing this?"]="Warum tust du das?",
["Why are you helping us, uhm...?"]="Warum hilfst du uns, äh, …?",
["Why can't he just let her go?!"]="Warum kann er sie nicht einfach freilassen?",
["… why did I risk my life to collect all the parts of the anti-gravity device?"] = "… warum hab ich dann mein Leben riskiert, um all die Teile des Antischwerkraftgeräts aufzusammeln?", -- A_Space_Adventure:final
["Why did you do this?"] = "Warum hast du das getan?", -- A_Classic_Fairytale:queen
["Why did you kill your father?"] = "Warum hast du deinen Vater getötet?", -- A_Classic_Fairytale:queen
["Why do men keep hurting me?"]="Warum tun mir Männer ständig weh?",
["Why do you always have to call me names?"] = "Warum müsst ihr mich immer ausschimpfen?", -- A_Classic_Fairytale:queen
["Why do you keep betraying us?"] = "Warum betrügst du uns andauernd?", -- A_Classic_Fairytale:queen
["Why do you not like me?"]="Warum magst du mich nicht?",
["Why do you want to take over our island?"]="Warum wollt ihr unsere Insel erobern?",
["Why me?!"]="Warum ich?",
["Why %s? Why?"] = "Warum %s? Warum?", -- A_Classic_Fairytale:backstab
["Why?"] = "Warum?", -- A_Classic_Fairytale:queen
["Why, why, why, why!"] = "Warum, warum, warum, warum!", -- A_Classic_Fairytale:queen
["Why would they do this?"]="Warum würden sie das tun?",
["Will this ever end?"]="Wird dies je enden?",
["Will you give me the other parts?"]="Wirst du mir die anderen Teile geben?",
["Wind"] = "Wind", -- Basic_Training_-_Bazooka
["Winner: %s"] = "Sieger: %s", -- Mutant
["Winning time: %s"] = "Bestzeit: %s", -- Racer, TechRacer
["Win"]="Sieg",
["Wise Oak"]="Weise Eiche",
["With Dense Cloud on the land of shadows, I'm the village's only hope..."]="Jetzt, wo Dichte Wolke im Land der Schatten ist, bin ich die einzige Hoffnung des Dorfs.",
["With low bounciness, it barely bounces at all, but it is much more predictable."] = "Mit einer niedrigen Sprungkraft springen sie fast gar nicht, aber sie sind viel berechenbarer.", -- Basic_Training_-_Grenade
["With the rest of the tribe gone, it was up to %s to save the village."] = "Da der Rest des Stammes fort war, lag es alleine an %s, das Dorf zu retten.", -- A_Classic_Fairytale:dragon
["Worry not, for it is a peaceful animal! There is no reason to be afraid..."]="Sei ganz beruhigt, da es ein friedliebendes Tier ist. Es gibt keinen Grund, Angst zu haben.",
["Wow, what a dream!"]="Wow, was für ein Traum!",
["Xeli"] = "Xeli", -- 
["Xerxes"] = "Xerxes", -- 
["Y3K1337"]="Y3K1337",
["Yay, we won!"]="Hurra, wir haben gewonnen!",
["Y Chwiliad"]="Y Chwiliad",
["Yeah...I think it's a 'he', lol."]="Ja, ich glaube, dass es ein »er« ist. (lach)",
["Yeah, sure! I died. Hilarious!"] = "Ja, sicher! Ich starb. Urkomisch!", -- A_Classic_Fairytale:backstab
["Yeah, take that!"]="Jawohl, nimm das!",
["Yeah? Watcha gonna do? Cry?"]="Ja und? Was willst du schon tun? Heulen?",
["Yeah, well, for some dude to be happy, some other dude has to suffer."] = "Tja, naja, damit ein Typ glücklich sein kann, muss ein anderer Typ leiden.", -- A_Classic_Fairytale:queen
["Yellow"] = "Gelb", -- 
["Yellow Pepper"]="Gelbpaprika",
["Yellow Watermelons"]="Gelbe Wassermelonen",
["Yes, but you're … different!"] = "Ja, aber du bist … anders!", -- A_Classic_Fairytale:queen
["Yes!"]="Ja!",
["Yes, yeees! You are now ready to enter the real world!"]="Ja, Jaaa! Jetzt bist du bereit, die wirkliche Welt zu betreten!",
["Yeti"] = "Yeti", -- 
["Yikes!"] = "Oh Schreck!", -- A_Space_Adventure:desert01
["Yo, dude! Get away from our weapons!"] = "He, Leute! Weg von unseren Waffen!", -- A_Classic_Fairytale:queen
["Yo, dude, we're here, too!"]="Heda, wir sind auch da!",
["Yo, escort my buttocks!"] = "Yo, geleitet meinen Hintern hinfort!", -- A_Classic_Fairytale:queen
["Yoshi"]="Yoshi",
["Yo, the aliens gave me plants. Medicinal plants. Lots of it."] = "Yo, die Aliens gaben mir Pflanzen. Medizinische Pflanzen. Viele von ihnen.", -- A_Classic_Fairytale:queen
["You are far from home, and the water is rising, climb up as high as you can!|Your score will be based on your height."]="Du bist weit weg von Zuhause, und das Wasser steigt, klettere so hoch, wie du kannst!|Deine Punktzahl wird von deiner Höhe abhängen.",
["You are given the chance to turn your life around..."]="Ich gebe dir die Chance, dein Leben auf den Kopf zu stellen.",
["You are in control of all the active ally units."]="Du hast die Kontrolle über alle aktive verbündete Einheiten.",
["You are indeed the best PAotH pilot."]="Du bist wirklich der beste PAdI-Pilot.",
["You are out of danger, time to go to the moon!"]="Du bist in Sicherheit. Zeit, zum Mond zu gelangen!",
["You are playing with our lives here!"]="Du spielst mit unseren Leben!",
["You are sabotaged, RUN!"]="Du wurdest sabotiert, LAUF!",
["You are the one who fled! So, you are alive."]="Du bist der, der floh! Du lebst also.",
["You bear impressive skills, %s!"] = "Du hast erstaunliche Fähigkeiten, %s!", -- A_Classic_Fairytale:dragon
["You can also hold down the key for “Precise Aim” to prevent slipping."] = "Alternativ kannst du die Taste für »Genaues Zielen« gedrückt halten, um nicht zu rutschen.", -- Basic_Training_-_Movement
["You can always trust me!"] = "Du kannst mir immer vertrauen!", -- A_Classic_Fairytale:epil
["You can always trust me! I love you!"] = "Du kannst mir immer vertrauen! Ich liebe dich!", -- A_Classic_Fairytale:epil
["You can avoid some battles."]="Du kannst einige Kämpfe vermeiden.",
["You can change the detonation timer of grenades."] = "Du kannst den Zeitzünder von Granaten einstellen.", -- Basic_Training_-_Grenade
["You can choose another planet by replaying this mission."]="Du kannst einen anderen Planeten auswählen, indem du diese Mission erneut spielst.",
["You can dive with your flying saucer!"] = "Mit deiner fliegenden Untertasse kannst du abtauchen!", -- Basic_Training_-_Flying_Saucer
["You can even change your aiming direction in mid-flight if you first hold [Precise] and then press [Up] or [Down]."] = "Du kannst sogar deine Zielrichtung im Flug ändern, wenn du|zuerst [Genaues Zielen] gedrückt hältst, und dann [Hoch] oder [Runter] drückst.", -- Basic_Training_-_Flying_Saucer
["You can further customize the race by changing the scheme script parameter."] = "Du kannst das Rennen ferner bearbeiten, indem du den Skriptparameter im Schema änderst.", -- TechRacer
["You can only use the sniper rifle or the watermelon bomb"]="Du kannst nur das Scharfschützengewehr oder die Wassermelonenbombe benutzen",
["You can only use the sniper rifle or the watermelon bomb."]="Du kannst nur das Scharfschützengewehr oder die Wassermelonenbombe benutzen.",
["You can practice moving around and using utilities in this mission.|However, it will never end!"] = "In dieser Mission kannst du üben, dich herumbewegen|und Werkzeuge benutzen.|Aber sie wird niemals enden!", -- A_Classic_Fairytale:epil
["You can set the bounciness of grenades (and grenade-like weapons)."] = "Du kannst die Sprunghaftigkeit von Granaten (und granatenähnlichen Waffen) setzen.", -- Basic_Training_-_Grenade
["You can’t open a portal on the blue surface."] = "Du kannst kein Portal auf der blauen Oberfläche öffnen.", -- portal
["You can use the other 2 hogs to assist you."]="Du kannst die anderen beiden Igel benutzen, um dich zu unterstützen.",
["You can use the rope to reach new places."] = "Du kannst das Seil benutzen, um neue Orte zu erreichen.", -- Basic_Training_-_Rope
["You choose well, %s!"] = "Eine gute Wahl, %s!", -- A_Space_Adventure:fruit01
["You completed the mission in %.3f seconds."] = "Du hast die Mission in %.3f Sekunden abgeschlossen.", -- A_Space_Adventure:ice02
["You completed the mission in %d rounds."] = "Du hast die Mission in %d Runden abgeschlossen.", -- A_Space_Adventure:death02, A_Space_Adventure:fruit03
["You completed the mission in "]="Du hast die Mission fertiggestellt in ",
["You complete the mission in "]="Du hast die Mission abgeschlossen in ",
["You couldn't have come to a worse time, %s!"] = "Du konntest zu keiner schlechteren Zeit gekommen sein, %s!", -- A_Space_Adventure:fruit01
["You couldn't possibly believe that after refusing my offer I'd just let you go!"]="Du kannst wohl nicht ernsthaft glauben, dass ich dich einfach laufen lasse, nachdem du mein Angebot abgelehnt hast!",
["You'd almost swear the water was rising!"]="Man könnte fast schwören, das Wasser würde steigen!",
["You'd better watch your steps..."]="Pass besser auf, wohin du trittst.",
["You defended yourself against Captain Lime."]="Du hast dich gegen Leutnant Limone gewehrt.",
["You defended yourself against %s."] = "Du hast dich gegen %s gewehrt.", -- A_Space_Adventure:fruit02
["You defended yourself against the Strawberry Assassins."]="Du hast dich gegen die Erdbeerassassinen gewehrt.",
["You did great, %s! However, we aren't out of danger yet!"] = "Du hast dich gut geschlagen, %s! Aber die Gefahr ist noch nicht gebannt!", -- A_Space_Adventure:cosmos
["You don't deserve my sacrifice!"] = "Ihr verdient mein Opfer nicht!", -- A_Classic_Fairytale:queen
["You drove Professor Hogevil away."] = "Du hast Professor Bösigel verjagt.", -- A_Space_Adventure:moon01
["You drove the minions away."] = "Du hast die Lakaien verjagt.", -- A_Space_Adventure:moon01
["You endangered your whole tribe, you bastard!"] = "Du hast deinen ganzen Stamm gefährdet, du Schwein!", -- A_Classic_Fairytale:queen
["You failed to kill all enemies in a single turn."] = "Du hast es nicht geschafft, alle Gegner in einem Zug zu töten.", -- Big_Armory
["You fought bravely and you helped us win this battle!"]="Du hast mutig gekämpft und uns geholfen, diese Schlacht zu gewinnen!",
["You give me no choice!"] = "Ihr habt mir keine andere Wahl gelassen!", -- A_Classic_Fairytale:queen
["You got a killer mask there, amigo!"] = "Du hast eine Killermaske, Amigo!", -- A_Classic_Fairytale:epil
["You got me"]="Du hast mich.",
["You got me!"] = "Du hast mich!", -- A_Space_Adventure:moon02
["You had %.1fs remaining on the clock (+%d points)."] = "Verbleibende Zeit: %.1fs (+%d Punkte)", -- 
["You had %.2fs remaining on the clock (+%d points)."]="Verbleibende Zeit: %.2fs (+%d Punkte).",
["You had "]="Du hattest ",
["You have 7 turns until the next wave arrives.|Make sure the arriving cannibals are greeted appropriately!|If the hog dies, the cause is lost.|Hint: You might want to use some mines ..."] = "Du hast 7 Züge, bevor die nächste Welle ankommt.|Stell sicher, die ankommenden Kannibalen angemessen zu begrüßen!|Wenn der Igel stirbt, ist alles verloren.|Tipp: Du solltest ein paar Minen legen.", -- A_Classic_Fairytale:backstab
["You have acquired the last device part."]="Du hast das letzte Bauteil erhalten.",
["You have activated Switch Hedgehog!"] = "Du hast »Igel wechseln« aktiviert!", -- Basic_Training_-_Movement
["You have beaten the challenge!"]="Du hast die Herausforderung gemeistert!",
["You have beaten the team record, congratulations!"] = "Du hast den Teamrekord geschlagen, Gratulation!", -- Utils
["You have been giving us out to the enemy, haven't you!"]="Du hast uns an den Feind verkauft, nicht wahr?",
["You have chosen the perfect moment to leave."]="Du hast den perfekten Augenblick ausgesucht, um zu gehen.",
["You have chosen to fight!"] = "Du hast dich für die Schlacht entschieden!", -- A_Space_Adventure:fruit01
["You have chosen to fight! Lead the Green Bananas to battle and eliminate all the enemies!"]="Du hast dich für die Schlacht entschieden! Führe die Grünen Bananen in die Schlacht und eliminiere alle Feinde.",
["You have chosen to flee."] = "Du hast dich für die Flucht entschieden.", -- A_Space_Adventure:fruit01
["You have chosen to flee ... Unfortunately, the only place where you can launch your saucer is the left-most place on the map."]="Du hast dich für die Flucht entschieden. Leider ist der einzige Ort, wo du deine Untertasse starten kannst, ganz links auf der Karte.",
["You have collected %d out of %d crate(s)."] = "Du hast %d von %d Kiste(n) eingesammelt.", -- 
["You have collected the “Switch Hedgehog” utility!"] = "Du hat das Werkzeug »Igel wechseln« eingesammelt!", -- Basic_Training_-_Movement
["You have completed the Basic Bazooka Training!"] = "Du hast die Übungen mit der Bazooka abgeschlossen!", -- Basic_Training_-_Bazooka
["You have completed the Basic Grenade Training!"] = "Du hast die Übungen mit der Granate abgeschlossen!", -- Basic_Training_-_Grenade
["You have completed the Basic Movement Training!"] = "Du hast die Fortbewegungsübungen abgeschlossen!", -- Basic_Training_-_Movement
["You have completed this challenge in %.2f s (+%d points)."] = "Du hast diese Herausforderung in %.2f s gemeistert (+%d Punkte).", -- User_Mission_-_Rope_Knock_Challenge
["You have destroyed all targets!"]="Du hast alle Zielscheiben zerstört!",
["You have destroyed all the targets."]="Du hast alle Zielscheiben zerstört.",
["You have destroyed %d of %d targets (+%d points)."]="Du hast %d von %d Zielscheiben zerstört (+%d Punkte).",
["You have dropped %d missiles."]="Du hast %d Bomben abgeworfen.",
["You have eliminated all visible enemy hedgehogs!"]="Du hast alle sichtbaren feindlichen Igel besiegt!",
["You have eliminated Professor Hogevil."] = "Du hast Professor Bösigel eliminiert.", -- A_Space_Adventure:moon01
["You have eliminated the evil minions."] = "Du hast die bösen Lakaien eliminiert.", -- A_Space_Adventure:moon01
["You have escaped successfully."]="Du bist erfolgreich geflohen.",
["You have failed to complete your task, young one!"]="Du hast versagt, Jüngling!",
["You have failed to save the tribe!"]="Du hast es nicht geschafft, den Stamm zu retten!",
["You have finally figured it out!"]="Ihr habt es endlich kapiert!",
["You have finished the Basic Rope Training!"] = "Du hast die Seilübung abgeschlossen!", -- Basic_Training_-_Rope
["You have finished the challenge!"]="Du hast die Herausforderung gemeistert!",
["You have finished the challenge in %.3f s."] = "Du hast die Herausforderung in %.3f s bewältigt.", -- 
["You have finished the Flying Saucer Training!"] = "Du hast die Übungen mit der fliegenden Untertasse abgeschlossen!", -- Basic_Training_-_Flying_Saucer
["You have finished the target practice!"] = "Du hast die Zielübung abgeschlossen!", -- 
["You have kidnapped our whole tribe!"]="Ihr habt unseren ganzen Stamm entführt!",
["You have killed an innocent hedgehog!"]="Du hast einen unschuldigen Igel getötet!",
["You have killed %d of 16 hedgehogs (+%d points)."] = "Du hast %d von 16 Igeln getötet (+%d Punkte).", -- User_Mission_-_Rope_Knock_Challenge
["You have launched %d bazookas."]="Du hast %d Bazookas abgefeuert.",
["You have launched %d homing bees."]="Du hast %d zielsuchende Bienen abgefeuert.",
["You have made %d shots."]="Du hast %d Schüsse abgegeben.",
["You have managed to catch the blue hedgehog in %.3f seconds."] = "Du hast es geschafft, den blauen Igel in %.3f Sekunden zu fangen.", -- A_Space_Adventure:moon02
["You have managed to catch the blue hedgehog in time"]="Du hast es geschafft, den blauen Igel rechtzeitig zu fangen.",
["You have never worked a bit in your life!"] = "Du hast in deinem gesamten Leben noch nicht gearbeitet!", -- A_Classic_Fairytale:queen
["You have nothing to be afraid of now."] = "Jetzt hast du nichts mehr zu befürchten.", -- A_Classic_Fairytale:epil
["You haven't rescued anyone."]="Du hast niemanden gerettet.",
["You have perfectly beaten the challenge!"]="Du hast die Herausforderung gemeistert!",
["You have proven yourself worthy to see our most ancient secret!"]="Du hast dich bewährt, um unser ältestes Geheimnis zu sehen.",
["You have proven yourselves worthy!"]="Ihr habt euch bewährt.",
["You have reached the take-off area successfully!"]="Du hast das Startfeld erfolgreich erreicht!",
["You have rescued H and Dr. Cornelius."]="Du hast H und Dr. Cornelius gerettet.",
["You have shot %d times."] = "Du hast %d Schüsse abgegeben.", -- 
["You have successfully eliminated Professor Hogevil."]="Du hast Professor Bösigel erfolgreich eliminiert!",
["You have successfully finished the campaign!"] = "Du hast die Kampagne erfolgreich abgeschlossen!", -- A_Classic_Fairytale:epil
["You have successfully finished the sniper rifle training!"]="Du hast das Scharfschützentraining abgeschlossen!",
["You have thrown %d cluster bombs."]="Du hast %d Splittergranaten geworfen.",
["You have thrown %d grenades."]="Du hast %d Granaten geworfen.",
["You have to be careful and must not die!"] = "Du musst vorsichtig sein und darfst nicht sterben!", -- A_Space_Adventure:cosmos
["You have to catch the other hog 3 times."]="Du musst den anderen Igel 3 mal fangen.",
["You have to complete the main mission on moon in order to travel to other planets."]="Du musst die Hauptmission auf dem Mond erledigen, damit du zu den anderen Planeten reisen kannst.",
["You have to continue alone from now on."]="Von hier an musst du alleine fortfahren.",
["You have to destroy all the explosives without dying!"]="Du musst alle Sprengstoffe zerstören, ohne zu sterben!",
["You have to destroy all the targets."]="Du musst alle Zielscheiben zerstören.",
["You have to destroy the target above by dropping a grenade on it from your flying saucer."] = "Du musst das obige Ziel zerstören, indem du eine Granate|aus deiner fliegenden Untertasse darauf abwirfst.", -- Basic_Training_-_Flying_Saucer
["You have to destroy two targets, but the previous technique would be very difficult or dangerous to use."] = "Du musst 2 Zielscheiben zerstören, aber die vorherige Methode wäre hier sehr schwer oder gefährlich.", -- Basic_Training_-_Flying_Saucer
["You have to drop the grenade from rope!"] = "Du musst die Granate vom Seil fallen lassen!", -- Basic_Training_-_Rope
["You have to eliminate all the enemies."]="Du musst alle Gegner eliminieren.",
["You have to eliminate all the visible enemies."]="Du musst alle sichtbaren Gegner eliminieren.",
["You have to get the weapons and rescue the PAotH researchers."]="Wir müssen die Waffen besorgen und die PAdI-Forscher retten.",
["You have to get to the left-most land and remove any enemy hog from there."]="Du musst zum linken Rand gelangen und von dort alle feindlichen Igel beseitigen.",
["You have to go back to the moon!"] = "Du musst zum Mond zurück!", -- A_Space_Adventure:cosmos
["You have to move upwards, not downwards, %s!"]="Du musst nach oben, nicht nach unten, %s!",
["You have to reach the left-most place on the map."] = "Du musst den linken Kartenrand erreichen.", -- A_Space_Adventure:fruit01
["You have to stand very close to him"]="Du musst sehr nahe an ihm stehen.",
["You have to travel again"]="Du musst erneut reisen.",
["You have to try again!"]="Du muss es nochmal versuchen!",
["You have triggered the secret Do-Not-Rope-to-the-Moon Defense System."] = "Du hast das geheime Seil-dich-nicht-zum-Mond-hinauf-Verteidigungssystem ausgelöst.", -- A_Space_Adventure:cosmos
["You have unlocked the target radar!"] = "Du hast das Zielscheibenradar freigeschaltet!", -- TargetPractice
["You have used %d flying saucers."] = "Du hast %d fliegende Untertassen benutzt.", -- A_Space_Adventure:ice02
["You have used %d RC planes."]="Du hast %d Funkflugzeuge benutzt.",
["You have used "]="Du hast benutzt ",
["You have used only 1 RC plane. Outstanding!"]="Du hast nur ein Funkflugzeug gebraucht. Ausgezeichnet!",
["You have violated PAotH regulations!"] = "Du hast gegen die PAdI-Vorschriften verstoßen!", -- A_Space_Adventure:cosmos
["You have won the game by proving true cooperative skills!"]="Ihr hab das Spiel gewonnen, indem ihr wahre kooperative Fähigkeiten gezeigt habt!",
["You just appeared out of thin air!"]="Du bist einfach aus dem Nichts aufgetaucht!",
["You just can't let it go, can you!"] = "Du kannst einfach nicht loslassen, oder?", -- A_Classic_Fairytale:queen
["You just committed suicide..."]="Du hast gerade Selbstmord begangen.",
["You just got yourself some extra health.|The more health your hedgehogs have, the better!"] = "Du hast etwas Gesundheit aufgesammelt.|Je gesünder deine Igel sind, desto besser!", -- Basic_Training_-_Movement
["You killed my father, you monster!"]="Du hast meinen Vater umgebracht, du Monster!",
["You know...taking a stroll."]="Du weißt schon … umherbummeln.",
["You know what? I don't even regret anything!"]="Weißt du was? Ich bereue nichts!",
["You'll get an extra sniper rifle every time you kill an enemy hog with a limit of max 4 rifles"] = "Du erhältst ein zusätzliches Scharfschützengewehr für jeden Igel, den du tötest (max. 4 Gewehre)", -- A_Space_Adventure:fruit03
["You'll get an extra sniper rifle every time you kill an enemy hog with a limit of max 4 rifles."] = "Du erhältst ein zusätzliches Scharfschützengewehr für jeden Igel, den du tötest (max. 4 Gewehre).", -- A_Space_Adventure:fruit03
["You'll get an extra teleport every time you kill an enemy hog with a limit of max 2 teleports"]="Du erhältst einen zusätzlichen Teleporter für jeden getöteten Igel (max. 2 Teleporter)", -- A_Space_Adventure:fruit03
["You'll get an extra teleport every time you kill an enemy hog with a limit of max 2 teleports."]="Du erhältst einen zusätzlichen Teleporter für jeden getöteten Igel (max. 2 Teleporter).", -- A_Space_Adventure:fruit03
["You'll get extra time in case you need it when you pass a ring"]="Du erhältst Bonuszeit, wenn du sie brauchst, sobald du einen Ring passierst", -- A_Space_Adventure:ice02
["You'll get extra time in case you need it when you pass a ring."]="Du erhältst Bonuszeit, wenn du sie brauchst, sobald du einen Ring passierst.", -- A_Space_Adventure:ice02
["You'll have only 2 watermelon bombs during the game"]="Du hast nur 2 Wassermelonenbomben während des Spiels", -- A_Space_Adventure:fruit03
["You'll have only 2 watermelon bombs during the game."]="Du hast nur 2 Wassermelonenbomben während des Spiels.", -- A_Space_Adventure:fruit03
["You'll have only one RC plane at the start of the mission"]="Am Anfang der Mission hast du nur ein Funkflugzeug",
["You'll have only one RC plane at the start of the mission."]="Am Anfang der Mission hast du nur ein Funkflugzeug.",
["You'll have to eliminate Captain Lime at the end."]="Am Ende musst du Leutnant Limone eliminieren.", -- A_Space_Adventure:fruit02
["You'll have to eliminate %s at the end."] = "Am Ende musst du %s eliminieren.", -- A_Space_Adventure:fruit02
["You'll have to eliminate the Strawberry Assassins at the end."]="Am Ende musst du die Erdbeerassassinen eliminieren.", -- A_Space_Adventure:fruit02
["You'll lose if you die or if your time is up."]="Du verlierst, wenn du stirbst oder deine Zeit abläuft.", -- A_Space_Adventure:moon02
["You'll see what I mean!"]="Du wirst verstehen, was ich meine.",
["You lost your target, try again!"]="Du hast deine Zielscheibe verloren, versuch es nochmal!",
["You may find it handy."]="Du könntest es gebrauchen.", -- A_Space_Adventure:cosmos
["You may only attack from a rope!"]="Du darfst nur von einem Seil angreifen!",
["You may only place 1 Extra Time crate per turn."] = "Du darfst nur 1 Extrazeit-Kiste pro Zug platzieren.", -- Construction_Mode
["You may only place %d crates per round."] = "Du darfst nur %d Kisten pro Runde platzieren.", -- Construction_Mode
["- You may only score when your flag is in your base"] = "- Du kannst nur punkten, wenn deine Flagge in deiner Basis ist", -- Capture_the_Flag
["You meatbags are pretty slow, you know!"]="Ihr Fleischklumpen seid ziemlich schwer von Begriff, wisst ihr?",
["You might want to find a way to instantly kill arriving cannibals!"]="Du könntest eine Möglichkeit finden, um die ankommenden Kannibalen sofort zu töten.",
["You must attack from a rope, after you collected a crate!"] = "Du musst vom Seil angreifen, nachdem du eine Kiste aufgesammelt hast!", -- WxW
["You must first collect a crate before you attack!"] = "Du musst zuerst eine Kiste aufsammeln, bevor du angreifen kannst!", -- WxW
["You must survive the flood in order to score."]="Du musst das Hochwasser überleben, um zu punkten.",
["You never give me plants!"] = "Ihr gebt mir niemals Pflanzen!", -- A_Classic_Fairytale:queen
["Young one, you are telling us that they can instantly change location without a shaman?"]="Jüngling, willst du uns etwa weiß machen, dass sie ihre Position sofort ändern können, ohne einen Schamanen?",
["You now have infinite fuel, grenades and bazookas for fun."] = "Du hast jetzt unbegrenzten Treibstoff, Granaten und Bazookas nur so zum Spaß.", -- Basic_Training_-_Flying_Saucer
["You only get 1 rope this time, don't waste it!"] = "Diesmal erhältst du nur 1 Seil, vergeud es nicht!", -- Basic_Training_-_Rope
["You only have 2 flying saucers this time."] = "Diesmal hast du nur 2 fliegende Untertassen.", -- Basic_Training_-_Flying_Saucer
["You only have one flying saucer this time."] = "Diesmal hast du nur eine fliegende Untertasse.", -- Basic_Training_-_Flying_Saucer
["You probably know what to do next..."]="Du weißt vermutlich, was als nächstes zu tun ist.",
["Your accuracy was %.1f%%."]="Deine Treffgenauigkeit betrug %.1f%%.",
["Your accuracy was %.1f%% (+%d points)."] = "Deine Treffgenauigkeit betrug %.1f%% (+%d Punkte).", -- 
["Your ammo is limited this time."] = "Diesmal ist deine Munition begrenzt.", -- Basic_Training_-_Bazooka
["Your deaths will be avenged, %s!"] = "Eure Tode werden nicht ungesühnt bleiben, %s!", -- A_Classic_Fairytale:enemy
["Your death will not be in vain, Dense Cloud!"]="Dein Tod wird nicht ungesühnt bleiben, Dichte Wolke!",
["You're a coward!"] = "Du bist ein Feigling!", -- A_Classic_Fairytale:queen
["You're...alive!? But we saw you die!"]="Du … lebst? Aber wir sahen dich sterben!",
["You're a pathetic liar!"]="Du bist ein dreckiger Lügner!",
["You're funny!"]="Du bist lustig!",
["You're on your way to freeing your tribe!"] = "Ihr seid dabei, euren Stamm zu befreien!", -- A_Classic_Fairytale:queen
["You're pathetic! You are not worthy of my attention..."]="Du bist erbärmlich! Du hast meine Aufmerksamkeit nicht verdient.",
["You're probably wondering why I brought you back ..."] = "Ihr fragst euch bestimmt, warum ich euch zurückgebracht habe.", -- A_Classic_Fairytale:backstab
["Your escape took you %d turns."] = "Deine Flucht dauerte %d Züge.", -- A_Space_Adventure:desert02
["You're so brave! I feel safe with you."] = "Du bist so mutig! In deinen Händen fühle ich mich sicher.", -- A_Classic_Fairytale:epil
["You're some piece of hypocrite junkie!"] = "Du bist sowas von ein heuchlerischer Junkie!", -- A_Classic_Fairytale:queen
["You're terrorizing the forest...We won't catch anything like this!"]="Du terrorisierst den Wald. Wir werden auf diese Weise nichts fangen!",
["You retrieved the lost part."]="Du hast das verlorene Teil ergattert.", -- A_Space_Adventure:fruit02
["Your fastest escape so far: %d turns"] = "Deine schnellste Flucht bis jetzt: %d Züge", -- A_Space_Adventure:desert02
["Your fastest victory so far: %d rounds"] = "Dein schnellster Sieg bis jetzt: %d Runden", -- A_Space_Adventure:death02, A_Space_Adventure:fruit03
["Your first destination is the moon in order to get more fuel."]="Dein erstes Ziel ist der Mond, um mehr Treibstoff zu erhalten.",
["Your hedgehog died!"]="Dein Igel ist gestorben!",
["Your hedgehog has been revived!"] = "Dein Igel wurde wiederbelebt!", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
["Your hedgehog was panicly afraid of the water and decided to go in a safe distance of %d from it."]="Dein Igel hatte panische Angst vorm Wasser und hatte einen Sicherheitsabstand von %d erreicht.",
["Your height over time"]="Deine Höhe über die Zeit",
["Your hogs must survive!"]="Deine Igel müssen überleben.",
["Your movement skills will be evaluated now."]="Deine Fortbewegungsfähigkeiten werden nun getestet.",
["Your next task is to collect some crates by using the rope!"] = "Für deine nächste Aufgabe musst du ein paar Kisten mit dem Seil aufsammeln.", -- A_Classic_Fairytale:first_blood
["Your personal best time so far: %.3f seconds"] = "Deine persönliche Bestzeit bisher: %.3f Sekunden", -- A_Space_Adventure:ice02, A_Space_Adventure:moon02
["Your rank: %s"]="Dein Rang: %s",
["Your rope is gone! Try again!"] = "Dein Seil ist futsch! Versuch es erneut!", -- Basic_Training_-_Rope
["You saved %d of 8 hegehogs."] = "Du hast %d von 8 Igeln gerettet.", -- User_Mission_-_That_Sinking_Feeling
["You see, hedgehog spikes are very, very valuable."] = "Ihr müsst verstehen, Igelstacheln sind sehr, sehr wertvoll.", -- A_Classic_Fairytale:queen
["You see the wind strength at the bottom right corner."] = "Du siehst die Windstärke in der unteren rechten Ecke.", -- Basic_Training_-_Bazooka
["You see the wind strength at the top."] = "Du siehst die Windstärke oben.", -- Basic_Training_-_Bazooka
["You should have known that we don't rely on meatbags!"] = "Ihr solltet gewusst haben, dass wir uns nicht auf Fleischbeutel verlassen!", -- A_Classic_Fairytale:queen
["You should know this more than anyone, Leaks!"] = "Du solltest es von allen am Ehesten wissen, Undichte!", -- A_Classic_Fairytale:queen
["You speak great truth, Hannibal. Here, take a sip!"] = "Du sprichst weise Worte, Hannibal. Hier, nimm einen Schluck!", -- A_Classic_Fairytale:epil
["You've been assaulting us, we have been just defending ourselves!"]="Ihr habt uns überfallen, wir haben uns nur verteidigt!",
["You will be avenged!"]="Du wirst gerächt!",
["You will fail if you run out of ammo and there are still targets available."]="Du wirst verlieren, wenn du keine Munition mehr hast und immer noch Zielscheiben übrigbleiben.", -- A_Space_Adventure:desert03
["You will gain some extra ammo from the crates the next time you play the \"Getting to the device\" mission."]="Du wirst etwas zusätzliche Munition aus den Kisten erhalten, wenn du das nächste Mal die Mission »Zum Greifen nah« spielst.", -- A_Space_Adventure:fruit03
["You will play every 3 turns"]="Du wirst alle 3 Züge spielen.",
["You will play every 3 turns."] = "Du wirst alle 3 Züge spielen.", -- A_Space_Adventure:fruit01
["You won't believe what happened to me!"]="Ihr werdet nicht glauben, was mir passiert ist!",
["Yuck! I bet they'll keep worshipping her even after I save the village!"]="Pfui! Ich wette, sie werden sie verehren, selbst, wenn ich das Dorf rette.",
["Yumme Gunpowder"] = "S. Schießpulver", -- 
["Zealandia"]="Neuseeland-Kontinent",
["Zombie"] = "Zombie", -- 
["Zombi"] = "Zombi", -- portal
["Zoom: [Pinch] with 2 fingers"] = "Zoomen: Mit 2 Fingern [kneifen]", -- Basic_Training_-_Movement
["Zoom: [Rotate mouse wheel]"] = "Zoomen: [Mausrad drehen]", -- Basic_Training_-_Movement
["Zork"]="Zork",
}
